@@ -1,8 +1,18 @@
-$(document).ready(function () {
+$(function () {
 
     const TABLE_DATA_REFRESH = 15000;
     const DEFAULT_RECIPIENT_ID = 0;
     const COLUMN_INDEX_ENDPOINT_TYPE = 1;
+    const SEVERITIES = [
+        'debug',
+        'info',
+        'notice',
+        'warning',
+        'error',
+        'critical',
+        'alert',
+        'emergency'
+    ];
 
     const makeFormData = (formSelector) => {
 
@@ -10,9 +20,10 @@ $(document).ready(function () {
 
         const params = {
             recipient_name: $(`${formSelector} [name='recipient_name']`).val(),
-            endpoint_conf_name: $(`${formSelector} [name='endpoint']`).val(),
+            endpoint_id: $(`${formSelector} [name='endpoint']`).val(),
             recipient_minimum_severity: $(`${formSelector} [name='recipient_minimum_severity']`).val(),
-            recipient_user_script_categories: $(`${formSelector} [name='recipient_user_script_categories']`).val().join(",")
+            recipient_check_categories: $(`${formSelector} [name='recipient_check_categories']`).val().join(","),
+            bind_to_all_pools: $(`${formSelector} [name='bind_to_all_pools']`).prop('checked')
         };
 
         // load each recipient params inside the template container in params
@@ -47,8 +58,9 @@ $(document).ready(function () {
         const body = { action: 'test', csrf: pageCsrf };
         $.extend(body, data);
 
+        $button.attr("disabled", "disabled");
         $button.find('span.spinner-border').fadeIn();
-        $feedbackLabel.removeClass(`text-danger text-success`).text(`${i18n.testing_recipient}...`).show();
+        $feedbackLabel.removeClass(`alert-danger alert-success`).text(`${i18n.testing_recipient}...`).show();
 
         try {
 
@@ -61,16 +73,16 @@ $(document).ready(function () {
             }, 5000);
             const { result } = await request.json();
 
-            if (result.status == "failed") {
+            if (result.status === "failed") {
                 $button.find('span.spinner-border').fadeOut(function () {
-                    $feedbackLabel.addClass(`text-danger`).html(result.error.message);
+                    $feedbackLabel.addClass(`alert-danger`).html(result.error.message);
                 });
                 return;
             }
 
             // show a green label to alert the endpoint message
             $button.find('span.spinner-border').fadeOut(function () {
-                $feedbackLabel.addClass('text-success').html(i18n.working_recipient).fadeOut(3000);
+                $feedbackLabel.addClass('alert-success').html(i18n.working_recipient).fadeOut(3000);
             });
 
         }
@@ -78,17 +90,18 @@ $(document).ready(function () {
 
             $button.find('span.spinner-border').fadeOut(function () {
 
-                $feedbackLabel.addClass(`text-danger`);
+                $feedbackLabel.addClass(`alert-danger`);
 
                 if (err.message == "Response timed out") {
                     $feedbackLabel.html(i18n.timed_out);
                     return;
                 }
-
                 $feedbackLabel.html(i18n.server_error);
-
             });
         }
+        finally {
+            $button.removeAttr("disabled");
+        }
 
     }
 
@@ -125,10 +138,19 @@ $(document).ready(function () {
         {
             text: '<i class="fas fa-plus"></i>',
             className: 'btn-link',
+            attr: {
+                id: 'btn-add-recipient',
+            },
             enabled: CAN_CREATE_RECIPIENT,
             action: function (e, dt, node, config) {
                 $('#add-recipient-modal').modal('show');
             }
+        },
+        {
+            text: '<i class="fas fa-sync"></i>',
+            action: function (e, dt, node, config) {
+                $recipientsTable.ajax.reload();
+            }
         }
     ]);
     dtConfig = DataTableUtils.setAjaxConfig(dtConfig, `${http_prefix}/lua/get_recipients_endpoint.lua`);
@@ -139,6 +161,7 @@ $(document).ready(function () {
             },
             {
                 data: `endpoint_key`,
+                width: '15%',
                 render: (endpointType, type, recipient) => {
 
                     if (type == "display") {
@@ -147,7 +170,7 @@ $(document).ready(function () {
                         const isBuiltin = (recipient.endpoint_conf && recipient.endpoint_conf.builtin) || false;
 
                         if (isBuiltin) {
-                            badge = `<span class='badge badge-dark'>built-in</span>`;
+                            badge = `<span class='badge bg-dark'>built-in</span>`;
                         }
 
                         return `${i18n.endpoint_types[endpointType]} ${badge}`;
@@ -182,39 +205,78 @@ $(document).ready(function () {
                 width: "15%",
                 render: $.fn.dataTableExt.absoluteFormatSecondsToHHMMSS
             },
-	    {
-		data: "stats.num_uses",
-		className: "text-right",
-		width: "10%",
-		render: function(data, type) {
-		    if (type == "display") return NtopUtils.fint(data);
-		    return data;
-		}
-	    },
-	    {
-		data: "stats.num_drops",
-		className: "text-right",
-		width: "10%",
-		render: function(data, type) {
-		    if (type == "display") return NtopUtils.fint(data);
-		    return data;
-		}
-	    },
+            {
+                data: "stats.num_uses",
+                className: "text-right",
+                width: "10%",
+                render: function (data, type) {
+                    if (type === "display") return NtopUtils.fint(data);
+                    return data;
+                }
+            },
+            {
+                data: "stats.num_drops",
+                className: "text-right",
+                width: "10%",
+                render: function (data, type) {
+                    if (type == "display") return NtopUtils.fint(data);
+                    return data;
+                }
+            },
+            {
+                data: "stats.fill_pct",
+                className: "text-right",
+                width: "5%",
+                render: function (data, type) {
+                    if (type == "display") return NtopUtils.fpercent(data);
+                    return data;
+                }
+            },
+            {
+                data: "check_categories",
+                className: "text-right",
+                width: "5%",
+                render: function (data, type) {
+                    if (data.length == 0)
+                        return `<i class='text-danger fas fa-exclamation-triangle'></i> ` + data.length;
+                    else
+                        return data.length;
+                }  
+            },
+            {
+                data: "minimum_severity",
+                className: "text-right text-nowrap",
+                width: "5%",
+                render: function (data, type) {
+                    const min_sev_key = SEVERITIES[data - 1];
+                    return `${i18n.endpoint_severities[min_sev_key]}`;
+                }  
+            },
+            {
+                data: "bind_to_pools",
+                className: "text-right text-nowrap",
+                width: "5%",
+                render: function (data, type) {
+                    if(data)
+                        return data + ` ${i18n.pools}`;
+                    else
+                        return `<i class='text-danger fas fa-exclamation-triangle'></i> 0 ` + `${i18n.pools}`;
+                }  
+            },
             {
                 targets: -1,
                 className: 'text-center',
                 data: null,
                 render: function (_, type, recipient) {
 
-                    if (!recipient.endpoint_conf) return;
+                    if (!recipient.endpoint_conf) return '';
 
                     const isBuiltin = (recipient.endpoint_conf && recipient.endpoint_conf.builtin) || false;
-                    if (isBuiltin) return;
 
                     return DataTableUtils.createActionButtons([
-                        {class: 'btn-info', icon: 'fa fa-users', modal: '#users-recipient-modal'},
-                        {class: 'btn-info', icon: 'fa-edit', modal: '#edit-recipient-modal' },
-                        {class: 'btn-danger', icon: 'fa-trash', modal: '#remove-recipient-modal'},
+                        { class: `btn-info ${isBuiltin ? 'disabled' : ''}`, icon: 'fa fa-users', modal: '#users-recipient-modal', title: `${i18n.recipient}` },
+                        { class: 'btn-info' /* Builtins are editable to change theis severity */, icon: 'fa-edit', modal: '#edit-recipient-modal', title: `${i18n.edit}` },
+                        { class: `btn-danger ${isBuiltin ? 'disabled' : ''}`, icon: 'fa-trash', modal: '#remove-recipient-modal', title: `${i18n.delete}` },
                     ]);
                 }
             }
@@ -225,6 +287,15 @@ $(document).ready(function () {
 
             const tableAPI = settings.oInstance.api();
 
+            // initialize add button tooltip
+            if (!CAN_CREATE_RECIPIENT) {
+                // wrap the button inside a span to show tooltip as request by the bootstrap framework
+                $(`#btn-add-recipient`).wrap(function() {
+                    return `<span id='suggest-tooltip' title='${i18n.createEndpointFirst}' class='d-inline-block' data-toggle='tooltip'></span>`;
+                });
+                $(`#suggest-tooltip`).tooltip();
+            }
+
             // when the data has been fetched check if the url has a recipient_id param
             // if the recipient is builtin then cancel the modal opening
             DataTableUtils.openEditModalByQuery({
@@ -235,18 +306,20 @@ $(document).ready(function () {
             });
 
             // reload data each TABLE_DATA_REFRESH milliseconds
-            setInterval(() => { tableAPI.ajax.reload();  }, TABLE_DATA_REFRESH);
+            setInterval(() => { tableAPI.ajax.reload(); }, TABLE_DATA_REFRESH);
         }
     });
 
     const $recipientsTable = $(`table#recipient-list`).DataTable(dtConfig);
+    DataTableUtils.addToggleColumnsDropdown($recipientsTable);
+
     const endpointTypeFilterMenu = new DataTableFiltersMenu({
         filterTitle: i18n.endpoint_type,
         filters: endpointTypeFilters,
         columnIndex: COLUMN_INDEX_ENDPOINT_TYPE,
         tableAPI: $recipientsTable,
         filterMenuKey: 'endpoint-type'
-    });
+    }).init();
 
     /* bind add endpoint event */
     $(`#add-recipient-modal form`).modalHandler({
@@ -320,10 +393,12 @@ $(document).ready(function () {
             /* load the values inside the template */
             $(`#edit-recipient-modal form [name='recipient_id']`).val(recipient.recipient_id || DEFAULT_RECIPIENT_ID);
             $(`#edit-recipient-modal form [name='recipient_name']`).val(recipient.recipient_name);
+	    if(recipient.endpoint_conf.builtin)
+		$(`#edit-recipient-modal form [name='recipient_name']`).attr('readonly', '');
             $(`#edit-recipient-modal form [name='endpoint_conf_name']`).val(recipient.endpoint_conf_name);
             $(`#edit-recipient-modal form [name='recipient_minimum_severity']`).val(recipient.minimum_severity);
-            $(`#edit-recipient-modal form [name='recipient_user_script_categories']`).val(recipient.user_script_categories);
-            $(`#edit-recipient-modal form [name='recipient_user_script_categories']`).selectpicker('refresh');
+            $(`#edit-recipient-modal form [name='recipient_check_categories']`).val(recipient.check_categories);
+            $(`#edit-recipient-modal form [name='recipient_check_categories']`).selectpicker('refresh');
             $(`#edit-recipient-modal form .recipient-template-container [name]`).each(function (i, input) {
                 $(this).val(recipient.recipient_params[$(this).attr('name')]);
             });
@@ -333,7 +408,7 @@ $(document).ready(function () {
                 const $self = $(this);
                 $self.attr("disabled");
                 const data = makeFormData(`#edit-recipient-modal form`);
-                data.endpoint_conf_name = recipient.endpoint_conf_name;
+                data.endpoint_id = recipient.endpoint_id;
                 testRecipient(data, $(this), $(`#edit-recipient-modal .test-feedback`)).then(() => {
                     $self.removeAttr("disabled");
                 });
@@ -375,12 +450,7 @@ $(document).ready(function () {
     /* bind edit recipient event */
     $(`table#recipient-list`).on('click', `a[href='#edit-recipient-modal']`, function (e) {
 
-        const selectedRecipient = $recipientsTable.row($(this).parent().parent()).data();
-        // prevent editing builtin
-        if (selectedRecipient.endpoint_conf.builtin) {
-            e.preventDefault();
-            return;
-        }
+        const selectedRecipient = $recipientsTable.row($(this).parent().parent().parent().parent()).data();
 
         $editRecipientModal.invokeModalInit(selectedRecipient);
     });
@@ -388,7 +458,7 @@ $(document).ready(function () {
     /* bind remove endpoint event */
     $(`table#recipient-list`).on('click', `a[href='#remove-recipient-modal']`, function (e) {
 
-        const selectedRecipient = $recipientsTable.row($(this).parent().parent()).data();
+        const selectedRecipient = $recipientsTable.row($(this).parent().parent().parent().parent()).data();
         // prevent removing builtin
         if (selectedRecipient.endpoint_conf.builtin) {
             e.preventDefault();
@@ -399,16 +469,16 @@ $(document).ready(function () {
     });
 
     /* bind recipient users button */
-    $(`table#recipient-list`).on('click', `a[href='#users-recipient-modal']`, async function() {
+    $(`table#recipient-list`).on('click', `a[href='#users-recipient-modal']`, async function () {
 
-        const {recipient_id, recipient_name} = $recipientsTable.row($(this).parent().parent()).data();
+        const { recipient_id, recipient_name } = $recipientsTable.row($(this).parent().parent().parent().parent()).data();
         $(`.recipient-name`).text(recipient_name);
         $(`.fetch-failed,.zero-user`).hide();
 
         try {
 
-            const response = await fetch(`${http_prefix}/lua/rest/v1/get/recipient/pools.lua?recipient_id=${recipient_id}`);
-            const {rsp} = await response.json();
+            const response = await fetch(`${http_prefix}/lua/rest/v2/get/recipient/pools.lua?recipient_id=${recipient_id}`);
+            const { rsp } = await response.json();
 
             // if there are no pools for the selected recipient shows a message
             if (rsp.length == 0) {
@@ -437,7 +507,7 @@ $(document).ready(function () {
             .then(() => { $self.removeAttr("disabled"); });
     });
 
-    $(`[name='recipient_user_script_categories']`).on('changed.bs.select', function(e, clickedIndex, isSelected, previousValue) {
+    $(`[name='recipient_check_categories']`).on('changed.bs.select', function (e, clickedIndex, isSelected, previousValue) {
 
         const lessThanOne = $(this).val().length < 1;
 
