@@ -3,7 +3,7 @@
  *
  * This script implements the logic for the overview tab inside snmpdevice_stats.lua page.
  */
-$(document).ready(function () {
+$(function () {
 
     // constant for filtering table
     const RESPONSIVE_COLUMN_INDEX = 0;
@@ -19,6 +19,12 @@ $(document).ready(function () {
         DEFAULT_POOL: 0
     };
 
+    const SNMP_VERSIONS = {
+        v1: 0,
+        v2c: 1,
+        v3: 2,
+    }
+
     // required fields for SNMPv3
     const requiredFields = {};
 
@@ -120,27 +126,47 @@ $(document).ready(function () {
         });
     }
 
+
+    function fillSNMPV3Fields(modalSelector, selectedSNMPDevice) {
+        if(selectedSNMPDevice.column_username)
+            $(`${modalSelector} input[name='snmp_username']`).val(selectedSNMPDevice.column_username);
+        if(selectedSNMPDevice.column_auth_protocol)
+            $(`${modalSelector} select[name='snmp_auth_protocol']`).val(selectedSNMPDevice.column_auth_protocol).change();
+        if(selectedSNMPDevice.column_auth_passphrase)    
+            $(`${modalSelector} input[name='snmp_auth_passphrase']`).val(selectedSNMPDevice.column_auth_passphrase);
+        if(selectedSNMPDevice.column_privacy_protocol)
+            $(`${modalSelector} select[name='snmp_privacy_protocol']`).val(selectedSNMPDevice.column_privacy_protocol).change();
+        if(selectedSNMPDevice.column_privacy_passphrase)
+            $(`${modalSelector} input[name='snmp_privacy_passphrase']`).val(selectedSNMPDevice.column_privacy_passphrase);        
+    }
+
+    function hideShowSNMPV3Fields(modalSelector, value) {
+        const usernameSelector = `${modalSelector} input[name='snmp_username']`;
+        const privacySelector = `${modalSelector} select[name='snmp_privacy_protocol'], ${modalSelector} input[name='snmp_privacy_passphrase']`;
+        const authSelector = `${modalSelector} input[name='snmp_auth_protocol'], ${modalSelector} select[name='snmp_auth_protocol']`;
+        
+        switch (value) {
+            case "authPriv":
+                $(`.auth-priv`).fadeIn(500);
+                $(`${privacySelector},${usernameSelector},${authSelector}`).removeAttr("disabled");
+                break;
+            case "noAuthNoPriv":
+                $(`.auth-priv`).fadeOut(500, () => { $(`.auth-no-priv`).fadeOut(500); });
+                $(`${authSelector},${privacySelector},${usernameSelector}`).attr("disabled", "disabled");
+                break;
+            case "authNoPriv":
+                $(`.auth-priv`).fadeOut(500);
+                $(`.auth-no-priv`).fadeIn(500);        
+                $(`${authSelector},${usernameSelector}`).removeAttr("disabled");
+                $(`${privacySelector}`).attr("disabled", "disabled");
+                break;
+        }
+    }
+
     function bindSNMPLevelSelect(modalSelector) {
 
         $(`${modalSelector} select[name='snmp_level']`).change(function(e) {
-
-            const usernameSelector = `${modalSelector} input[name='snmp_username']`;
-            const privacySelector = `${modalSelector} select[name='snmp_privacy_protocol'], ${modalSelector} input[name='snmp_privacy_passphrase']`;
-            const authSelector = `${modalSelector} input[name='snmp_auth_protocol'], ${modalSelector} select[name='snmp_auth_protocol']`;
-
-            switch ($(this).val()) {
-                case "authPriv":
-                    $(`${privacySelector},${usernameSelector},${authSelector}`).removeAttr("disabled");
-                    break;
-                case "noAuthNoPriv":
-                    $(`${authSelector},${privacySelector},${usernameSelector}`).attr("disabled", "disabled");
-                    break;
-                case "authNoPriv":
-                    $(`${authSelector},${usernameSelector}`).removeAttr("disabled");
-                    $(privacySelector).attr("disabled", "disabled");
-                    break;
-            }
-
+            hideShowSNMPV3Fields(modalSelector, $(this).val());
         });
     }
 
@@ -160,6 +186,7 @@ $(document).ready(function () {
                 $(`.community-field`).fadeOut(500, () => { $(`.non-community-field`).fadeIn(500); });
                 requiredFields[modalSelector]['community'].attr("disabled", "disabled");
                 requiredFields[modalSelector]['non-community'].removeAttr("disabled");
+                hideShowSNMPV3Fields(modalSelector, $(`${modalSelector} select[name='snmp_level']`).val());
                 return;
             }
 
@@ -168,7 +195,6 @@ $(document).ready(function () {
             $(`.non-community-field`).fadeOut(500, () => { $(`.community-field`).fadeIn(500); });
             requiredFields[modalSelector]['non-community'].attr("disabled", "disabled");
             requiredFields[modalSelector]['community'].removeAttr("disabled");
-
         });
     }
 
@@ -179,7 +205,7 @@ $(document).ready(function () {
 
             $(this).attr("disabled", true);
 
-            const request = await fetch(`${http_prefix}/lua/rest/v1/get/snmp/device/pools.lua`);
+            const request = await fetch(`${http_prefix}/lua/rest/v2/get/snmp/device/pools.lua`);
             const data = await request.json();
 
             if (data.rc < 0) {
@@ -232,7 +258,7 @@ $(document).ready(function () {
             }
         }
     ]);
-    dtConfig = DataTableUtils.setAjaxConfig(dtConfig, '/lua/pro/enterprise/get_snmp_devices_list.lua', 'data');
+    dtConfig = DataTableUtils.setAjaxConfig(dtConfig, http_prefix + '/lua/pro/enterprise/get_snmp_devices_list.lua', 'data');
     dtConfig = DataTableUtils.extendConfig(dtConfig, {
         orderFixed: { post: [[1, "asc"]] },
         columns: [
@@ -247,7 +273,7 @@ $(document).ready(function () {
 
                     if (type == "display" && row.column_device_status == "unreachable") {
                         return (`
-                            <span class='badge badge-warning' title='${i18n.snmp.snmp_device_does_not_respond}'>
+                            <span class='badge bg-warning' title='${i18n.snmp.snmp_device_does_not_respond}'>
                                 <i class="fas fa-exclamation-triangle"></i>
                             </span>
                             ${data}
@@ -257,6 +283,9 @@ $(document).ready(function () {
                     return data;
                 }
             },
+            {
+                data: "column_version",
+            },                
             {
                 data: "column_pool_name"
             },
@@ -296,8 +325,8 @@ $(document).ready(function () {
                     if (!isAdministrator) return "";
 
                     return DataTableUtils.createActionButtons([
-                        { class: 'btn-info', icon: 'fa-edit', modal: '#edit-snmp-device-modal' },
-                        { class: 'btn-danger', icon: 'fa-trash', modal: '#delete-snmp-device-modal'}
+                        { class: 'btn-info', icon: 'fa-edit', modal: '#edit-snmp-device-modal', title: `${i18n.edit}` },
+                        { class: 'btn-danger', icon: 'fa-trash', modal: '#delete-snmp-device-modal', title: `${i18n.delete}` }
                     ]);
                 }
             }
@@ -325,14 +354,16 @@ $(document).ready(function () {
 
     // initialize the DataTable with the created config
     const $snmpTable = $(`#table-devices`).DataTable(dtConfig);
-    addPoolFilters($snmpTable);
-    addResponsivenessFilter($snmpTable);
+    DataTableUtils.addToggleColumnsDropdown($snmpTable);
+
+    addPoolFilters($snmpTable).init();
+    addResponsivenessFilter($snmpTable).init();
 
     $(`#add-snmp-device-modal form`).modalHandler({
         method: 'post',
         csrf: addCsrf,
         resetAfterSubmit: false,
-        endpoint: `${ http_prefix }/lua/pro/rest/v1/add/snmp/device.lua`,
+        endpoint: `${ http_prefix }/lua/pro/rest/v2/add/snmp/device.lua`,
         beforeSumbit: () => {
             return buildDataRequest(`#add-snmp-device-modal`);
         },
@@ -359,7 +390,7 @@ $(document).ready(function () {
         method: 'post',
         csrf: addCsrf,
         resetAfterSubmit: false,
-        endpoint: `${ http_prefix }/lua/pro/rest/v1/edit/snmp/device/device.lua`,
+        endpoint: `${ http_prefix }/lua/pro/rest/v2/edit/snmp/device/device.lua`,
         beforeSumbit: (selectedSNMPDevice) => {
             const data = buildDataRequest('#edit-snmp-device-modal');
             data.snmp_host = selectedSNMPDevice.column_key;
@@ -368,11 +399,12 @@ $(document).ready(function () {
         onModalInit: (selectedSNMPDevice) => {
 
             // if the version is over SNMP_VERSION_THREE then bind it to the default one
-            const version = (selectedSNMPDevice.column_version > SNMP_VERSION_THREE) ? SNMP_DEFAULTS.VERSION : selectedSNMPDevice.column_version;
+            let version = (selectedSNMPDevice.column_version > "v3") ? "v1" : selectedSNMPDevice.column_version;
+            version = SNMP_VERSIONS[version]
 
             $(`#edit-snmp-device-modal input[name='snmp_read_community']`).val(selectedSNMPDevice.column_community);
 	        $(`#edit-snmp-device-modal input[name='snmp_write_community']`).val(selectedSNMPDevice.column_write_community);
-            $(`#edit-snmp-device-modal select[name='snmp_version']`).val(version);
+            $(`#edit-snmp-device-modal select[name='snmp_version']`).val(version).change();
             $(`#edit-snmp-device-modal select[name='pool']`).val(selectedSNMPDevice.column_pool_id);
             $(`#edit-snmp-device-modal .device-name`).text(selectedSNMPDevice.column_key);
 
@@ -386,6 +418,11 @@ $(document).ready(function () {
 
             // load the recipient lists inside the modal
             $(`#edit-snmp-device-modal select[name='pool']`).trigger('change');
+
+            if(version === SNMP_VERSION_THREE) {
+                hideShowSNMPV3Fields("#edit-snmp-device-modal", $(`#edit-snmp-device-modal select[name='snmp_level']`).val());
+                fillSNMPV3Fields("#edit-snmp-device-modal", selectedSNMPDevice);
+            }
         },
         onSubmitSuccess: (response, textStatus, modalHandler) => {
             onRequestSuccess(response, textStatus, modalHandler, '#edit-snmp-device-modal');
@@ -395,7 +432,7 @@ $(document).ready(function () {
     const $deleteModalHandler = $(`#delete-snmp-device-modal form`).modalHandler({
         method: 'post',
         csrf: deleteCsrf,
-        endpoint: `${ http_prefix }/lua/pro/rest/v1/delete/snmp/device.lua`,
+        endpoint: `${ http_prefix }/lua/pro/rest/v2/delete/snmp/device.lua`,
         resetAfterSubmit: false,
         onModalInit: function(selectedSNMPDevice) {
             $(`.delete-snmp-device-name`).text(selectedSNMPDevice.column_key);
@@ -416,12 +453,12 @@ $(document).ready(function () {
     });
 
     $(`#table-devices`).on('click', `a[href='#delete-snmp-device-modal']`, function (e) {
-        const selectedSNMPDevice = $snmpTable.row($(this).parent().parent()).data();
+        const selectedSNMPDevice = $snmpTable.row($(this).parent().parent().parent().parent()).data();
         $deleteModalHandler.invokeModalInit(selectedSNMPDevice);
     });
 
     $(`#table-devices`).on('click', `a[href='#edit-snmp-device-modal']`, function (e) {
-        const selectedSNMPDevice = $snmpTable.row($(this).parent().parent()).data();
+        const selectedSNMPDevice = $snmpTable.row($(this).parent().parent().parent().parent()).data();
         $editModalHandler.invokeModalInit(selectedSNMPDevice);
     });
 
