@@ -40,7 +40,7 @@
                 throw new Error("ModalHandler::The submit button was not found inside the form!");
             }
 
-            submitButton.attr("disabled", "disabled");
+            this.toggleFormSubmission();
 
         }
 
@@ -92,12 +92,12 @@
                 self.firstCloseAttempt = false;
                 $(self.element)[0].reportValidity();
                 $(self.dialog).find('.confirm-closing').fadeOut(100, function () {
-                    $(self.dialog).find('button.close').fadeIn(100);
+                    $(self.dialog).find('button.btn-close').fadeIn(100);
                 });
             });
 
             $(this.dialog).off('hide.bs.modal').on('hide.bs.modal', function (event) {
-
+                
                 if (self.isSubmitting) {
                     event.preventDefault();
                     return;
@@ -116,7 +116,7 @@
                 self.firstCloseAttempt = true;
 
                 // show an alert to inform the user
-                $(self.dialog).find('button.close').fadeOut(100, function () {
+                $(self.dialog).find('button.btn-close').fadeOut(100, function () {
                     $(self.dialog).find('.confirm-closing').fadeIn(100);
                 });
 
@@ -143,7 +143,7 @@
                 self.firstCloseAttempt = false;
 
                 $(self.dialog).find('.confirm-closing').fadeOut(100, function () {
-                    $(self.dialog).find('button.close').fadeIn(100);
+                    $(self.dialog).find('button.btn-close').fadeIn(100);
                 });
 
                 // clean the form when the modal is closed
@@ -221,7 +221,7 @@
                     // if the response was negative then alert the user
                     if (response.rc < 0) {
                         input.setCustomValidity(response.rc_str);
-                        return [false, i18n[response.rc_str]];
+                        return [false, response.rc_str_hr];
                     }
 
                     // return success for valid resolved hostnmae
@@ -244,11 +244,21 @@
                     }
 
                     if (input.validity.patternMismatch) {
-                        input.setCustomValidity("Invalid input.");
+                        input.setCustomValidity("Pattern mismatch.");
                         return [false, validation.data.validationMessage || i18n.invalid_field];
                     }
 
-                    // toggle validity to true
+                    if (input.validity.rangeOverflow) {
+                        input.setCustomValidity("Value exceed the maximum value.");
+                        return [false, validation.data.rangeOverflowMessage || i18n.invalid_field];
+                    }
+
+                    if (input.validity.rangeUnderflow) {
+                        input.setCustomValidity("Value is under the minimum value.");
+                        return [false, validation.data.rangeUnderflowMessage || i18n.invalid_field];
+                    }
+
+                    // set validation to true
                     input.setCustomValidity("");
                     return [true, "Success"];
                 }
@@ -260,9 +270,11 @@
                             validationMessage: $input.data('validationMessage'),
                             validationEmptyMessage: $input.data('validationEmptyMessage'),
                             cannotBeEmpty: ($input.attr('required') === "required") || ($input.data("validationNotEmpty") == true),
-                            resolveDNS: $input.data('validationResolvedns')
+                            resolveDNS: $input.data('validationResolvedns'),
+                            rangeOverflowMessage: $input.data('validationRangeOverflowMessage'),
+                            rangeUnderflowMessage: $input.data('validationUnderflowOverflowMessage'),
                         },
-                        isInputEmpty: (typeof($input.val()) == "string" ? $input.val().trim() == "" : false)
+                        isInputEmpty: (typeof($input.val()) === "string" ? $input.val().trim() == "" : false)
                     };
 
                     const [isValid, messageToShow] = await validInput(validation);
@@ -294,12 +306,12 @@
                     if (timeoutId != -1) clearTimeout(timeoutId);
 
                     if (!$input.attr("formnovalidate")) {
-                        // trigger input validation after 500msec
+                        // trigger input validation after 300msec
                         timeoutId = setTimeout(() => {
                             checkValidation();
                             // trigger form validation to enable the submit button
                             self.toggleFormSubmission();
-                        }, 500);
+                        }, 300);
                         // the user has changed the input, we can abort the first close attempt
                         self.firstCloseAttempt = false;
                     }
@@ -329,7 +341,6 @@
                 isValid &= input.validity.valid;
             });
 
-
             isValid
                 ? $(this.element).find(`[type='submit'],[type='test']`).removeAttr("disabled")
                 : $(this.element).find(`[type='submit'],[type='test']`).attr("disabled", "disabled");
@@ -356,53 +367,80 @@
             /* clean previous state and disable button */
             submitButton.attr("disabled", "disabled");
 
-            let request;
             const self = this;
 
-            if (self.options.method == "post") {
-                request = $.ajax({
-                    url: this.options.endpoint,
-                    data: JSON.stringify(dataToSend),
-                    method: self.options.method,
-                    dataType: "json",
-                    contentType: "application/json; charset=utf-8"
-                });
-            }
-            else {
-                request = $.get(this.options.endpoint, dataToSend);
-            }
+            if (this.options.endpoint) {
+                let request;
 
-            this.isSubmitting = true;
-
-            request.done(function (response, textStatus) {
-
-                // clear submitting state
-                self.isSubmitting = false;
-                // clear the current form state
-                self.currentState = null;
-
-                if (self.options.resetAfterSubmit) self.cleanForm();
-                self.options.onSubmitSuccess(response, dataToSend, self);
-
-                /* unbind the old closure on submit event and bind a new one */
-                $(self.element).off('submit', self.submitHandler);
-                self.delegateSubmit();
-
-                $feedbackLabel.hide();
-            })
-            .fail(function (jqxhr, textStatus, errorThrown) {
-
-                self.isSubmitting = false;
-                const response = jqxhr.responseJSON;
-                if (response.rc !== undefined && response.rc < 0) {
-                    $feedbackLabel.html(i18n.rest[response.rc_str]).show();
+                if (self.options.method == "post") {
+                    request = $.ajax({
+                        url: this.options.endpoint,
+                        data: JSON.stringify(dataToSend),
+                        method: self.options.method,
+                        dataType: "json",
+                        contentType: "application/json; charset=utf-8"
+                    });
+                }
+                else {
+                    request = $.get(this.options.endpoint, dataToSend);
                 }
 
-                self.options.onSubmitError(response, dataToSend, textStatus, errorThrown);
-            })
-            .always(function (d) {
-                submitButton.removeAttr("disabled");
-            });
+                this.isSubmitting = true;
+
+                request.done(function (response, textStatus) {
+
+                    // clear submitting state
+                    self.isSubmitting = false;
+                    // clear the current form state
+                    self.currentState = null;
+
+                    if (self.options.resetAfterSubmit) self.cleanForm();
+                    $feedbackLabel.hide();
+
+                    const success = self.options.onSubmitSuccess(response, dataToSend, self);
+                    // if the submit return a true boolean then close the modal
+                    if (success) {
+                        self.dialog.modal('hide');
+                    }
+
+                    /* unbind the old closure on submit event and bind a new one */
+                    $(self.element).off('submit', self.submitHandler);
+                    self.delegateSubmit();
+                })
+                .fail(function (jqxhr, textStatus, errorThrown) {
+
+                    self.isSubmitting = false;
+                    const response = jqxhr.responseJSON;
+                    if (response.rc !== undefined && response.rc < 0) {
+                        $feedbackLabel.html(response.rc_str_hr).show();
+                    }
+
+                    self.options.onSubmitError(response, dataToSend, textStatus, errorThrown);
+                })
+                .always(function (d) {
+                    submitButton.removeAttr("disabled");
+                });
+
+            } else { // no endpoint
+
+                    // clear the current form state
+                    self.currentState = null;
+
+                    //if (self.options.resetAfterSubmit) self.cleanForm();
+                    $feedbackLabel.hide();
+
+                    const success = self.options.onSubmitSuccess({}, dataToSend, self);
+                    // if the submit return a true boolean then close the modal
+                    if (success) {
+                        self.dialog.modal('hide');
+                    }
+
+                    /* unbind the old closure on submit event and bind a new one */
+                    $(self.element).off('submit', self.submitHandler);
+                    self.delegateSubmit();
+
+                    submitButton.removeAttr("disabled");
+            }
         }
 
         delegateResetButton() {
