@@ -1,5 +1,5 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 --
@@ -16,12 +16,14 @@ local recovery_utils = require "recovery_utils"
 require "lua_utils" -- NOTE: required by alert_utils
 local alert_utils = require "alert_utils"
 local recipients = require "recipients"
-local user_scripts = require "user_scripts"
+local checks = require "checks"
 local periodicity = 3
 
 local now = os.time()
 local ifnames = interface.getIfNames()
 
+-- io.write("shutdown.lua ["..os.time().."]\n")
+
 alert_utils.notify_ntopng_stop()
 
 -- Check and possibly dump preferences to disk
@@ -34,7 +36,7 @@ end
 
 recipients.process_notifications(now, now + 3 --[[ deadline ]], 3 --[[ periodicity ]], true)
 
--- Unload all user scripts
-user_scripts.loadUnloadUserScripts(false --[[ unload --]])
+-- Unload all checks
+checks.loadUnloadUserScripts(false --[[ unload --]])
 
 recovery_utils.mark_clean_shutdown()
