@@ -1,5 +1,5 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 --
@@ -9,11 +9,6 @@
 local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
-if(ntop.isPro()) then
-   package.path = dirs.installdir .. "/pro/scripts/callbacks/system/?.lua;" .. package.path
-   require("startup")
-end
-
 require "lua_utils"
 
 -- Important: load this before any other alert related module
@@ -32,10 +27,36 @@ local lists_utils = require "lists_utils"
 local recovery_utils = require "recovery_utils"
 local delete_data_utils = require "delete_data_utils"
 local ts_utils = require "ts_utils"
-local user_scripts = require("user_scripts")
 local presets_utils = require "presets_utils"
-local prefs = ntop.getPrefs()
-local notification_configs = require "notification_configs"
+local blog_utils = require("blog_utils")
+
+-- ##################################################################
+
+traceError(TRACE_NORMAL, TRACE_CONSOLE, "Processing startup.lua: please hold on...")
+
+if ntop.isPro() then
+   package.path = dirs.installdir .. "/pro/scripts/callbacks/system/?.lua;" .. package.path
+   require("startup")
+end
+
+-- ##################################################################
+
+if ntop.isAppliance() then
+   package.path = dirs.installdir .. "/scripts/lua/modules/system_config/?.lua;" .. package.path
+
+   -- Discard any pending, unfinished, unsaved configuration
+   local appliance_config = require("appliance_config"):create(true):discard()
+
+   -- Load the actual valid configuration
+   appliance_config = require("appliance_config"):create(false)
+
+   -- Apply some config prefs
+   local vlan_trunk = appliance_config:isBridgeOverVLANTrunkEnabled()
+   ntop.setPref("ntopng.prefs.enable_vlan_trunk_bridge", ternary(vlan_trunk, "1", "0"))
+
+   -- Load possibly changed prefs
+   ntop.reloadPreferences()
+end
 
 host_pools_nedge.migrateHostPools()
 if ntop.isnEdge() then
@@ -47,50 +68,11 @@ if(ntop.isPro()) then
    shaper_utils.initShapers()
 end
 
-traceError(TRACE_NORMAL, TRACE_CONSOLE, "Processing startup.lua: please hold on...")
-
--- ##################################################################
-
--- Load the default user scripts configuration
-user_scripts.loadDefaultConfig()
-
--- Use a specific bridging_policy_target_type default for previous user installations
-if isEmptyString(ntop.getPref("ntopng.prefs.bridging_policy_target_type")) then
-   for _, ifname in pairs(interface.getIfNames()) do
-      local ifid = getInterfaceId(ifname)
-      interface.select(ifname)
-
-      local stats = interface.getStats()
-      if stats.inline then
-         -- Override the default
-         ntop.setPref("ntopng.prefs.bridging_policy_target_type", "both")
-         break
-      end
-   end
-end
-
--- ##################################################################
-
--- Migration from old ntop auth_type to new separeted keys
-local old_auth_val = ntop.getPref("ntopng.prefs.auth_type")
-local new_local_auth = ntop.getPref("ntopng.prefs.local.auth_enabled")
-local new_ldap_auth = ntop.getPref("ntopng.prefs.ldap.auth_enabled")
-
-if((not isEmptyString(old_auth_val)) and isEmptyString(new_ldap_auth) and isEmptyString(new_local_auth)) then
-   if old_auth_val == "ldap" then
-      ntop.setPref("ntopng.prefs.local.auth_enabled", "0")
-      ntop.setPref("ntopng.prefs.ldap.auth_enabled", "1")
-   elseif old_auth_val == "ldap_local" then
-      ntop.setPref("ntopng.prefs.local.auth_enabled", "1")
-      ntop.setPref("ntopng.prefs.ldap.auth_enabled", "1")
-   end
-end
-
 -- ##################################################################
 
 local has_pcap_dump_interface = false
 
-local function cleanupIfname(ifname)
+local function cleanupIfname(ifname, ifid)
    interface.select(ifname)
    local ifid = getInterfaceId(ifname)
 
@@ -114,23 +96,17 @@ local function cleanupIfname(ifname)
 end
 
 -- Remove the json dumps previously needed for alerts generation
-for _, ifname in pairs(interface.getIfNames()) do
-   cleanupIfname(ifname)
+for ifid, ifname in pairs(interface.getIfNames()) do
+   cleanupIfname(ifname, ifid)
 end
-cleanupIfname(getSystemInterfaceName())
+
+cleanupIfname(getSystemInterfaceName(), getSystemInterfaceId())
 
 -- Also flush the export queue
 ntop.delCache("ntopng.influx_file_queue")
 
 -- ##################################################################
 
--- Check remote assistance expiration
-local remote_assistance = require "remote_assistance"
-remote_assistance.checkAvailable()
-remote_assistance.checkExpiration()
-
--- ##################################################################
-
 local recording_utils = require "recording_utils"
 recording_utils.checkAvailable()
 
@@ -163,7 +139,6 @@ alert_utils.notify_ntopng_start()
 
 if not recovery_utils.check_clean_shutdown() then
    package.path = dirs.installdir .. "/scripts/callbacks/system/?.lua;" .. package.path
-   require("recovery")
 end
 
 recovery_utils.unmark_clean_shutdown()
@@ -215,4 +190,13 @@ if(ntop.exists(local_startup_file)) then
    dofile(local_startup_file)
 end
 
-traceError(TRACE_NORMAL, TRACE_CONSOLE, "Startup completed: ntopng is now operational")
+if(ntop.isPro()) then
+   -- Import ClickHouse dumps if any
+   local silence_import_warnings = true
+
+   ntop.importClickHouseDumps(silence_import_warnings)
+end
+
+blog_utils.fetchLatestPosts()
+
+traceError(TRACE_NORMAL, TRACE_CONSOLE, "Completed startup.lua")
