@@ -24,14 +24,6 @@
 --!  @ingroup Script
 ---------------------------------
 
-
---! @memberof interface
---! @brief Get the default network interface name.
---! @details For more information please read the @ref ntop_get_default_interface_name documentation.
---! @return {string} The default network interface name of ntopng.
-function getDefaultIfName()
-
-
 --! @memberof interface
 --! @brief Sets the network interface name identified by Id as active one on which to perform operations.
 --! @details For more information please read the @ref ntop_set_active_interface_id documentation.
@@ -110,10 +102,11 @@ function getFlowsInfo()
 
 --! @memberof interface
 --! @brief Get the flow peers information identified by key of network interface.
---! @details For more information please read the @ref ntop_get_interface_find_flow_by_key documentation.
+--! @details For more information please read the @ref ntop_get_interface_find_flow_by_key_and_hash_id documentation.
 --! @tparam number key The flow key.
+--! @tparam number hash_id The flow id in the flows hash table.
 --! @return An hashtable containing the flow information identified by the key parameter of network interface if it exists.
-function findFlowByKey(key)
+function findFlowByKeyAndHashId(key, hash_id)
 
 --! @memberof interface
 --! @brief Get the host identified by key of network interface.
