@@ -1,5 +1,5 @@
 --
--- (C) 2019-20 - ntop.org
+-- (C) 2019-22 - ntop.org
 --
 local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
@@ -13,7 +13,7 @@ local page_utils = require "page_utils"
 
 sendHTTPContentTypeHeader('text/html')
 
-if not haveAdminPrivileges() then
+if not isAdministratorOrPrintErr() then
    return
 end
 
@@ -201,14 +201,14 @@ elseif (_POST["member"] ~= nil) and (_POST["pool"] ~= nil) then
 end
 
 function printPoolNameField(pool_id_str)
-   print[[<div class="form-group has-feedback" style="margin-bottom:0;">]]
+   print[[<div class="form-group mb-3 has-feedback" style="margin-bottom:0;">]]
    print[[<input name="pool_' + ]] print(pool_id_str) print[[ + '" class="form-control" spellcheck="false" data-unique="unique" placeholder="]] print(i18n("host_pools.specify_pool_name")) print[[" required/>]]
    print[[<div class="help-block with-errors" style="margin-bottom:0;"></div>]]
    print[[</div>]]
 end
 
 function printMemberAddressField(member_str, origin_value_str)
-   print[[<div class="form-group has-feedback" style="margin-bottom:0;">]]
+   print[[<div class="form-group mb-3 has-feedback" style="margin-bottom:0;">]]
    print[[<input name="member_' + ]] print(member_str) print[[ + '" class="form-control" spellcheck="false" data-address="address" data-member="member" placeholder="]] print(i18n("host_pools.specify_member_address")) print[["]]
    if not isEmptyString(origin_value_str) then
       print[[ data-origin-value="' + ]] print(origin_value_str) print[[ + '"]]
@@ -219,8 +219,8 @@ function printMemberAddressField(member_str, origin_value_str)
 end
 
 function printMemberVlanField(member_str)
-   print[[<div class="form-group has-feedback" style="margin-bottom:0;">]]
-   print[[<input name="member_' + ]] print(member_str) print[[ + '_vlan" class="form-control text-right" data-member="member" style="width:5em; padding-right:1em; margin: 0 auto;" type="number" min="0" value="0" required/>]]
+   print[[<div class="form-group mb-3 has-feedback" style="margin-bottom:0;">]]
+   print[[<input name="member_' + ]] print(member_str) print[[ + '_vlan" class="form-control text-end" data-member="member" style="width:5em; padding-right:1em; margin: 0 auto;" type="number" min="0" value="0" required/>]]
    print[[<div class="help-block with-errors" style="margin-bottom:0;"></div>]]
    print[[</div>]]
 end
@@ -268,15 +268,15 @@ local ifstats = interface.getStats()
 print [[
 
   <ul id="hostPoolsNav" class="nav nav-tabs" role="tablist">
-    <li class="nav-item"><a class="nav-link" data-toggle="tab" role="tab" href="#manage">]] print(i18n("host_pools.manage_pools")) print[[</a></li>
-    <li class="nav-item"><a class="nav-link" data-toggle="tab" role="tab" href="#create">]] print(i18n("host_pools.create_pools")) print[[</a></li>
+    <li class="nav-item"><a class="nav-link" data-bs-toggle="tab" role="tab" href="#manage">]] print(i18n("host_pools.manage_pools")) print[[</a></li>
+    <li class="nav-item"><a class="nav-link" data-bs-toggle="tab" role="tab" href="#create">]] print(i18n("host_pools.create_pools")) print[[</a></li>
   </ul>
   <div class="tab-content">
     <div id="manage" class="tab-pane">
 <br/><table><tbody><tr>
 ]]
 
-print('<td style="white-space:nowrap; padding-right:1em;">') print(i18n("host_pools.pool")) print(': <select id="pool_selector" class="form-control pool-selector" style="display:inline; width:14em;" onchange="document.location.href=\'?ifid=') print(ifId.."") print('&page=pools&pool=\' + $(this).val() + \'#manage\';">')
+print('<td style="white-space:nowrap; padding-right:1em;">') print(i18n("host_pools.pool")) print(': <select id="pool_selector" class="form-select pool-selector" style="display:inline; width:14em;" onchange="document.location.href=\'?ifid=') print(ifId.."") print('&page=pools&pool=\' + $(this).val() + \'#manage\';">')
 print(graph_utils.poolDropdown(ifId, selected_pool.id, {[host_pools_utils.DEFAULT_POOL_ID]=true}))
 print('</select>')
 
@@ -341,9 +341,8 @@ end
 for _, msg in ipairs(pool_add_warnings) do
    print([[
   <div class="alert alert-warning alert-dismissible" style="margin-top:2em; margin-bottom:0em;">
-    <button type="button" class="close" data-dismiss="alert" aria-label="]]..i18n("close")..[[">
-      <span aria-hidden="true">&times;</span>
-    </button><b>]]..i18n("warning")..[[</b>: ]]..msg..[[
+    <b>]]..i18n("warning")..[[</b>: ]]..msg..[[
+	<button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
   </div>]])
 end
 
@@ -377,12 +376,12 @@ print[[
       </form>
 
       <div style="float:left">
-	<form action="/lua/rest/v1/get/pool/config.lua" class="form-inline" method="GET" data-ays-ignore="true">
+	<form action="/lua/rest/v2/get/pool/config.lua" class="form-inline" method="GET" data-ays-ignore="true">
 	  <input type="hidden" name="ifid" value="]] print(tostring(ifId)) print[[" />
 	  <input type="hidden" name="download" value="true" />
 	  <button type="submit" class="btn btn-secondary"><span>]] print(i18n("host_pools.config_export")) print[[</span></button>
 	</form>
-	<button id="import-modal-btn" data-toggle="modal" data-target="#import-modal" class="btn btn-secondary"><span>]] print(i18n("host_pools.config_import")) print[[</span></button>
+	<button id="import-modal-btn" data-bs-toggle="modal" data-target="#import-modal" class="btn btn-secondary"><span>]] print(i18n("host_pools.config_import")) print[[</span></button>
       </div>
 
       <br/><br/>]]
@@ -458,7 +457,7 @@ print(
 		      action  = "changeMemberPool(change_member_id)",
 		      title   = i18n("host_pools.change_member_pool"),
 		      message = i18n("host_pools.select_new_pool", {member='<span id="change_member_pool_dialog_member"></span>'}) ..
-			 '<br><br><select class="form-control" id="changed_host_pool" style="width:15em;">'..
+			 '<br><br><select class="form-select" id="changed_host_pool" style="width:15em;">'..
 			 graph_utils.poolDropdown(ifId, "", {[selected_pool.id]=true, [host_pools_utils.DEFAULT_POOL_ID]=true})..
 			 '</select>',
 		      custom_alert_class = "",
@@ -520,7 +519,7 @@ print[[
 			$button.removeAttr("disabled");
 		    } else {
 			// Submit configuration file
-			$.post(`${http_prefix}/lua/rest/v1/set/pool/config.lua`, {
+			$.post(`${http_prefix}/lua/rest/v2/set/pool/config.lua`, {
 			    csrf: import_csrf,
 			    JSON: JSON.stringify(json_conf)
 			})
@@ -791,7 +790,7 @@ print [[/lua/get_host_pools.lua?ifid=]] print(ifId.."") print[[&pool=]] print(se
       hidePerPage: true,
 
       buttons: [
-	 '<a id="addPoolMemberBtn" onclick="addPoolMember()" role="button" class="add-on btn" data-toggle="modal"><i class="fas fa-plus" aria-hidden="true"></i></a>'
+	 '<a id="addPoolMemberBtn" onclick="addPoolMember()" role="button" class="add-on btn" data-bs-toggle="modal"><i class="fas fa-plus" aria-hidden="true"></i></a>'
       ], columns: [
 	 {
 	    title: "]] print(i18n("host_pools.member_address")) print[[",
@@ -1082,7 +1081,7 @@ print [[/lua/get_host_pools.lua?ifid=]] print(ifId.."") print[[",
       perPage: ]] print(perPagePools) print[[,
 
       buttons: [
-	 '<a id="addNewPoolBtn" onclick="addPool()" role="button" class="add-on btn" data-toggle="modal"><i class="fas fa-plus" aria-hidden="true"></i></a>'
+	 '<a id="addNewPoolBtn" onclick="addPool()" role="button" class="add-on btn" data-bs-toggle="modal"><i class="fas fa-plus" aria-hidden="true"></i></a>'
       ], columns: [
 	 {
 	    field: "column_pool_id",
