@@ -11,7 +11,7 @@ local page_utils = require("page_utils")
 sendHTTPContentTypeHeader('text/html')
 
 
-if(haveAdminPrivileges()) then
+if(isAdministratorOrPrintErr()) then
    interface.select(ifname)
 
    page_utils.set_active_menu_entry(page_utils.menu_entries.manage_users)
