@@ -1,12 +1,11 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 require "lua_utils"
 local alert_consts = require("alert_consts")
-local flow_consts = require("flow_consts")
 local page_utils = require("page_utils")
 local template = require "template_utils"
 
@@ -19,10 +18,9 @@ dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 local context = {
    page_utils = page_utils,
    alert_consts = alert_consts,
-   flow_consts = flow_consts,
 }
 
-print(template.gen("defs_list.html", context))
+print(template.gen("pages/alerts/defs_overview.template", context))
 
 dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
 
