@@ -1,5 +1,5 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -7,6 +7,7 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 local json  = require "dkjson"
+local stats_utils = require("stats_utils")
 
 sendHTTPContentTypeHeader('text/html')
 
@@ -22,7 +23,7 @@ local what = {}
 local res = {}
 
 if(host == nil) then
-   print("<div class=\"alert alert-danger\"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png> This flow cannot be found (expired ?)</div>")
+   print("<div class=\"alert alert-danger\"><i class='fas fa-exclamation-triangle fa-lg fa-ntopng-warning'></i> This flow cannot be found (expired ?)</div>")
 else
 
    if((type == nil) or (type == "size")) then
@@ -33,24 +34,11 @@ else
       end
    end
 
-   local tot = 0
    for key, value in pairs(what) do
-      tot = tot + value
-   end
-
-   local threshold = (5 * tot) / 100
-
-   local s = 0
-   for key, value in pairs(what) do
-      if(value > threshold) then
-	 res[#res + 1] = {label = key, value = value}
-	 s = s + value
-      end
-   end
-
-   if tot > s then
-      res[#res + 1] = {label = "Other", value = (tot - s)}
+      res[#res + 1] = {label = key, value = value}
    end
 end
 
-print(json.encode(res))
+local collapsed = stats_utils.collapse_stats(res, 1, 5 --[[ threshold ]])
+
+print(json.encode(collapsed))
