@@ -1,35 +1,21 @@
 --
--- (C) 2013-18 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
-dirs = ntop.getDirs()
+local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
+local json = require "dkjson"
+local stats_utils = require("stats_utils")
 
 sendHTTPContentTypeHeader('text/html')
 
-interface.select(ifname)
-host_info = url2hostinfo(_GET)
+local host_info = url2hostinfo(_GET)
+local ifid = _GET["ifid"]
+local what = {}
 
-if(host_info["host"] ~= nil) then
-   local stats = interface.getHostInfo(host_info["host"],host_info["vlan"])
-   if stats == nil then return end
-
-   -- join sent and rcvd
-   local sent_stats = stats["pktStats.sent"]
-   local rcvd_stats = stats["pktStats.recv"]
-   what = {}
-
-   for k, _ in pairs(sent_stats) do
-      what[k] = sent_stats[k] + rcvd_stats[k]
-   end
-else
-   local stats = interface.getStats()
-   if stats == nil then return end
-
-   what = stats["pktSizeDistribution"]
-end
+interface.select(ifid)
 
 local pkt_distribution = {
    ['syn'] = 'SYN',
@@ -38,22 +24,35 @@ local pkt_distribution = {
    ['rst'] = 'RST',
 }
 
-print "[\n"
-num = 0
+if(host_info["host"] ~= nil) then
+   local stats = interface.getHostInfo(host_info["host"],host_info["vlan"])
+   if stats == nil then return end
+
+   -- join sent and rcvd
+   local sent_stats = stats["pktStats.sent"]["tcp_flags"]
+   local rcvd_stats = stats["pktStats.recv"]["tcp_flags"]
+
+   for k, _ in pairs(sent_stats) do
+      what[k] = sent_stats[k] + rcvd_stats[k]
+   end
+else
+   local stats = interface.getStats()
+   if stats == nil then return end
+
+   what = stats["pktSizeDistribution"]["tcp_flags"]
+end
+
+local res = {}
 for key, value in pairs(what) do
-   if(pkt_distribution[key] ~= nil) then
-      if(num > 0) then
-	 print ",\n"
-      end
-            
-      print("\t { \"label\": \"" .. pkt_distribution[key] .."\", \"value\": ".. value .." }") 
-      num = num + 1
+   if value > 0 then
+      res[#res + 1] = {label = pkt_distribution[key], value = value}
    end
 end
 
-if(num == 0) then
-   print("\t, { \"label\": \"Other\", \"value\": 100 }") 
+if table.len(res) == 0 then
+   res[#res + 1] = {label = "Other", value = 100}
+else
+   res = stats_utils.collapse_stats(res, 1, 1 --[[ threshold ]])
 end
 
-print "\n]"
-
+print(json.encode(res))
