@@ -7,13 +7,11 @@ local template = require("template_utils")
 print [[
 
 <div id="password_dialog" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="password_dialog_label" aria-hidden="true">
-  <div class="modal-dialog">
+  <div class="modal-dialog modal-lg">
     <div class="modal-content">
       <div class="modal-header">
-        <h5 class="modal-title" id="password_dialog_label">]] print(i18n("manage_users.manage_user_x", {user=[[<span class="password_dialog_title"></span>]]})) print[[ </h5>
-        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">
-          <span aria-hidden="true">&times;</span>
-        </button>
+        <h5 class="modal-title" id="password_dialog_label">]] print(i18n("manage_users.manage_user_x", {user=[[<span class="password_dialog_title">]].. _SESSION['user'] ..[[</span>]]})) print[[ </h5>
+        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
       </div>
 
 <div class="modal-body">
@@ -22,27 +20,28 @@ print [[
   <div class='card'>
   <div class='card-header'>
   <ul class="nav nav-tabs card-header-tabs" role="tablist" id="edit-user-container">
-    <li class="nav-item active"><a class="nav-link active" href="#change-password-dialog" role="tab" data-toggle="tab"> ]] print(i18n("login.password")) print[[ </a></li>
 ]]
-
-if(is_admin) then
-   print[[<li class="nav-item" id="li_change_prefs"><a class="nav-link" href="#change-prefs-dialog" role="tab" data-toggle="tab"> ]] print(i18n("prefs.preferences")) print[[ </a></li>]]
-end
+    if(is_admin) then
+      print[[<li class="nav-item active" id="li_change_prefs"><a class="nav-link active" href="#change-prefs-dialog" role="tab" data-bs-toggle="tab"> ]] print(i18n("prefs.preferences")) print[[ </a></li>]]
+    end
    print[[
+    <li class="nav-item ]] print(ternary(is_admin, "", "active")) print[["><a class="nav-link ]] print(ternary(is_admin, "", "active")) print[[" href="#change-password-dialog" role="tab" data-bs-toggle="tab"> ]] print(i18n("login.password")) print[[ </a></li>
+    <li class="nav-item"><a class="nav-link" href="#user-token-tab" role="tab" data-bs-toggle="tab"> ]] print(i18n("login.auth_token")) print[[ </a></li>
+  
   </ul>
   </div>
   <div class="card-body tab-content">
-  <div class="tab-pane active" id="change-password-dialog">
+  <div class="tab-pane ]] print(ternary(is_admin, "", "active")) print[[" id="change-password-dialog">
 
   <div id="password_alert_placeholder"></div>
 
 <script>
   password_alert = function() {}
-  password_alert.error   = function(message) { $('#password_alert_placeholder').html('<div class="alert alert-danger"><button type="button" class="close" data-dismiss="alert">x</button>' + message + '</div>');  }
-  password_alert.success = function(message) { $('#password_alert_placeholder').html('<div class="alert alert-success"><button type="button" class="close" data-dismiss="alert">x</button>' + message + '</div>'); }
+  password_alert.error   = function(message) { $('#password_alert_placeholder').html('<div class="alert alert-danger alert-dismissable">' + message + '<button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button></div>');  }
+  password_alert.success = function(message) { $('#password_alert_placeholder').html('<div class="alert alert-success alert-dismissable">' + message + '<button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button></div>'); }
 </script>
 
-  <form data-toggle="validator" id="form_password_reset" method="post" action="]] print(ntop.getHttpPrefix()) print[[/lua/admin/password_reset.lua" accept-charset="UTF-8">
+  <form data-bs-toggle="validator" id="form_password_reset" method="post" action="]] print(ntop.getHttpPrefix()) print[[/lua/admin/password_reset.lua" accept-charset="UTF-8">
 ]]
 
    print('<input name="csrf" type="hidden" value="'..ntop.getRandomCSRFValue()..'" />\n')
@@ -58,12 +57,10 @@ local col_md_size = "6"
 if(not is_admin) then
    col_md_size = "4"
 print [[
-  <div class='form-group'>
-  <label for="old_password_input">]] print(i18n("manage_users.old_password")) print[[</label>
+  <div class='form-group mb-3'>
+  <label class='form-label' for="old_password_input">]] print(i18n("manage_users.old_password")) print[[</label>
   <div class='input-group mb-]] print(col_md_size) print[[ has-feedback'>
-      <div class="input-group-prepend">
         <span class="input-group-text"><i class="fas fa-lock"></i></span>
-      </div>
       <input id="old_password_input" type="password" name="old_password" value="" class="form-control" required>
   </div>
   </div>
@@ -71,22 +68,18 @@ print [[
 end
 
 print [[
-  <div class='form-group'>
-    <label for="new_password_input">]] print(i18n("manage_users.new_password")) print[[</label>
+  <div class='form-group mb-3'>
+    <label class='form-label' for="new_password_input">]] print(i18n("manage_users.new_password")) print[[</label>
     <div class='input-group mb-]] print(col_md_size) print[['>
-        <div class="input-group-prepend"><span class="input-group-text">
-          <i class="fas fa-lock"></i></span>
-        </div>
+        <span class="input-group-text"><i class="fas fa-lock"></i></span>
         <input id="new_password_input" type="password" name="new_password" value="" class="form-control" pattern="]] print(getPasswordInputPattern()) print[[" required>
     </div>
   </div>
 
-  <div class='form-group'>
-  <label for="confirm_new_password_input">]] print(i18n("manage_users.new_password_confirm")) print[[</label>
+  <div class='form-group mb-3'>
+  <label class='form-label' class='form-label' for="confirm_new_password_input">]] print(i18n("manage_users.new_password_confirm")) print[[</label>
   <div class='input-group md-]] print(col_md_size) print[['>
-      <div class="input-group-prepend">
         <span class="input-group-text"><i class="fas fa-lock"></i></span>
-      </div>
         <input id="confirm_new_password_input" type="password" name="confirm_password" value="" class="form-control" pattern="]] print(getPasswordInputPattern()) print[[" required>
   </div>
   </div>
@@ -94,9 +87,9 @@ print [[
 
 <div><small>]] print(i18n("manage_users.allowed_passwd_charset")) print[[.  </small></div>
 
-<br>
+<hr>
 
-    <div class="has-feedback text-right">
+    <div class="has-feedback text-end">
       <button id="password_reset_submit" class="btn btn-primary">]] print(i18n("manage_users.change_user_password")) print[[</button>
     </div>
 
@@ -107,17 +100,17 @@ print [[
 if(is_admin) then
 
 print [[
-</div>
-<div class="tab-pane" id="change-prefs-dialog">
+  </div>
+<div class="tab-pane ]] print(ternary(is_admin, "active", "")) print[[" id="change-prefs-dialog">
 
-  <form data-toggle="validator" id="form_pref_change" method="post" action="]] print(ntop.getHttpPrefix()) print[[/lua/admin/change_user_prefs.lua">
+  <form data-bs-toggle="validator" id="form_pref_change" method="post" action="]] print(ntop.getHttpPrefix()) print[[/lua/admin/change_user_prefs.lua">
     <input name="csrf" type="hidden" value="]] print(ntop.getRandomCSRFValue()) print[[" />
   <input id="pref_dialog_username" type="hidden" name="username" value="" />
 
-  <div class='form-group'>
-  <label for="host_role_select">]] print(i18n("manage_users.user_role")) print[[</label>
+  <div class='form-group mb-3'>
+  <label class='form-label' for="host_role_select">]] print(i18n("manage_users.user_role")) print[[</label>
   <div class='input-group mb-6'>
-        <select id="host_role_select" name="user_role" class="form-control">
+        <select id="host_role_select" name="user_role" class="form-select">
           <option value="unprivileged">]] print(i18n("manage_users.non_privileged_user")) print[[</option>
           <option value="administrator">]] print(i18n("manage_users.administrator")) print[[</option>
         </select>
@@ -126,10 +119,10 @@ print [[
 
   <div id="unprivileged_manage_input">
 
-  <div class='form-group'>
-  <label for="allowed_interface">]] print(i18n("manage_users.allowed_interface")) print[[</label>
+  <div class='form-group mb-3'>
+  <label class='form-label' for="allowed_interface">]] print(i18n("manage_users.allowed_interface")) print[[</label>
   <div class='input-group mb-6'>
-        <select name="allowed_interface" id="allowed_interface" class="form-control">
+        <select name="allowed_interface" id="allowed_interface" class="form-select">
           <option value="">]] print(i18n("manage_users.any_interface")) print[[</option>
 ]]
    for _, interface_name in pairsByValues(interface.getIfNames(), asc) do
@@ -141,17 +134,17 @@ print [[
   </div>
   </div>
 
-  <div class='form-group'>
-    <label for="networks_input">]] print(i18n("manage_users.allowed_networks")) print[[</label>
+  <div class='form-group mb-3'>
+    <label class='form-label' for="networks_input">]] print(i18n("manage_users.allowed_networks")) print[[</label>
     <div class='input-group mb-6'>
-      <input id="networks_input" type="text" name="allowed_networks" value="" class="form-control" required>
-      <small>]] print(i18n("manage_users.allowed_networks_descr")) print[[ 192.168.1.0/24,172.16.0.0/16</small>
+      <input id="networks_input" type="text" name="allowed_networks" value="" class="form-control w-100" required>
     </div>
+    <small>]] print(i18n("manage_users.allowed_networks_descr")) print[[ 192.168.1.0/24,172.16.0.0/16</small>
   </div>
 
 
-    <div class="form-group mb-6">
-      <div class="form-check">]]
+    <div class="form-group mb-3 mb-6">
+      <div class="form-check pl-0">]]
 
     print(template.gen("on_off_switch.html", {
      id = "allow_pcap_download",
@@ -177,13 +170,11 @@ print [[
 ]]
 
 print[[
-  <div class='form-group'>
-    <label for="user_language">]] print(i18n("language")) print[[</label>
+  <div class='form-group mb-3'>
+    <label class='form-label' for="user_language">]] print(i18n("language")) print[[</label>
     <div class='input-group mb-6'>
-      <div class="input-group-prepend">
         <span class="input-group-text"><i class="fas fa-language" aria-hidden="true"></i></span>
-      </div>
-      <select name="user_language" id="user_language" class="form-control">]]
+      <select name="user_language" id="user_language" class="form-select">]]
 
 for _, lang in ipairs(locales_utils.getAvailableLocales()) do
    print('<option value="'..lang["code"]..'">'..i18n("locales." .. lang["code"])..'</option>')
@@ -195,7 +186,8 @@ print[[
 ]]
 
 print[[
-    <div class="has-feedback text-right">
+    <hr>
+    <div class="has-feedback text-end">
       <button id="pref_change" class="btn btn-primary">]] print(i18n("manage_users.change_user_preferences")) print[[</button>
     </div>
   </form>
@@ -203,7 +195,77 @@ print[[
 ]]
 end
 
-print [[<script>
+if not is_admin then
+print("</div>")
+end
+
+-- get the user token from redis
+local api_token = ntop.getUserAPIToken(_SESSION['user'])
+local input_value = api_token or i18n("manage_users.token_not_generated")
+
+print([[
+  <div class='tab-pane' id='user-token-tab'>
+    <div class="form-group mb-3 has-error">
+      <label class='form-label' for="token-input">]] .. i18n("manage_users.token") ..[[</label>
+      <div class='d-flex'>
+        <input readonly class='form-control' id='input-token' value=']].. input_value ..[['>
+        <input readonly hidden id='input-username' value=']].._SESSION['user'] ..[['>
+        <button ]].. (isEmptyString(api_token) and "style='display: none'" or "") ..[[ class="btn btn-light border ms-1" data-placement="bottom" id="btn-copy-token">
+          <i class='fas fa-copy'></i>
+        </button>
+      </div>
+    </div>
+    <hr>
+    <div class='w-100 text-end'>
+      <button class='btn btn-primary' id='btn-generate_token'>]].. i18n("login.generate_token") ..[[</button>
+    </div>
+  </div>
+]])
+
+print [[
+  <script type='text/javascript'>
+
+  $(document).ready(function() {
+
+    $(`#btn-copy-token`).click(function() {
+      
+      const $this = $(this);
+      const inputToken = document.querySelector('#input-token');
+      inputToken.select();
+
+      // copy the token to the clipboard
+      document.execCommand("copy");
+
+      // show a tooltip
+      $this.tooltip({title: ']] print(i18n("copied")) print[[!', delay: {show: 50, hide: 300}});
+      $this.tooltip('show');
+      // destroy the tooltip after the hide event
+      $this.on('hidden.bs.tooltip', function () {
+        $this.tooltip('dispose');
+      });
+    });
+
+    $(`#btn-generate_token`).click(async function(e) {
+
+      const user = $(`#input-username`).val() || loggedUser;
+      const response = await fetch(`${http_prefix}/lua/rest/v2/create/ntopng/api_token.lua`, {
+        method: 'POST',
+        body: JSON.stringify({username: user, csrf: ']] print(ntop.getRandomCSRFValue()) print [['}),
+        headers: {
+          'Content-Type': 'application/json; charset=utf-8'
+        }
+      });
+
+      const data = await response.json();
+      const token = data.rsp.api_token;
+      $(`#input-token`).val(token);
+      $(`#btn-copy-token`).show();
+
+      $(this).removeAttr("disabled");
+    });
+
+  });
+
   $("#lifetime_unlimited").click(function() {
     $("#lifetime_selection_table label").attr("disabled", "disabled");
     $("#lifetime_selection_table input").attr("disabled", "disabled");
@@ -249,8 +311,8 @@ print [[<script>
         var response = jQuery.parseJSON(data);
         if(response.result == 0) {
           password_alert.success(response.message);
-   	  // window.location.href = 'users.lua';
-          window.location.href = window.location.href;
+          const url = new URL(window.location);
+          window.location.href = url.origin + url.pathname;
 
        } else
           password_alert.error(response.message);
@@ -340,18 +402,24 @@ function reset_pwd_dialog(user) {
         $('#old_host_pool_id').val(data.host_pool_id);
         $('#host_pool_id option[value = '+data.host_pool_id+']').attr('selected','selected');
       }
-      if(data.limited_lifetime) {
-        $("#lifetime_selection_table label").removeAttr("disabled");
-        $("#lifetime_selection_table input").removeAttr("disabled");
-        $("#lifetime_limited").click();
-        if (typeof resol_selector_set_value === "function")
-          resol_selector_set_value("#lifetime_secs", data.limited_lifetime);
-      } else {
-        $("#lifetime_selection_table label").attr("disabled", "disabled");
-        $("#lifetime_selection_table input").attr("disabled", "disabled");
-        $("#lifetime_unlimited").click();
-        if (typeof resol_selector_set_value === "function")
-          resol_selector_set_value("#lifetime_secs", 3600);
+
+     if (isAdministrator || loggedUser === data.username) {
+        $(`[href="#user-token-tab"]`).show();
+        $(`#input-username`).val(data.username);
+        $(`#input-token`).val(data.api_token);
+
+        if (data.api_token === "") {
+          $(`#btn-copy-token`).hide();
+          $(`#input-token`).val(']] print(i18n("manage_users.token_not_generated")) print[[');
+        }
+        else {
+          $(`#btn-copy-token`).show();
+        }
+      }
+      else {
+        $(`#input-token`).val('');
+        $(`#input-username`).val('');
+        $(`[href="#user-token-tab"]`).hide();
       }
 
       $('#form_pref_change').show();
@@ -373,7 +441,6 @@ $('#password_reset_submit').click(function() {
 </div>
 </div>
 </div>
-</div>
 </div> <!-- password_dialog -->
 
 			    ]]
