@@ -1,5 +1,5 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -17,7 +17,6 @@ end
 require "lua_utils"
 local graph_utils = require "graph_utils"
 local alert_utils = require "alert_utils"
-require "historical_utils"
 require "discover_utils"
 require "mac_utils"
 
@@ -83,16 +82,17 @@ page_utils.set_active_menu_entry(page_utils.menu_entries.devices)
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
 if(mac == nil) then
-   print("<div class=\"alert alert alert-danger\"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png>" .. " " .. i18n("mac_details.mac_parameter_missing_message") .. "</div>")
+   print("<div class=\"alert alert alert-danger\"><i class='fas fa-exclamation-triangle fa-lg fa-ntopng-warning'></i>" .. " " .. i18n("mac_details.mac_parameter_missing_message") .. "</div>")
+   dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
    return
 end
 
 if isAdministrator() then
    if _POST["action"] == "reset_stats" then
       if interface.resetMacStats(mac) then
-         print("<div class=\"alert alert alert-success\">")
-         print[[<button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>]]
+         print("<div class=\"alert alert alert-dismissable alert-success\">")
          print(i18n("mac_details.reset_stats_in_progress"))
+         print([[<button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>]])
          print("</div>")
       end
    end
@@ -103,9 +103,10 @@ local mac_info = interface.getMacInfo(mac)
 -- tprint(mac_info)
 
 local only_historical = (mac_info == nil) and (page == "historical")
+local serialize_by_mac = ntop.getPref(string.format("ntopng.prefs.ifid_" .. ifId .. ".serialize_local_broadcast_hosts_as_macs")) == "1"
 
 if(mac_info == nil) and not only_historical then
-   print('<div class=\"alert alert-danger\"><i class="fas fa-exclamation-triangle fa-lg"></i>'..' '..i18n("mac_details.mac_cannot_be_found_message",{mac=mac}))
+   print('<div class=\"alert alert-danger\"><i class="fas fa-exclamation-triangle fa-lg fa-ntopng-warning"></i>'..' '..i18n("mac_details.mac_cannot_be_found_message",{mac=mac}))
    print("</div>")
    dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
    return
@@ -136,7 +137,7 @@ page_utils.print_navbar(title, url,
 			      label = i18n("host_details.snmp"),
 			   },
 			   {
-			      hidden = not areMacsTimeseriesEnabled(ifId),
+			      hidden = not areMacsTimeseriesEnabled(ifId) and not serialize_by_mac,
 			      active = page == "historical",
 			      page_name = "historical",
 			      label = "<i class='fas fa-lg fa-chart-area'></i>",
@@ -361,7 +362,7 @@ elseif(page == "packets") then
    print[[</table>
 
    <script type='text/javascript'>
-    var refresh = ]] print(getInterfaceRefreshRate(ifstats.id)) print[[ * 1000; /* ms */;
+    var refresh = ]] print(interface.getStatsUpdateFreq(ifstats.id)) print[[ * 1000; /* ms */;
 
 	 window.onload=function() {
        do_pie("#ipverDistro", ']]
