@@ -14,13 +14,13 @@ function as2record(ifId, as)
    record["column_asn"] = as_link
 
    record["column_asname"] = printASN(as["asn"], as["asname"])
-
+   record["column_score"] = as["score"]
    record["column_hosts"] = as["num_hosts"]..""
    record["column_since"] = secondsToTime(now - as["seen.first"] + 1)
 
    local sent2rcvd = round((as["bytes.sent"] * 100) / (as["bytes.sent"] + as["bytes.rcvd"]), 0)
    record["column_breakdown"] = "<div class='progress'><div class='progress-bar bg-warning' style='width: "
-      .. sent2rcvd .."%;'>Sent</div><div class='progress-bar bg-info' style='width: " .. (100-sent2rcvd) .. "%;'>Rcvd</div></div>"
+      .. sent2rcvd .."%;'>Sent</div><div class='progress-bar bg-success' style='width: " .. (100-sent2rcvd) .. "%;'>Rcvd</div></div>"
 
    if(throughput_type == "pps") then
       record["column_thpt"] = pktsToSize(as["throughput_pps"])
