@@ -1,5 +1,5 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -20,7 +20,27 @@ if ntop.isPro() then
    shaper_utils = require("shaper_utils")
 end
 
-local json = require ("dkjson")
+-- #######################
+
+local flow_verdict_mapping = {
+   "Pass", -- 1
+   "Drop", -- 2
+}
+
+local flow_verdict_icon = {
+   '<i class="fas fa-check"></i>',
+   '<i class="fas fa-ban"></i>',
+}
+
+-- #######################
+
+function parseFlowVerdict(flow_verdict)
+   if flow_verdict_mapping[flow_verdict] then
+      return (flow_verdict .. " (" .. flow_verdict_mapping[flow_verdict] .. " " .. flow_verdict_icon[flow_verdict] .. ")")
+   end
+
+   return flow_verdict
+end
 
 -- #######################
 
@@ -42,7 +62,7 @@ function formatTrafficProfile(profile)
    local res = ""
 
    if not isEmptyString(profile) then
-      res = "<span class='badge badge-primary'>"..profile.."</span> "
+      res = "<span class='badge bg-primary'>"..profile.."</span> "
    end
 
    return res
@@ -50,20 +70,20 @@ end
 
 -- #######################
 
--- Extracts the information serialized into status_info from the flow
--- user scripts
-function flow2statusinfo(flow)
-   local status_info = flow["status_info"]
+-- Extracts the information serialized into alert_info from the flow
+-- checks
+function flow2alertinfo(flow)
+   local alert_info = flow["alert_info"]
 
-   if(status_info and (string.sub(status_info, 1, 1) == "{")) then
-      local res = json.decode(status_info)
+   if(alert_info and (string.sub(alert_info, 1, 1) == "{")) then
+      local res = json.decode(alert_info)
 
       if(res ~= nil) then
          return(res)
       end
    end
 
-   return(status_info)
+   return(alert_info)
 end
 
 -- #######################
@@ -76,30 +96,34 @@ function getFlowsFilter()
    local perPage     = _GET["perPage"]
 
    -- Other Filters
-   local port        = _GET["port"]
-   local application = _GET["application"]
-   local category    = _GET["category"]
-   local network_id  = _GET["network"]
+   local port         = _GET["port"]
+   local application  = _GET["application"]
+   local category     = _GET["category"]
+   local network_id   = _GET["network"]
    local traffic_profile = _GET["traffic_profile"]
    local traffic_type = _GET["traffic_type"]
-   local flowhosts_type = _GET["flowhosts_type"]
+   local flowhosts_type  = _GET["flowhosts_type"]
    local ipversion    = _GET["version"]
    local l4proto      = _GET["l4proto"]
-   local vlan        = _GET["vlan"]
-   local username = _GET["username"]
-   local host   = _GET["host"]
-   local pid_name = _GET["pid_name"]
-   local container   = _GET["container"]
-   local pod         = _GET["pod"]
-   local icmp_type   = _GET["icmp_type"]
-   local icmp_code   = _GET["icmp_cod"]
-   local flow_status = _GET["flow_status"]
+   local vlan         = _GET["vlan"]
+   local username     = _GET["username"]
+   local host         = _GET["host"]
+   local pid_name     = _GET["pid_name"]
+   local container    = _GET["container"]
+   local pod          = _GET["pod"]
+   local icmp_type    = _GET["icmp_type"]
+   local icmp_code    = _GET["icmp_cod"]
+   local dscp_filter  = _GET["dscp"]
+   local host_pool    = _GET["host_pool_id"]
+   local flow_status  = _GET["flow_status"]
    local flow_status_severity = _GET["flow_status_severity"]
-   local deviceIP    = _GET["deviceIP"]
-   local inIfIdx     = _GET["inIfIdx"]
-   local outIfIdx    = _GET["outIfIdx"]
-   local asn         = _GET["asn"]
-   local tcp_state   = _GET["tcp_flow_state"]
+   local alert_type  = _GET["alert_type"]
+   local alert_type_severity = _GET["alert_type_severity"]
+   local deviceIP     = _GET["deviceIP"]
+   local inIfIdx      = _GET["inIfIdx"]
+   local outIfIdx     = _GET["outIfIdx"]
+   local asn          = _GET["asn"]
+   local tcp_state    = _GET["tcp_flow_state"]
 
    if sortColumn == nil or sortColumn == "column_" or sortColumn == "" then
       sortColumn = getDefaultTableSort("flows")
@@ -195,21 +219,21 @@ function getFlowsFilter()
       end
    end
 
-   if not isEmptyString(flow_status) then
-      if flow_status == "normal" then
+   if not isEmptyString(alert_type) then
+      if alert_type == "normal" then
 	 pageinfo["alertedFlows"] = false
 	 pageinfo["filteredFlows"] = false
-      elseif flow_status == "alerted" then
+      elseif alert_type == "alerted" then
 	 pageinfo["alertedFlows"] = true
-      elseif flow_status == "filtered" then
+      elseif alert_type == "filtered" then
 	 pageinfo["filteredFlows"] = true
       else
-	 pageinfo["statusFilter"] = tonumber(flow_status)
+	 pageinfo["statusFilter"] = tonumber(alert_type)
       end
    end
 
-   if not isEmptyString(flow_status_severity) then
-      local s = alert_consts.severity_groups[flow_status_severity]
+   if not isEmptyString(alert_type_severity) then
+      local s = alert_consts.severity_groups[alert_type_severity]
 
       if s then
 	 pageinfo["statusSeverityFilter"] = s.severity_group_id
@@ -263,6 +287,14 @@ function getFlowsFilter()
    pageinfo["icmp_type"] = tonumber(icmp_type)
    pageinfo["icmp_code"] = tonumber(icmp_code)
 
+   if not isEmptyString(dscp_filter) then
+      pageinfo["dscpFilter"] = tonumber(dscp_filter)
+   end
+
+   if not isEmptyString(host_pool) then
+      pageinfo["poolFilter"] = tonumber(host_pool)
+   end
+
    if not isEmptyString(tcp_state) then
       pageinfo["tcpFlowStateFilter"] = tcp_state
    end
@@ -283,17 +315,12 @@ function handleCustomFlowField(key, value, snmpdevice)
       return(format_utils.formatValue(value))
    elseif key == 'EXPORTER_IPV4_ADDRESS' or
           key == 'NPROBE_IPV4_ADDRESS' then
-      local hinfo = hostkey2hostinfo(value)
-      local res = hostinfo2label(hinfo)
 
-      local ret = ip2detailshref(value, nil, nil, value)
-
-      if((res == "") or (res == nil)) and ret ~= ipaddr then
-	 ret = string.format("%s [%s]", ret, ipaddr)
-      elseif value ~= res then
-	 ret = string.format("%s [%s]", ret, res)
+      if ntop.isPro() then
+	 return("<A HREF=\"".. ntop.getHttpPrefix() .."/lua/pro/enterprise/flowdevice_details.lua?ip="..value.."\">"..value.."</A>")
+      else
+	 return(value)
       end
-      return(ret .. "</A>")
    elseif key == 'FLOW_USER_NAME' then
       elems = string.split(value, ';')
 
@@ -390,30 +417,6 @@ end
 
 -- #######################
 
--- See Utils::l4proto2name()
-l4_protocols = {
-   ['IP'] = 0,
-   ['ICMP'] = 1,
-   ['IGMP'] = 2,
-   ['TCP'] = 6,
-   ['UDP'] = 17,
-   ['IPv6'] = 41,
-   ['RSVP'] = 46,
-   ['GRE'] = 47,
-   ['ESP'] = 50,
-   ['IPv6-ICMP'] = 58,
-   ['OSPF'] = 89,
-   ['PIM'] = 103,
-   ['VRRP'] = 112,
-   ['HIP'] = 139,
-}
-
-function getL4ProtoName(proto_id)
-   return(l4_proto_to_string(proto_id))
-end
-
- -- #######################
-
 local dns_types = {
   ['A'] = 1,
   ['NS'] = 2,
@@ -452,6 +455,22 @@ end
 
 -- #######################
 
+function get_dns_type_label(dns_type)
+   dns_type = tonumber(dns_type)
+
+   if dns_type then
+      for k, v in pairs(dns_types) do
+	 if v == dns_type then
+	    return k
+	 end
+      end
+   end
+
+   return string.format("%u", dns_type)
+end
+
+-- #######################
+
 function extractSIPCaller(caller)
    local i
    local j
@@ -517,6 +536,7 @@ function getAlertTimeBounds(alert, engaged)
       epoch_end = alert.last_switched + half_interval
     else
       local tend = ternary(engaged, os.time(), alert.alert_tstamp_end) or alert_tstamp
+      -- tprint(debug.traceback())
       half_interval = math.max(half_interval, (tend - alert_tstamp) / 2) -- at least 1 hour interval
       local middle_time = (tend + alert_tstamp) / 2
 
@@ -538,7 +558,12 @@ local function formatFlowHost(flow, cli_or_srv, historical_bounds, hyperlink_suf
      hyperlink_params = hyperlink_suffix
   end
 
-  local host_name = shortenString(flowinfo2hostname(flow,cli_or_srv))
+  local host = flow2hostinfo(flow, cli_or_srv)
+  local host_name = host["name"]
+
+  if isEmptyString(host_name) then
+      host_name = host["host"]
+  end
 
   if(flow[cli_or_srv .. ".systemhost"] == true) then
      host_name = host_name.." <i class='fas fa-flag' aria-hidden='true'></i>"
@@ -546,6 +571,11 @@ local function formatFlowHost(flow, cli_or_srv, historical_bounds, hyperlink_suf
   if(flow[cli_or_srv ..  ".blacklisted"] == true) then
      host_name = host_name.." <i class='fas fa-ban' aria-hidden='true' title='Blacklisted'></i>"
   end
+  if(flow[cli_or_srv .. ".localhost"] == true) then
+     host_name = host_name .. ' <abbr title=\"'.. i18n("details.label_local_host") ..'\"><span class="badge bg-success">'..i18n("details.label_short_local_host")..'</span></abbr>'
+  else
+     host_name = host_name .. ' <abbr title=\"'.. i18n("details.label_remote") ..'\"><span class="badge bg-secondary">'..i18n("details.label_short_remote")..'</span></abbr>'
+  end
 
   return hostinfo2detailshref(flow2hostinfo(flow, cli_or_srv), hyperlink_params, host_name, nil, true --[[ perform link existance checks --]])
 end
@@ -564,24 +594,18 @@ function getFlowLabel(flow, show_macs, add_hyperlinks, historical_bounds, hyperl
 
    local cli_name = flowinfo2hostname(flow, "cli")
    local srv_name = flowinfo2hostname(flow, "srv")
+   local cli_mac = flow["cli.mac"]
+   local srv_mac = flow["srv.mac"]
+   local cli_as  = nil
+   local srv_as  = nil
 
    if((not isIPv4(cli_name)) and (not isIPv6(cli_name))) then cli_name = shortenString(cli_name) end
    if((not isIPv4(srv_name)) and (not isIPv6(srv_name))) then srv_name = shortenString(srv_name) end
 
    local cli_port
    local srv_port
-   if flow["cli.port"] and flow["cli.port"] > 0 then cli_port = flow["cli.port"] end
-   if flow["srv.port"] and flow["srv.port"] > 0 then srv_port = flow["srv.port"] end
-
-   local srv_mac
-   if(not isEmptyString(flow["srv.mac"]) and flow["srv.mac"] ~= "00:00:00:00:00:00") then
-      srv_mac = flow["srv.mac"]
-   end
-
-   local cli_mac
-   if(flow["cli.mac"] ~= nil and flow["cli.mac"]~= "" and flow["cli.mac"] ~= "00:00:00:00:00:00") then
-      cli_mac = flow["cli.mac"]
-   end
+   if flow["cli.port"] and (flow["cli.port"] > 0 or flow["proto.l4"] == "TCP" or flow["proto.l4"] == "UDP") then cli_port = flow["cli.port"] end
+   if flow["srv.port"] and (flow["srv.port"] > 0 or flow["proto.l4"] == "TCP" or flow["proto.l4"] == "UDP") then srv_port = flow["srv.port"] end
 
    if add_hyperlinks then
       cli_name = formatFlowHost(flow, "cli", historical_bounds, hyperlink_suffix)
@@ -595,12 +619,26 @@ function getFlowLabel(flow, show_macs, add_hyperlinks, historical_bounds, hyperl
 	 srv_port = formatFlowPort(flow, "srv", srv_port, historical_bounds)
       end
 
-      if cli_mac then
-	 cli_mac = "<A HREF=\""..ntop.getHttpPrefix().."/lua/hosts_stats.lua?mac=" ..cli_mac.."\">" ..cli_mac.."</A>"
+      if((flow.cli_as ~= nil) and (flow.cli_as ~= 0)) then
+         cli_as = "<A HREF=\""..ntop.getHttpPrefix().."/lua/hosts_stats.lua?asn=" ..flow.cli_as.."\">" .. shortenString( flow.cli_as_name or "", 14 ) .."</A>"
+         cli_mac = ""
+      else
+         if cli_mac and (cli_mac ~= "00:00:00:00:00:00") then
+	    cli_mac = "<A HREF=\""..ntop.getHttpPrefix().."/lua/hosts_stats.lua?mac=" ..cli_mac.."\">" ..cli_mac.."</A>"
+	 else
+	    cli_mac = ""
+         end
       end
 
-      if srv_mac then
-	 srv_mac = "<A HREF=\""..ntop.getHttpPrefix().."/lua/hosts_stats.lua?mac=" ..srv_mac.."\">" ..srv_mac.."</A>"
+      if((flow.dst_as ~= nil) and (flow.dst_as ~= 0)) then
+         dst_as = "<A HREF=\""..ntop.getHttpPrefix().."/lua/hosts_stats.lua?asn=" ..flow.dst_as.."\">" .. shortenString( flow.dst_as_name or "", 14 ) .."</A>"
+	 srv_mac = ""
+      else
+        if srv_mac and (srv_mac ~= "00:00:00:00:00:00")then
+	   srv_mac = "<A HREF=\""..ntop.getHttpPrefix().."/lua/hosts_stats.lua?mac=" ..srv_mac.."\">" ..srv_mac.."</A>"
+	else
+	   srv_mac = ""
+        end
       end
 
    end
@@ -623,8 +661,12 @@ function getFlowLabel(flow, show_macs, add_hyperlinks, historical_bounds, hyperl
       label = label..":"..cli_port
    end
 
-   if show_macs and cli_mac then
-      label = label.." [ "..cli_mac.." ]"
+  if(cli_as ~= nil) then
+     label = label.." [ "..cli_as.." ]"
+   else
+      if show_macs and not isEmptyString(cli_mac) then
+        label = label.." [ "..cli_mac.." ]"
+     end
    end
 
    label = label.."&nbsp; <i class=\"fas fa-exchange-alt fa-lg\"  aria-hidden=\"true\"></i> &nbsp;"
@@ -645,8 +687,19 @@ function getFlowLabel(flow, show_macs, add_hyperlinks, historical_bounds, hyperl
       label = label..":"..srv_port
    end
 
-   if show_macs and srv_mac then
+  if(dst_as ~= nil) then
+     label = label.." [ "..dst_as.." ]"
+  else
+     if show_macs and not isEmptyString(srv_mac) then
       label = label.." [ "..srv_mac.." ]"
+    end
+  end
+
+   local s_info = flow2alertinfo(flow)
+   if(s_info ~= nil) then
+      if(not isEmptyString(s_info.info)) then
+	 label = label.."  [".. s_info.info .."]"
+      end
    end
 
    return label
@@ -766,6 +819,8 @@ function getFlowValue(info, field)
    local return_value = "0"
    local value_original = "0"
 
+   if((info == nil) or (table.len(info) == 0)) then return("") end
+
    if(info[field] ~= nil) then
       return_value = handleCustomFlowField(field, info[field])
       value_original = info[field]
@@ -1341,52 +1396,53 @@ end
 -- #######################
 
 function printFlowSNMPInfo(snmpdevice, input_idx, output_idx)
+   local printed = false
+
    -- Make sure indices are strings as snmp_utils handles them as strings
    input_idx = tostring(input_idx)
    output_idx = tostring(output_idx)
 
-   if not ntop.isPro() then
-      return
-   end
+   if ntop.isPro() then
+      if not isEmptyString(snmpdevice) then
+	 local snmp_cached_dev = require "snmp_cached_dev"
+	 local cached_device = snmp_cached_dev:create(snmpdevice)
 
-   if not isEmptyString(snmpdevice) then
-      local snmp_cached_dev = require "snmp_cached_dev"
-      local cached_device = snmp_cached_dev:create(snmpdevice)
+	 if cached_device and cached_device["interfaces"] and table.len(cached_device["interfaces"]) > 0 then
+	    local snmpurl = "<A HREF='" .. ntop.getHttpPrefix() .. "/lua/pro/enterprise/snmp_device_details.lua?host="..snmpdevice.. "'>"..snmpdevice.."</A>"
 
-      if cached_device and cached_device["interfaces"] and table.len(cached_device["interfaces"]) > 0 then
-         local snmpurl = "<A HREF='" .. ntop.getHttpPrefix() .. "/lua/pro/enterprise/snmp_device_details.lua?host="..snmpdevice.. "'>"..snmpdevice.."</A>"
+	    local snmp_interfaces = cached_device["interfaces"]
+	    local inputurl, outputurl
 
-         local snmp_interfaces = cached_device["interfaces"]
-         local inputurl, outputurl
+	    local function prepare_interface_url(idx, port)
+	       local snmp_utils = require "snmp_utils"
+	       local ifurl
 
-         local function prepare_interface_url(idx, port)
-	    local snmp_utils = require "snmp_utils"
-            local ifurl
+	       if port then
+		  ifurl = "<A HREF='" .. ntop.getHttpPrefix() .. "/lua/pro/enterprise/snmp_interface_details.lua?host="..snmpdevice.."&snmp_port_idx="..port["index"].."'>"..snmp_utils.get_snmp_interface_label(port).."</A>"
+	       else
+		  ifurl = idx
+	       end
 
-	    if port then
-	       ifurl = "<A HREF='" .. ntop.getHttpPrefix() .. "/lua/pro/enterprise/snmp_interface_details.lua?host="..snmpdevice.."&snmp_port_idx="..port["index"].."'>"..snmp_utils.get_snmp_interface_label(port).."</A>"
-	    else
-	       ifurl = idx
+	       return ifurl
 	    end
 
-	    return ifurl
-         end
+	    if input_idx then
+	       inputurl = prepare_interface_url(input_idx, snmp_interfaces[input_idx])
+	    end
 
-         local inputurl
-         local outputurl
+	    if output_idx then
+	       outputurl = prepare_interface_url(output_idx, snmp_interfaces[output_idx])
+	    end
 
-         if input_idx then
-            inputurl = prepare_interface_url(input_idx, snmp_interfaces[input_idx])
-         end
-         if output_idx then
-            outputurl = prepare_interface_url(output_idx, snmp_interfaces[output_idx])
-         end
-
-         print("<tr><th rowspan='3'>"..i18n("details.flow_snmp_localization").."</th><th>"..i18n("snmp.snmp_device").."</th><td>"..snmpurl.."</td></tr>")
-         print("<tr><th>"..i18n("details.input_device_port").."</th><td>"..(inputurl or "").."</td></tr>")
-	 print("<tr><th>"..i18n("details.output_device_port").."</th><td>"..(outputurl or "").."</td></tr>")
+	    print("<tr><th rowspan='3'>"..i18n("details.flow_snmp_localization").."</th><th>"..i18n("snmp.snmp_device").."</th><td>"..snmpurl.."</td></tr>")
+	    print("<tr><th>"..i18n("details.input_device_port").."</th><td>"..(inputurl or "").." (".. input_idx ..")</td></tr>")
+	    print("<tr><th>"..i18n("details.output_device_port").."</th><td>"..(outputurl or "").." (".. output_idx ..")</td></tr>")
+	    printed = true
+	 end
       end
-   else
+   end
+
+   if(printed == false) then
       print("<tr><th rowspan='2'>"..i18n("details.flow_snmp_localization").."</th><th>"..i18n("details.input_device_port").."</th><td>"..(input_idx or "").."</td></tr>")
       print("<tr><th>"..i18n("details.output_device_port").."</th><td>"..(output_idx or "").."</td></tr>")
    end
@@ -1414,8 +1470,8 @@ function printBlockFlowJs()
         var row_id = flow_key + "_" + flow_hash_id;
         if (data.status == "BLOCKED") {
           $('#'+row_id+'_block')
-            .removeClass('badge-secondary')
-            .addClass('badge-danger')
+            .removeClass('bg-secondary')
+            .addClass('bg-danger')
             .attr('title', ']] print(i18n("flow_details.flow_traffic_is_dropped")) print[[');
         }
       },
@@ -1448,8 +1504,8 @@ function printL4ProtoDropdown(base_url, page_params, l4_proto)
    end
 
    print[[\
-      <button class="btn btn-link dropdown-toggle" data-toggle="dropdown">]] print(i18n("flows_page.l4_protocol")) print[[]] print(l4proto_filter) print[[<span class="caret"></span></button>\
-      <ul class="dropdown-menu scrollable-dropdown" role="menu" id="flow_dropdown">\
+      <button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">]] print(i18n("flows_page.l4_protocol")) print[[]] print(l4proto_filter) print[[<span class="caret"></span></button>\
+      <ul class="dropdown-menu dropdown-menu-end scrollable-dropdown" role="menu" id="flow_dropdown">\
          <li><a class="dropdown-item" href="]] print(getPageUrl(base_url, l4proto_params_non_tcp)) print[[">]] print(i18n("flows_page.all_l4_protocols")) print[[</a></li>]]
 
     if l4_proto then
@@ -1477,12 +1533,15 @@ local function printFlowDevicesFilterDropdown(base_url, page_params)
    local snmp_cached_dev = require "snmp_cached_dev"
    local flowdevs = interface.getFlowDevices()
    local vlans = interface.getVLANsList()
+   local ordering_fun = pairsByKeys
 
    if flowdevs == nil then flowdevs = {} end
 
-   local devips = {}
-   for dip, _ in pairsByValues(flowdevs, asc) do
-      devips[#devips + 1] = dip
+   local devips = getProbesName(flowdevs)
+   local devips_order = ntop.getPref("ntopng.prefs.flow_table_probe_order") == "1" -- Order by Probe Name
+
+   if devips_order then
+      ordering_fun = pairsByValues
    end
 
    local cur_dev = _GET["deviceIP"]
@@ -1499,23 +1558,16 @@ local function printFlowDevicesFilterDropdown(base_url, page_params)
    end
 
    print[[, '<div class="btn-group float-right">\
-      <button class="btn btn-link dropdown-toggle" data-toggle="dropdown">]] print(i18n("flows_page.device_ip")) print[[]] print(cur_dev_filter) print[[<span class="caret"></span></button>\
-      <ul class="dropdown-menu scrollable-dropdown" role="menu" id="flow_dropdown">\
+      <button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">]] print(i18n("flows_page.device_ip")) print[[]] print(cur_dev_filter) print[[<span class="caret"></span></button>\
+      <ul class="dropdown-menu dropdown-menu-end scrollable-dropdown" role="menu" id="flow_dropdown">\
 	 <li><a class="dropdown-item" href="]] print(getPageUrl(base_url, dev_params)) print[[">]] print(i18n("flows_page.all_devices")) print[[</a></li>\]]
-   for _, dev_ip in ipairs(devips) do
+   for dev_ip, dev_resolved_name in ordering_fun(devips, asc) do
       local dev_name = dev_ip
-      local cached_device = snmp_cached_dev:create(dev_ip)
+
       dev_params["deviceIP"] = dev_name
 
-      if cached_device and not isEmptyString(cached_device["name"]) then
-	 dev_name = dev_name .. " ["..shortenString(cached_device["name"]).."]"
-      else
-	 local hinfo = hostkey2hostinfo(dev_name)
-	 local resname = hostinfo2label(hinfo)
-
-	 if not isEmptyString(resname) and resname ~= dev_name then
-	    dev_name = dev_name .. " ["..shortenString(resname).."]"
-	 end
+      if not isEmptyString(dev_resolved_name) and dev_resolved_name ~= dev_name then
+         dev_name = dev_name .. " ["..shortenString(dev_resolved_name).."]"
       end
 
       print[[
@@ -1541,7 +1593,7 @@ local function printFlowDevicesFilterDropdown(base_url, page_params)
 
 	 if_params[direction] = nil
 	    print[[, '<div class="btn-group float-right">\
-      <button class="btn btn-link dropdown-toggle" data-toggle="dropdown">]] print(i18n("flows_page."..direction)) print[[]] print(cur_if_filter) print[[<span class="caret"></span></button>\
+      <button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">]] print(i18n("flows_page."..direction)) print[[]] print(cur_if_filter) print[[<span class="caret"></span></button>\
       <ul class="dropdown-menu scrollable-dropdown" role="menu" id="flow_dropdown">\
 	 <li><a class="dropdown-item" href="]] print(getPageUrl(base_url, if_params)) print[[">]] print(i18n("flows_page.all_"..direction)) print[[</a></li>\]]
 
@@ -1595,7 +1647,7 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
 
     print[['\
        <div class="btn-group">\
-	  <button class="btn btn-link dropdown-toggle" data-toggle="dropdown">]] print(i18n("flows_page.hosts")) print(getParamFilter(page_params, "flowhosts_type")) print[[<span class="caret"></span></button>\
+	  <button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">]] print(i18n("flows_page.hosts")) print(getParamFilter(page_params, "flowhosts_type")) print[[<span class="caret"></span></button>\
 	  <ul class="dropdown-menu scrollable-dropdown" role="menu" id="flow_dropdown">\
 	     <li><a class="dropdown-item" href="]] print(getPageUrl(base_url, flowhosts_type_params)) print[[">]] print(i18n("flows_page.all_hosts")) print[[</a></li>\]]
        printDropdownEntries({
@@ -1611,14 +1663,14 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
 
     -- Status selector
     -- table.clone needed to modify some parameters while keeping the original unchanged
-    local flow_status_params = table.clone(page_params)
-    flow_status_params["flow_status"] = nil
+    local alert_type_params = table.clone(page_params)
+    alert_type_params["alert_type"] = nil
 
     print[[, '\
        <div class="btn-group">\
-	  <button class="btn btn-link dropdown-toggle" data-toggle="dropdown">]] print(i18n("status")) print(getParamFilter(page_params, "flow_status")) print[[<span class="caret"></span></button>\
+	  <button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">]] print(i18n("status")) print(getParamFilter(page_params, "alert_type")) print[[<span class="caret"></span></button>\
 	  <ul class="dropdown-menu scrollable-dropdown" role="menu">\
-	  <li><a class="dropdown-item" href="]] print(getPageUrl(base_url, flow_status_params)) print[[">]] print(i18n("flows_page.all_flows")) print[[</a></li>\]]
+	  <li><a class="dropdown-item" href="]] print(getPageUrl(base_url, alert_type_params)) print[[">]] print(i18n("flows_page.all_flows")) print[[</a></li>\]]
 
        local entries = {
 	  {"normal", i18n("flows_page.normal")},
@@ -1627,26 +1679,29 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
 
        local status_stats = flowstats["status"]
        local first = true
-       for _, s in pairsByKeys(flow_consts.status_types) do
-          local t = s.status_key
 
-          if(t > 0) then
-             if status_stats[t] and status_stats[t].count > 0 then
-               if first then
-                 entries[#entries + 1] = '<li role="separator" class="divider"></li>'
-                 entries[#entries + 1] = '<li class="dropdown-header">'.. i18n("flow_details.alerted_flows") ..'</li>'
-                 first = false
-               end
-               entries[#entries + 1] = {string.format("%u", t), (i18n(s.i18n_title) or s.i18n_title) .. " ("..status_stats[t].count..")"}
-             end
-          end
+       -- Add labels to allow alphabetic sort
+       for status_key, status in pairs(status_stats) do
+	  if status.count > 0 then
+	     status.label =  alert_consts.alertTypeLabel(status_key, true --[[ no html --]])
+	  end
+       end
+
+       for status_key, status in pairsByField(status_stats, "label", asc) do
+	  if status.count > 0 then
+	     if first then
+		entries[#entries + 1] = '<li class="dropdown-header" id="alerted-flows-title" style="padding-left: 8px; padding-top: 4px; padding-bottom: 4px">'.. i18n("flow_details.alerted_flows") ..'</li>'
+		first = false
+	     end
+	     entries[#entries + 1] = {string.format("%u", status_key), (status.label) .. " ("..status.count..")"}
+	  end
        end
 
        if isBridgeInterface(ifstats) then
 	  entries[#entries + 1] = {"filtered", i18n("flows_page.blocked")}
        end
 
-       printDropdownEntries(entries, base_url, flow_status_params, "flow_status", page_params.flow_status)
+       printDropdownEntries(entries, base_url, alert_type_params, "alert_type", page_params.alert_type)
 
        print[[\
 	  </ul>\
@@ -1654,14 +1709,14 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
     ']]
 
        -- Flow Status Severity
-       local flow_status_severity_params = table.clone(page_params)
-       flow_status_severity_params["flow_status_severity"] = nil
+       local alert_type_severity_params = table.clone(page_params)
+       alert_type_severity_params["alert_type_severity"] = nil
 
        print[[, '\
        <div class="btn-group">\
-	  <button class="btn btn-link dropdown-toggle" data-toggle="dropdown">]] print(i18n("flows_page.flow_status_severity")) print(getParamFilter(page_params, "flow_status_severity")) print[[<span class="caret"></span></button>\
+	  <button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">]] print(i18n("flows_page.alert_type_severity")) print(getParamFilter(page_params, "alert_type_severity")) print[[<span class="caret"></span></button>\
 	  <ul class="dropdown-menu scrollable-dropdown" role="menu">\
-	  <li><a class="dropdown-item" href="]] print(getPageUrl(base_url, flow_status_severity_params)) print[[">]] print(i18n("flows_page.all_flows")) print[[</a></li>]]
+	  <li><a class="dropdown-item" href="]] print(getPageUrl(base_url, alert_type_severity_params)) print[[">]] print(i18n("flows_page.all_flows")) print[[</a></li>]]
 
        local entries
 
@@ -1675,7 +1730,7 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
 	  end
        end
 
-       printDropdownEntries(entries, base_url, flow_status_severity_params, "flow_status_severity", page_params.flow_status_severity)
+       printDropdownEntries(entries, base_url, alert_type_severity_params, "alert_type_severity", page_params.alert_type_severity)
 
        print[[\
 	  </ul>\
@@ -1691,7 +1746,7 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
 
 	  print[[, '\
 	   <div class="btn-group">\
-	      <button class="btn btn-link dropdown-toggle" data-toggle="dropdown">]] print(i18n("flows_page.tcp_state")) print(getParamFilter(page_params, "tcp_flow_state")) print[[<span class="caret"></span></button>\
+	      <button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">]] print(i18n("flows_page.tcp_state")) print(getParamFilter(page_params, "tcp_flow_state")) print[[<span class="caret"></span></button>\
 	      <ul class="dropdown-menu scrollable-dropdown" role="menu">\
 	      <li><a class="dropdown-item" href="]] print(getPageUrl(base_url, tcp_state_params)) print[[">]] print(i18n("flows_page.all_flows")) print[[</a></li>\]]
 
@@ -1714,7 +1769,7 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
 
 	print[[, '\
 	   <div class="btn-group">\
-	      <button class="btn btn-link dropdown-toggle" data-toggle="dropdown">]] print(i18n("flows_page.direction")) print(getParamFilter(page_params, "traffic_type")) print[[<span class="caret"></span></button>\
+	      <button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">]] print(i18n("flows_page.direction")) print(getParamFilter(page_params, "traffic_type")) print[[<span class="caret"></span></button>\
 	      <ul class="dropdown-menu scrollable-dropdown" role="menu">\
 		 <li><a class="dropdown-item" href="]] print(getPageUrl(base_url, traffic_type_params)) print[[">]] print(i18n("flows_page.all_flows")) print[[</a></li>\]]
 	printDropdownEntries({
@@ -1738,7 +1793,7 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
 	    if not table.empty(pods) then
 		print[[, '\
 	       <div class="btn-group">\
-		  <button class="btn btn-link dropdown-toggle" data-toggle="dropdown">]] print(i18n("containers_stats.pod")) print(getParamFilter(page_params, "pod")) print[[<span class="caret"></span></button>\
+		  <button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">]] print(i18n("containers_stats.pod")) print(getParamFilter(page_params, "pod")) print[[<span class="caret"></span></button>\
 		  <ul class="dropdown-menu scrollable-dropdown" role="menu">\
 		  ]]
 		local entries = {}
@@ -1767,7 +1822,7 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
 	    if not table.empty(containers) then
 		print[[, '\
 	       <div class="btn-group">\
-		  <button class="btn btn-link dropdown-toggle" data-toggle="dropdown">]] print(i18n("containers_stats.container")) print(getParamFilter(page_params, "container")) print[[<span class="caret"></span></button>\
+		  <button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">]] print(i18n("containers_stats.container")) print(getParamFilter(page_params, "container")) print[[<span class="caret"></span></button>\
 		  <ul class="dropdown-menu scrollable-dropdown" role="menu">\
 		  ]]
 		local entries = {}
@@ -1788,7 +1843,7 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
     end
 
     -- L7 Application
-    print(', \'<div class="btn-group"><button class="btn btn-link dropdown-toggle" data-toggle="dropdown">'..i18n("report.applications")..' ' .. getParamFilter(page_params, "application") .. '<span class="caret"></span></button> <ul class="dropdown-menu scrollable-dropdown" role="menu" id="flow_dropdown">')
+    print(', \'<div class="btn-group"><button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">'..i18n("report.applications")..' ' .. getParamFilter(page_params, "application") .. '<span class="caret"></span></button> <ul class="dropdown-menu scrollable-dropdown" role="menu" id="flow_dropdown">')
     print('<li><a class="dropdown-item" href="')
 
     -- table.clone needed to modify some parameters while keeping the original unchanged
@@ -1824,7 +1879,7 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
     print("</ul> </div>'")
 
     -- L7 Application Category
-    print(', \'<div class="btn-group"><button class="btn btn-link dropdown-toggle" data-toggle="dropdown">'..i18n("users.categories")..' ' .. getParamFilter(page_params, "category") .. '<span class="caret"></span></button> <ul class="dropdown-menu scrollable-dropdown" role="menu" id="flow_dropdown">')
+    print(', \'<div class="btn-group"><button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">'..i18n("users.categories")..' ' .. getParamFilter(page_params, "category") .. '<span class="caret"></span></button> <ul class="dropdown-menu scrollable-dropdown" role="menu" id="flow_dropdown">')
     print('<li><a class="dropdown-item" href="')
     -- table.clone needed to modify some parameters while keeping the original unchanged
     local category_filter_params = table.clone(page_params)
@@ -1846,6 +1901,33 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
 
     print("</ul> </div>'")
 
+    -- DSCP selector
+    -- table.clone needed to modify some parameters while keeping the original unchanged
+    local dscp_params = table.clone(page_params)
+    dscp_params["dscp"] = nil
+
+    print[[, '<div class="btn-group float-right">]]
+    printDSCPDropdown(base_url, dscp_params, flowstats["dscps"] or {})
+    print [[</div>']]
+
+    -- Host Pool selector
+    -- table.clone needed to modify some parameters while keeping the original unchanged
+    local host_pool_params = table.clone(page_params)
+    host_pool_params["host_pool"] = nil
+
+    print[[, '<div class="btn-group float-right">]]
+    printHostPoolDropdown(base_url, host_pool_params, flowstats["host_pool_id"] or {})
+    print [[</div>']]
+
+    -- Host Pool selector
+    -- table.clone needed to modify some parameters while keeping the original unchanged
+    local local_network_params = table.clone(page_params)
+    local_network_params["network"] = nil
+
+    print[[, '<div class="btn-group float-right">]]
+    printLocalNetworksDropdown(base_url, local_network_params)
+    print [[</div>']]
+
     -- IP version selector
     -- table.clone needed to modify some parameters while keeping the original unchanged
     local ipversion_params = table.clone(page_params)
@@ -1885,7 +1967,7 @@ function printActiveFlowsDropdown(base_url, page_params, ifstats, flowstats, is_
 
       if profiles_defined then
         -- Traffic Profiles
-        print(', \'<div class="btn-group"><button class="btn btn-link dropdown-toggle" data-toggle="dropdown">'..i18n("traffic_profiles.traffic_profiles")..' ' .. getParamFilter(page_params, "traffic_profile") .. '<span class="caret"></span></button> <ul class="dropdown-menu scrollable-dropdown" role="menu" id="flow_dropdown">')
+        print(', \'<div class="btn-group"><button class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">'..i18n("traffic_profiles.traffic_profiles")..' ' .. getParamFilter(page_params, "traffic_profile") .. '<span class="caret"></span></button> <ul class="dropdown-menu scrollable-dropdown" role="menu" id="flow_dropdown">')
         print('<li><a class="dropdown-item" href="')
 	-- table.clone needed to modify some parameters while keeping the original unchanged
         local traffic_profile_filter_params = table.clone(page_params)
@@ -1916,35 +1998,40 @@ end
 -- #######################
 
 function getFlowsTableTitle()
+   local active_msg = ""
    local status_type
 
-   if _GET["flow_status"] then
-      local flow_status_id = tonumber(_GET["flow_status"])
+   if _GET["alert_type"] then
+      local alert_type_id = tonumber(_GET["alert_type"])
 
-      if(flow_status_id ~= nil) then
-	 status_type = flow_consts.getStatusTitle(_GET["flow_status"])
+      if(alert_type_id ~= nil) then
+	 status_type = alert_consts.alertTypeLabel(tonumber(_GET["alert_type"]), true)
       else
-	 status_type = _GET["flow_status"]
+	 status_type = firstToUpper(_GET["alert_type"])
       end
    end
 
-   local filter = (_GET["application"] or _GET["category"] or _GET["vhost"] or status_type or "")
-   local active_msg = ""
-   local filter_msg = ""
+   if _GET["alert_type_severity"] then
+      local alert_type_severity = _GET["alert_type_severity"]
 
-   if not isEmptyString(filter) then
-      filter_msg = i18n("flows_page."..filter)
-      if isEmptyString(filter_msg) then
-	 filter_msg = firstToUpper(filter)
-      end
+      local s = alert_consts.severity_groups[alert_type_severity]
+      active_msg = active_msg .. " "..  i18n(s.i18n_title)
    end
 
-   if not interface.isPacketInterface() then
-      active_msg = i18n("flows_page.recently_active_flows", {filter=filter_msg})
-   elseif interface.isPcapDumpInterface() then
-      active_msg = i18n("flows_page.flows", {filter=filter_msg})
-   else
-      active_msg = i18n("flows_page.active_flows", {filter=filter_msg})
+   if _GET["application"] then
+      active_msg = active_msg .. " "..  _GET["application"]
+   end
+
+   if _GET["category"] then
+      active_msg = active_msg .. " " .. _GET["category"]
+   end
+
+   if _GET["vhost"] then
+      active_msg = active_msg .. " " .. _GET["vhost"]
+   end
+
+   if status_type then
+      active_msg = active_msg .. " " .. status_type
    end
 
    if(_GET["network_name"] ~= nil) then
@@ -1995,6 +2082,14 @@ function getFlowsTableTitle()
       active_msg = active_msg .. " ["..tcp_flow_state_utils.state2i18n(_GET["tcp_flow_state"]).."]"
    end
 
+   if not interface.isPacketInterface() then
+      active_msg = i18n("flows_page.recently_active_flows", {filter = active_msg})
+   elseif interface.isPcapDumpInterface() then
+      active_msg = i18n("flows_page.flows", {filter = active_msg})
+   else
+      active_msg = i18n("flows_page.active_flows", {filter = active_msg})
+   end
+
    return active_msg
 end
 
