@@ -1,5 +1,5 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -7,11 +7,9 @@ package.path = dirs.installdir .. "/scripts/lua/modules/pools/?.lua;" .. package
 
 require "lua_utils"
 require "db_utils"
-require "historical_utils"
 require "rrd_paths"
 
 local dkjson = require("dkjson")
-local host_pools = require "host_pools"
 local top_talkers_utils = require "top_talkers_utils"
 local os_utils = require "os_utils"
 local graph_common = require "graph_common"
@@ -19,6 +17,8 @@ local have_nedge = ntop.isnEdge()
 
 local ts_utils = require("ts_utils")
 
+local iface_behavior_update_freq = 300 --Seconds
+
 -- ########################################################
 
 local graph_utils = {}
@@ -33,7 +33,7 @@ end
 
 -- ########################################################
 
-local graph_colors = {
+graph_utils.graph_colors = {
    '#1f77b4',
    '#ff7f0e',
    '#2ca02c',
@@ -69,6 +69,12 @@ local graph_colors = {
 
 -- ########################################################
 
+function graph_utils.get_html_color(index) 
+   return graph_utils.graph_colors[(index % #graph_utils.graph_colors) + 1]
+end
+
+-- ########################################################
+
 -- @brief Ensure that the provided series have the same number of points. This is a
 -- requirement for the charts.
 -- @param series a list of series to fix. The format of each serie is the one
@@ -160,7 +166,7 @@ function graph_utils.breakdownBar(sent, sentLabel, rcvd, rcvdLabel, thresholdLow
     elseif(sent2rcvd > thresholdHigh) then rcvdLabel = '<i class="fas fa-exclamation-triangle fa-lg""></i> '..rcvdLabel end
 
       print('<div class="progress"><div class="progress-bar bg-warning" aria-valuenow="'.. sent2rcvd..'" aria-valuemin="0" aria-valuemax="100" style="width: ' .. sent2rcvd.. '%;">'..sentLabel)
-      print('</div><div class="progress-bar bg-info" aria-valuenow="'.. (100-sent2rcvd)..'" aria-valuemin="0" aria-valuemax="100" style="width: ' .. (100-sent2rcvd) .. '%;">' .. rcvdLabel .. '</div></div>')
+      print('</div><div class="progress-bar bg-success" aria-valuenow="'.. (100-sent2rcvd)..'" aria-valuemin="0" aria-valuemax="100" style="width: ' .. (100-sent2rcvd) .. '%;">' .. rcvdLabel .. '</div></div>')
 
    else
       print('&nbsp;')
@@ -228,8 +234,8 @@ function graph_utils.stackedProgressBars(total, bars, other_label, formatter, cs
       if bar.class == nil then bar.class = "primary" end
       if bar.style == nil then bar.style = "" end
       if bar.link ~= nil then
-         res[#res + 1] = [[<a href="]] .. bar.link .. [[" style="width:]] .. percentage .. [[%;]] .. bar.style .. [[">
-            <div class="progress-bar bg-]] .. (bar.class) .. [[" role="progressbar" style="width: 100%"></div></a>]]
+         res[#res + 1] = [[<a href="]] .. bar.link .. [[" style="width:]] .. percentage .. [[%;]] .. bar.style .. 
+         [[" class="progress-bar bg-]] .. (bar.class) .. [[" role="progressbar"></a>]]
       else
          res[#res + 1] = [[
             <div class="progress-bar bg-]] .. (bar.class) .. [[" role="progressbar" style="width:]] .. percentage .. [[%;]] .. bar.style .. [["></div></a>]]
@@ -264,7 +270,7 @@ function graph_utils.stackedProgressBars(total, bars, other_label, formatter, cs
       res[#res + 1] = [[<span>]]
       if(num > 0) then res[#res + 1] = [[<br>]] end
       if bar.link ~= nil then res[#res + 1] = [[<a href="]] .. bar.link .. [[">]] end
-      res[#res + 1] = [[<span class="badge badge-]].. (bar.class) ..[[" style="]] .. bar.style .. [[">&nbsp;</span>]]
+      res[#res + 1] = [[<span class="badge bg-]].. (bar.class) ..[[" style="]] .. bar.style .. [[">&nbsp;</span>]]
       if bar.link ~= nil then res[#res + 1] = [[</a>]] end
       res[#res + 1] = [[<span> ]] .. bar.title .. " (".. formatter(bar.value) ..")</span></span>"
       num = num + 1
@@ -295,24 +301,7 @@ end
 
 -- #################################################
 
-local function printGraphTopFlows(ifId, host, epoch, zoomLevel, l7proto, vlan)
-   -- Check if the DB is enabled
-   rsp = interface.execSQLQuery("show tables")
-   if(rsp == nil) then return end
-
-   if((epoch == nil) or (epoch == "")) then epoch = os.time() end
-
-   local d = graph_common.getZoomDuration(zoomLevel)
-
-   epoch_end = epoch
-   epoch_begin = epoch-d
-
-   historicalFlowsTab(ifId, host, epoch_begin, epoch_end, l7proto, '', '', '', vlan)
-end
-
--- ########################################################
-
-function graph_utils.drawGraphs(ifid, schema, tags, zoomLevel, baseurl, selectedEpoch, options)
+function graph_utils.drawGraphs(ifid, schema, tags, zoomLevel, baseurl, selectedEpoch, options, show_graph)
    local page_utils =require("page_utils") -- Do not require at the top as it could conflict with plugins_utils.getMenuEntries
    local debug_rrd = false
    local is_system_interface = page_utils.is_system_view()
@@ -354,7 +343,7 @@ function graph_utils.drawGraphs(ifid, schema, tags, zoomLevel, baseurl, selected
 
    if graph_utils.drawProGraph then
       _ifstats = interface.getStats()
-      graph_utils.drawProGraph(ifid, schema, tags, zoomLevel, baseurl, options)
+      graph_utils.drawProGraph(ifid, schema, tags, zoomLevel, baseurl, options, show_graph)
       return
    end
 
@@ -417,84 +406,78 @@ function graph_utils.drawGraphs(ifid, schema, tags, zoomLevel, baseurl, selected
    <div class='card'>
       <div class='card-header'>
          <ul class="nav nav-tabs card-header-tabs" role="tablist" id="historical-tabs-container">
-            <li class="nav-item active"> <a class="nav-link active" href="#historical-tab-chart" role="tab" data-toggle="tab"> Chart </a> </li>
+            <li class="nav-item active"> <a class="nav-link active" href="#historical-tab-chart" role="tab" data-bs-toggle="tab"> Chart </a> </li>
 ]]
 
-local show_historical_tabs = ntop.getPrefs().is_dump_flows_to_mysql_enabled and options.show_historical
-
-if show_historical_tabs then
-   print('<li class="nav-item"><a class="nav-link" href="#historical-flows" role="tab" data-toggle="tab" id="tab-flows-summary"> Flows </a> </li>\n')
-end
-
-print[[
+   print[[
 </ul>
 </div>
 <div class='card-body'>
   <div class="tab-content">
     <div class="tab-pane active in" id="historical-tab-chart">
-
 <table border=0>
 <tr><td valign="top">
 ]]
 
-local page_params = {
-   ts_schema = schema,
-   zoom = zoomLevel or '',
-   epoch = selectedEpoch or '',
-   tskey = options.tskey,
-}
+   local page_params = {
+      ts_schema = schema,
+      zoom = zoomLevel or '',
+      epoch = selectedEpoch or '',
+      tskey = options.tskey,
+   }
 
-if(options.timeseries) then
-   print [[
+   if(options.timeseries) then
+      print [[
    <div class="dropdown d-inline">
-      <button class="btn btn-light btn-sm dropdown-toggle" data-toggle="dropdown">Timeseries <span class="caret"></span></button>
+      <button class="btn btn-light btn-sm dropdown-toggle" data-bs-toggle="dropdown">Timeseries <span class="caret"></span></button>
       <div class="dropdown-menu scrollable-dropdown">
-   ]]
+      ]]
 
-   graph_common.printSeries(options, tags, start_time, end_time, baseurl, page_params)
-   graph_common.printGraphMenuEntries(graph_common.printEntry, nil, start_time, end_time)
+      graph_common.printSeries(options, tags, start_time, end_time, baseurl, page_params)
+      graph_common.printGraphMenuEntries(graph_common.printEntry, nil, start_time, end_time)
 
-   print [[
+      print [[
       </div>
    </div><!-- /btn-group -->
-   ]]
-end -- options.timeseries
+      ]]
+   end -- options.timeseries
 
-print('<span class="mx-1">Timeframe:</span><div class="btn-group btn-group-toggle" data-toggle="buttons" id="graph_zoom">\n')
+   print('<span class="mx-1">Timeframe:</span><div class="btn-group" role="group" id="graph_zoom">\n')
 
-for k,v in ipairs(graph_common.zoom_vals) do
-   -- display 1 minute button only for networks and interface stats
-   -- but exclude applications. Application statistics are gathered
-   -- every 5 minutes
-   if graph_common.zoom_vals[k][1] == '1m' and min_zoom ~= '1m' then
-      goto continue
-   elseif graph_common.zoom_vals[k][1] == '5m' and min_zoom ~= '1m' and min_zoom ~= '5m' then
-      goto continue
+   for k,v in ipairs(graph_common.zoom_vals) do
+      -- display 1 minute button only for networks and interface stats
+      -- but exclude applications. Application statistics are gathered
+      -- every 5 minutes
+      if graph_common.zoom_vals[k][1] == '1m' and min_zoom ~= '1m' then
+         goto continue
+      elseif graph_common.zoom_vals[k][1] == '5m' and min_zoom ~= '1m' and min_zoom ~= '5m' then
+         goto continue
+      end
+      
+      local params = table.merge(page_params, {zoom=graph_common.zoom_vals[k][1]})
+
+      -- Additional parameters
+      if tags.protocol ~= nil then
+         params["protocol"] = tags.protocol
+      end
+      if tags.category ~= nil then
+         params["category"] = tags.category
+      end
+
+      local url = getPageUrl(baseurl, params)
+      print('<input type="radio" class="btn-check" name="options" id="zoom_level_'..k..'" value="'..url..'">')
+
+      if(graph_common.zoom_vals[k][1] == zoomLevel) then
+         print([[<label class="btn bg-primary text-white" for='zoom_level_]].. k ..[['>]]..  graph_common.zoom_vals[k][1] ..[[</label>]])
+      else
+         print([[<label class="btn btn-outline-secondary" for='zoom_level_]].. k ..[['>]]..  graph_common.zoom_vals[k][1] ..[[</label>]])
+      end
+
+
+      ::continue::
    end
 
-   if(graph_common.zoom_vals[k][1] == zoomLevel) then
-      print([[<label class="btn bg-primary text-white">]])
-   else
-      print([[<label class="btn btn-link">]])
-   end
-
-   local params = table.merge(page_params, {zoom=graph_common.zoom_vals[k][1]})
-
-   -- Additional parameters
-   if tags.protocol ~= nil then
-      params["protocol"] = tags.protocol
-   end
-   if tags.category ~= nil then
-      params["category"] = tags.category
-   end
-
-   local url = getPageUrl(baseurl, params)
-
-   print('<input type="radio" name="options" id="zoom_level_'..k..'" value="'..url..'">'.. graph_common.zoom_vals[k][1] ..'</input></label>\n')
-   ::continue::
-end
-
-print [[
+   print [[
 </div>
 </div>
 
@@ -506,173 +489,174 @@ print [[
 
 <div id="legend"></div>
 <div id="chart_legend"></div>
-<div id="chart" style="margin-right: 50px; margin-left: 10px; display: table-cell"></div>
-<p style='color: lightgray'><small>NOTE: Click on the graph to zoom.</small>
-
+<div id="chart" style="margin-right: 3rem; margin-left: 1rem; display: table-cell"></div>
 </td>
 
 
 <td rowspan=2>
 <div id="y_axis"></div>
 
-<div style="margin-left: 10px; display: table">
+<div style="margin-left: 1rem; display: table">
 <div id="chart_container" style="display: table-row">
 
-]]
-
-local format_as_bps = true
-local format_as_bytes = false
-local formatter_fctn
-
-local label = data.series[1].label
-
-if label == "load_percentage" then
-   formatter_fctn = "NtopUtils.ffloat"
-   format_as_bps = false
-elseif label == "resident_bytes" then
-   formatter_fctn = "NtopUtils.bytesToSize"
-   format_as_bytes = true
-elseif string.contains(label, "pct") then
-   formatter_fctn = "NtopUtils.fpercent"
-   format_as_bps = false
-   format_as_bytes = false
-elseif schema == "process:num_alerts" then
-   formatter_fctn = "NtopUtils.falerts"
-   format_as_bps = false
-   format_as_bytes = false
-elseif label:contains("millis") or label:contains("_ms") then
-   formatter_fctn = "NtopUtils.fmillis"
-   format_as_bytes = false
-   format_as_bps = false
-elseif string.contains(label, "packets") or string.contains(label, "flows") or label:starts("num_") or label:contains("alerts") then
-   formatter_fctn = "NtopUtils.fint"
-   format_as_bytes = false
-   format_as_bps = false
-else
-   formatter_fctn = (is_system_interface and "NtopUtils.fnone" or "NtopUtils.fbits")
-end
-
-print [[
-   <table class="table table-bordered table-striped" style="border: 0; margin-right: 10px; display: table-cell">
    ]]
 
-print('   <tr><th>&nbsp;</th><th>Time</th><th>Value</th></tr>\n')
+   local format_as_bps = true
+   local format_as_bytes = false
+   local formatter_fctn
 
-local stats = data.statistics
+   local label = data.series[1].label
 
-if(stats ~= nil) then
-  local minval_time = stats.min_val_idx and (data.start + data.step * stats.min_val_idx) or 0
-  local maxval_time = stats.max_val_idx and (data.start + data.step * stats.max_val_idx) or 0
-  local lastval_time = data.start + data.step * (data.count-1)
-  local lastval = 0
-
-  for _, serie in pairs(data.series) do
-     lastval = lastval + (serie.data[data.count] or 0)
-  end
-
-   if format_as_bytes then
-      if(minval_time > 0) then print('   <tr><th>Min</th><td>' .. os.date("%x %X", minval_time) .. '</td><td>' .. bytesToSize((stats.min_val*8) or "") .. '</td></tr>\n') end
-      if(maxval_time > 0) then print('   <tr><th>Max</th><td>' .. os.date("%x %X", maxval_time) .. '</td><td>' .. bytesToSize((stats.max_val*8) or "") .. '</td></tr>\n') end
-      print('   <tr><th>Last</th><td>' .. os.date("%x %X", lastval_time) .. '</td><td>' .. bytesToSize(lastval*8)  .. '</td></tr>\n')
-      print('   <tr><th>Average</th><td colspan=2>' .. bytesToSize(stats.average*8) .. '</td></tr>\n')
-      print('   <tr><th>95th <A HREF=https://en.wikipedia.org/wiki/Percentile>Percentile</A></th><td colspan=2>' .. bytesToSize(stats["95th_percentile"]*8) .. '</td></tr>\n')
-   elseif(not format_as_bps) then
-     if(minval_time > 0) then print('   <tr><th>Min</th><td>' .. os.date("%x %X", minval_time) .. '</td><td>' .. formatValue(stats.min_val or "") .. '</td></tr>\n') end
-     if(maxval_time > 0) then print('   <tr><th>Max</th><td>' .. os.date("%x %X", maxval_time) .. '</td><td>' .. formatValue(stats.max_val or "") .. '</td></tr>\n') end
-     print('   <tr><th>Last</th><td>' .. os.date("%x %X", lastval_time) .. '</td><td>' .. formatValue(round(lastval), 1) .. '</td></tr>\n')
-     print('   <tr><th>Average</th><td colspan=2>' .. formatValue(round(stats.average, 2)) .. '</td></tr>\n')
-     print('   <tr><th>95th <A HREF=https://en.wikipedia.org/wiki/Percentile>Percentile</A></th><td colspan=2>' .. formatValue(round(stats["95th_percentile"], 2)) .. '</td></tr>\n')
-   elseif is_system_interface then
-      if(minval_time > 0) then print('   <tr><th>Min</th><td>' .. os.date("%x %X", minval_time) .. '</td><td>' .. (formatValue(round(stats["min_val"], 2)) or "") .. '</td></tr>\n') end
-      if(maxval_time > 0) then print('   <tr><th>Max</th><td>' .. os.date("%x %X", maxval_time) .. '</td><td>' .. (formatValue(round(stats["max_val"], 2)) or "") .. '</td></tr>\n') end
-      print('   <tr><th>Last</th><td>' .. os.date("%x %X", lastval_time) .. '</td><td>' .. formatValue(round(lastval, 2)) .. '</td></tr>\n')
-      print('   <tr><th>Average</th><td colspan=2>' ..formatValue(round(stats["average"], 2)).. '</td></tr>\n')
-      print('   <tr><th>95th <A HREF=https://en.wikipedia.org/wiki/Percentile>Percentile</A></th><td colspan=2>' ..(formatValue(round(stats["95th_percentile"], 2)) or '') .. '</td></tr>\n')
-      print('   <tr><th>Total Traffic</th><td colspan=2>' .. (stats.total or '') .. '</td></tr>\n')
+   -- Attempt at reading the formatter from the options using the schema
+   local formatter
+   if options and options.timeseries then
+      for _, cur_ts in pairs(options.timeseries or {}) do
+	 if cur_ts.schema == schema and cur_ts.value_formatter then
+	    formatter = cur_ts.value_formatter[1] or cur_ts.value_formatter
+	    break
+	 end
+      end
+   end
+   
+   if label == "load_percentage" then
+      formatter_fctn = "NtopUtils.ffloat"
+      format_as_bps = false
+   elseif label == "resident_bytes" then
+      formatter_fctn = "NtopUtils.bytesToSize"
+      format_as_bytes = true
+   elseif string.contains(label, "pct") then
+      formatter_fctn = "NtopUtils.fpercent"
+      format_as_bps = false
+      format_as_bytes = false
+   elseif schema == "process:num_alerts" then
+      formatter_fctn = "NtopUtils.falerts"
+      format_as_bps = false
+      format_as_bytes = false
+   elseif label:contains("millis") or label:contains("_ms") then
+      formatter_fctn = "NtopUtils.fmillis"
+      format_as_bytes = false
+      format_as_bps = false
+   elseif string.contains(label, "packets") or string.contains(label, "flows") or label:starts("num_") or label:contains("alerts") then
+      formatter_fctn = "NtopUtils.fint"
+      format_as_bytes = false
+      format_as_bps = false
+   elseif formatter then
+      -- The formatter specified in the options
+      formatter_fctn = formatter
+      format_as_bytes = false
+      format_as_bps = false
    else
-     if(minval_time > 0) then print('   <tr><th>Min</th><td>' .. os.date("%x %X", minval_time) .. '</td><td>' .. bitsToSize((stats.min_val*8) or "") .. '</td></tr>\n') end
-     if(maxval_time > 0) then print('   <tr><th>Max</th><td>' .. os.date("%x %X", maxval_time) .. '</td><td>' .. bitsToSize((stats.max_val*8) or "") .. '</td></tr>\n') end
-     print('   <tr><th>Last</th><td>' .. os.date("%x %X", lastval_time) .. '</td><td>' .. bitsToSize(lastval*8)  .. '</td></tr>\n')
-     print('   <tr><th>Average</th><td colspan=2>' .. bitsToSize(stats.average*8) .. '</td></tr>\n')
-     print('   <tr><th>95th <A HREF=https://en.wikipedia.org/wiki/Percentile>Percentile</A></th><td colspan=2>' .. bitsToSize(stats["95th_percentile"]*8) .. '</td></tr>\n')
-     print('   <tr><th>Total Traffic</th><td colspan=2>' .. bytesToSize(stats.total) .. '</td></tr>\n')
-  end
+      formatter_fctn = (is_system_interface and "NtopUtils.fnone" or "NtopUtils.fbits")
+   end
 
-end
+   print [[
+   <table class="table table-bordered table-striped" style="border: 1rem; margin-right: 1rem; display: table-cell">
+   ]]
 
-print('   <tr><th>Time</th><td colspan=2><div id=when></div></td></tr>\n')
+   print('   <tr><th>&nbsp;</th><th>Time</th><th>Value</th></tr>\n')
 
--- hide Minute Interface Top Talker if we are in system interface
-if top_talkers_utils.areTopEnabled(ifid) and not is_system_interface then
-   print('   <tr><th>Minute<br>Interface<br>Top Talkers</th><td colspan=2><div id=talkers></div></td></tr>\n')
-end
+   local stats = data.statistics
+
+   if(stats ~= nil) then
+      local minval_time = stats.min_val_idx and (data.start + data.step * stats.min_val_idx) or 0
+      local maxval_time = stats.max_val_idx and (data.start + data.step * stats.max_val_idx) or 0
+      local lastval_time = data.start + data.step * (data.count-1)
+      local lastval = 0
+
+      for _, serie in pairs(data.series) do
+         lastval = lastval + (serie.data[data.count] or 0)
+      end
+
+      if format_as_bytes then
+         if(minval_time > 0) then print('   <tr><th>Min</th><td>' .. os.date("%x %X", minval_time) .. '</td><td>' .. bytesToSize((stats.min_val*8) or "") .. '</td></tr>\n') end
+         if(maxval_time > 0) then print('   <tr><th>Max</th><td>' .. os.date("%x %X", maxval_time) .. '</td><td>' .. bytesToSize((stats.max_val*8) or "") .. '</td></tr>\n') end
+         print('   <tr><th>Last</th><td>' .. os.date("%x %X", lastval_time) .. '</td><td>' .. bytesToSize(lastval*8)  .. '</td></tr>\n')
+         print('   <tr><th>Average</th><td colspan=2>' .. bytesToSize(stats.average*8) .. '</td></tr>\n')
+         print('   <tr><th>95th <A HREF=https://en.wikipedia.org/wiki/Percentile>Percentile</A></th><td colspan=2>' .. bytesToSize(stats["95th_percentile"]*8) .. '</td></tr>\n')
+      elseif(not format_as_bps) then
+         if(minval_time > 0) then print('   <tr><th>Min</th><td>' .. os.date("%x %X", minval_time) .. '</td><td>' .. formatValue(stats.min_val or "") .. '</td></tr>\n') end
+         if(maxval_time > 0) then print('   <tr><th>Max</th><td>' .. os.date("%x %X", maxval_time) .. '</td><td>' .. formatValue(stats.max_val or "") .. '</td></tr>\n') end
+         print('   <tr><th>Last</th><td>' .. os.date("%x %X", lastval_time) .. '</td><td>' .. formatValue(round(lastval), 1) .. '</td></tr>\n')
+         print('   <tr><th>Average</th><td colspan=2>' .. formatValue(round(stats.average, 2)) .. '</td></tr>\n')
+         print('   <tr><th>95th <A HREF=https://en.wikipedia.org/wiki/Percentile>Percentile</A></th><td colspan=2>' .. formatValue(round(stats["95th_percentile"], 2)) .. '</td></tr>\n')
+      elseif is_system_interface then
+         if(minval_time > 0) then print('   <tr><th>Min</th><td>' .. os.date("%x %X", minval_time) .. '</td><td>' .. (formatValue(round(stats["min_val"], 2)) or "") .. '</td></tr>\n') end
+         if(maxval_time > 0) then print('   <tr><th>Max</th><td>' .. os.date("%x %X", maxval_time) .. '</td><td>' .. (formatValue(round(stats["max_val"], 2)) or "") .. '</td></tr>\n') end
+         print('   <tr><th>Last</th><td>' .. os.date("%x %X", lastval_time) .. '</td><td>' .. formatValue(round(lastval, 2)) .. '</td></tr>\n')
+         print('   <tr><th>Average</th><td colspan=2>' ..formatValue(round(stats["average"], 2)).. '</td></tr>\n')
+         print('   <tr><th>95th <A HREF=https://en.wikipedia.org/wiki/Percentile>Percentile</A></th><td colspan=2>' ..(formatValue(round(stats["95th_percentile"], 2)) or '') .. '</td></tr>\n')
+         print('   <tr><th>Total Traffic</th><td colspan=2>' .. (stats.total or '') .. '</td></tr>\n')
+      else
+         if(minval_time > 0) then print('   <tr><th>Min</th><td>' .. os.date("%x %X", minval_time) .. '</td><td>' .. bitsToSize((stats.min_val*8) or "") .. '</td></tr>\n') end
+         if(maxval_time > 0) then print('   <tr><th>Max</th><td>' .. os.date("%x %X", maxval_time) .. '</td><td>' .. bitsToSize((stats.max_val*8) or "") .. '</td></tr>\n') end
+         print('   <tr><th>Last</th><td>' .. os.date("%x %X", lastval_time) .. '</td><td>' .. bitsToSize(lastval*8)  .. '</td></tr>\n')
+         print('   <tr><th>Average</th><td colspan=2>' .. bitsToSize(stats.average*8) .. '</td></tr>\n')
+         print('   <tr><th>95th <A HREF=https://en.wikipedia.org/wiki/Percentile>Percentile</A></th><td colspan=2>' .. bitsToSize(stats["95th_percentile"]*8) .. '</td></tr>\n')
+         print('   <tr><th>Total Traffic</th><td colspan=2>' .. bytesToSize(stats.total) .. '</td></tr>\n')
+      end
+   end
+
+   print('   <tr><th>Time</th><td colspan=2><div id=when></div></td></tr>\n')
+
+   -- hide Minute Interface Top Talker if we are in system interface
+   if top_talkers_utils.areTopEnabled(ifid) and not is_system_interface then
+      print('   <tr><th>Minute<br>Interface<br>Top Talkers</th><td colspan=2><div id=talkers></div></td></tr>\n')
+   end
 
 
-print [[
+   print [[
    </table>
-]]
+   ]]
 
-print[[</div></td></tr></table>
+   print[[</div></td></tr></table>
 
     </div> <!-- closes div id "historical-tab-chart "-->
-]]
+   ]]
 
-if show_historical_tabs then
-   local host = tags.host -- can be nil
-   local l7proto = tags.protocol or ""
-   local k2info = hostkey2hostinfo(host)
-
-   print('<div class="tab-pane" id="historical-flows">')
-   if tonumber(start_time) ~= nil and tonumber(end_time) ~= nil then
-      -- if both start_time and end_time are vaid epoch we can print finer-grained top flows
-      historicalFlowsTab(ifid, k2info["host"] or '', start_time, end_time, l7proto, '', '', '', k2info["vlan"])
-   else
-      printGraphTopFlows(ifid, k2info["host"] or '', _GET["epoch"], zoomLevel, l7proto, k2info["vlan"])
-   end
-   print('</div>')
-end
-
-print[[
+   print[[
   </div> <!-- closes div class "tab-content" -->
   </div>
 </div> <!-- closes div class "card" -->]]
 
-local ui_utils = require("ui_utils")
-print(ui_utils.render_notes(options.notes))
+   local ui_utils = require("ui_utils")
+   print(ui_utils.render_notes(options.notes))
 
-print[[
+   print[[
 <script>
 
 var palette = new Rickshaw.Color.Palette();
 
 var graph = new Rickshaw.Graph( {
 				   element: document.getElementById("chart"),
-				   width: 600,
-				   height: 300,
+				   width: 750,
+               stroke: true,
+               min: 'auto',
+               padding: {top: 0.02, bottom: 0.02},
+				   height: 350,
 				   renderer: 'area',
 				   series: [
 				]]
 
-for serie_idx, serie in ipairs(data.series) do
-   print("{name: \"" .. serie.label .. "\"")
-   print("\n, color: '".. graph_colors[serie_idx] .."', data: [")
+   for serie_idx, serie in ipairs(data.series) do
+      print("{name: \"" .. serie.label .. "\"")
+      print("\n, color: '".. graph_utils.graph_colors[serie_idx] .."', data: [")
 
-   local t = data.start
+      local t = data.start
 
-   for i, val in ipairs(serie.data) do
-      print("{x: " .. t)
-      if (format_as_bps) then
-        print(",y: " .. (val*8) .. "},\n")
-      else
-        print(",y: " .. val .. "},\n")
+      for i, val in ipairs(serie.data) do
+         print("{x: " .. t)
+         if (format_as_bps) then
+            print(",y: " .. (val*8) .. "},\n")
+         else
+            print(",y: " .. val .. "},\n")
+         end
+         t = t + data.step
       end
-      t = t + data.step
+
+      print("]},")
    end
 
-   print("]},")
-end
-
-print [[
+   print [[
 				]} );
 
 graph.render();
@@ -681,30 +665,29 @@ var chart_legend = document.querySelector('#chart_legend');
 
 var Hover = Rickshaw.Class.create(Rickshaw.Graph.HoverDetail, {
     graph: graph,
-    xFormatter: function(x) { return new Date( x * 1000 ); },
+    xFormatter: function(x) { return NtopUtils.epoch2Seen(x); },
     yFormatter: function(bits) { return(]] print(formatter_fctn) print [[(bits)); },
     render: function(args) {
 		var graph = this.graph;
 		var points = args.points;
 		var point = points.filter( function(p) { return p.active } ).shift();
+      if(point.value.y === null) return;
 
-		if(point.value.y === null) return;
-
-		var formattedXValue = NtopUtils.fdate(point.value.x); // point.formattedXValue;
+		var formattedXValue = NtopUtils.epoch2Seen(point.value.x); // point.formattedXValue;
 		var formattedYValue = ]]
-	  print(formatter_fctn)
-	  print [[(point.value.y); // point.formattedYValue;
+   print(formatter_fctn)
+   print [[(point.value.y); // point.formattedYValue;
 		var infoHTML = "";
 ]]
 
-print[[
+   print[[
 
 infoHTML += "<ul>";
 $.ajax({
 	  type: 'GET',
 	  url: ']]
-	  print(ntop.getHttpPrefix().."/lua/get_top_talkers.lua?epoch='+point.value.x+'&addvlan=true")
-	    print [[',
+   print(ntop.getHttpPrefix().."/lua/get_top_talkers.lua?epoch='+point.value.x+'&addvlan=true")
+   print [[',
 		  data: { epoch: point.value.x },
 		  async: false,
 		  success: function(content) {
@@ -734,7 +717,7 @@ $.ajax({
    });
 infoHTML += "</ul>";]]
 
-print [[
+   print [[
 		this.element.innerHTML = '';
 		this.element.style.left = graph.x(point.value.x) + 'px';
 
@@ -752,6 +735,8 @@ print [[
 
 		item.className = 'item';
 		item.innerHTML = this.formatter(point.series, point.value.x, point.value.y, formattedXValue, formattedYValue, point);
+      let tmp = item.innerHTML;
+      item.innerHTML = formattedXValue + "<br>" + tmp;
 		item.style.top = this.graph.y(point.value.y0 + point.value.y) + 'px';
 		this.element.appendChild(item);
 
@@ -792,38 +777,38 @@ var legend = new Rickshaw.Graph.Legend( {
 
 var yAxis = new Rickshaw.Graph.Axis.Y({
     graph: graph,
+    padding: { top: 0.02, bottom: 0.02 },
     tickFormat: ]] print(formatter_fctn) print [[
 });
 
 yAxis.render();
 
 ]]
-
-if zoomLevel ~= nextZoomLevel then
-print[[
+   if zoomLevel ~= nextZoomLevel then
+      print[[
 $("#chart").click(function() {
   if(hover.selected_epoch)
     window.location.href = ']]
-print(baseurl .. '&ts_schema=' .. schema .. '&zoom=' .. nextZoomLevel)
+      print(baseurl .. '&ts_schema=' .. schema .. '&zoom=' .. nextZoomLevel)
 
-if tags.protocol ~= nil then
-   print("&protocol=" .. tags.protocol)
-elseif tags.category ~= nil then
-   print("&category=" .. tags.category)
-end
+      if tags.protocol ~= nil then
+         print("&protocol=" .. tags.protocol)
+      elseif tags.category ~= nil then
+         print("&category=" .. tags.category)
+      end
 
-print('&epoch=')
-print[['+hover.selected_epoch;
+      print('&epoch=')
+      print[['+hover.selected_epoch;
 });]]
-end
+   end
 
-print[[
+   print[[
 </script>
 
 ]]
-else
-   print("<div class=\"alert alert-danger\"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png> No data found</div>")
-end -- if(data)
+   else
+      print("<div class=\"alert alert-danger\"><i class='fas fa-exclamation-triangle fa-lg fa-ntopng-warning'></i> No data found</div>")
+   end -- if(data)
 end
 
 -- #################################################
@@ -871,7 +856,7 @@ function graph_utils.printProtocolQuota(proto, ndpi_stats, category_stats, quota
       if not traffic_quota_ratio then traffic_quota_ratio = 0 end
 
       if show_td then
-        output[#output + 1] = [[<td class='text-right']]..ternary(bytes_exceeded, ' style=\'color:red;\'', '').."><span>"..lb_bytes..ternary(hide_limit, "", " / "..lb_bytes_quota).."</span>"
+        output[#output + 1] = [[<td class='text-end']]..ternary(bytes_exceeded, ' style=\'color:red;\'', '').."><span>"..lb_bytes..ternary(hide_limit, "", " / "..lb_bytes_quota).."</span>"
       end
 
       output[#output + 1] = [[
@@ -893,7 +878,7 @@ function graph_utils.printProtocolQuota(proto, ndpi_stats, category_stats, quota
       local duration_quota_ratio = round(duration_taken * 100 / (duration_taken+duration_remaining), 0) or 0
 
       if show_td then
-        output[#output + 1] = [[<td class='text-right']]..ternary(time_exceeded, ' style=\'color:red;\'', '').."><span>"..lb_duration..ternary(hide_limit, "", " / "..lb_duration_quota).."</span>"
+        output[#output + 1] = [[<td class='text-end']]..ternary(time_exceeded, ' style=\'color:red;\'', '').."><span>"..lb_duration..ternary(hide_limit, "", " / "..lb_duration_quota).."</span>"
       end
 
       output[#output + 1] = ([[
@@ -911,6 +896,7 @@ end
 -- #################################################
 
 function graph_utils.poolDropdown(ifId, pool_id, exclude)
+   local host_pools = require "host_pools"
    local host_pools_instance = host_pools:create()
    pool_id = tostring(pool_id)
 
@@ -956,7 +942,7 @@ function graph_utils.printPoolChangeDropdown(ifId, pool_id, have_nedge)
    output[#output + 1] = [[<tr>
       <th>]] .. i18n(ternary(have_nedge, "nedge.user", "host_config.host_pool")) .. [[</th>
       <td>
-            <select name="pool" class="form-control" style="width:20em; display:inline;">]]
+            <select name="pool" class="form-select" style="width:20em; display:inline;">]]
 
    output[#output + 1] = graph_utils.poolDropdown(ifId, pool_id)
 
@@ -964,7 +950,7 @@ function graph_utils.printPoolChangeDropdown(ifId, pool_id, have_nedge)
 
    output[#output + 1] = [[
             </select>
-        <a class='ml-1' href="]] .. ntop.getHttpPrefix() .. edit_pools_link .. [["><i class="fas fa-edit" aria-hidden="true" title="]]
+        <a class='ms-1' href="]] .. ntop.getHttpPrefix() .. edit_pools_link .. [["><i class="fas fa-edit" aria-hidden="true" title="]]
       ..(have_nedge and i18n("edit") or '')
       .. [["></i></a>
    </tr>]]
@@ -984,7 +970,7 @@ function graph_utils.printCategoryDropdownButton(by_id, cat_id_or_name, base_url
    count_callback = count_callback or count_all
 
    -- 'Category' button
-   print('\'<div class="btn-group float-right"><div class="btn btn-link dropdown-toggle" data-toggle="dropdown">'..
+   print('\'<div class="btn-group float-right"><div class="btn btn-link dropdown-toggle" data-bs-toggle="dropdown">'..
          i18n("category") .. ternary(not isEmptyString(cat_id_or_name), '<span class="fas fa-filter"></span>', '') ..
          '<span class="caret"></span></div> <ul class="dropdown-menu scrollable-dropdown" role="menu" style="min-width: 90px;">')
 
@@ -1032,25 +1018,21 @@ local default_timeseries = {
    {schema="iface:new_flows",             label=i18n("graphs.new_flows"), value_formatter = {"NtopUtils.fflows", "NtopUtils.formatFlows"}},
    {schema="iface:alerted_flows",         label=i18n("graphs.total_alerted_flows")},
    {schema="iface:hosts",                 label=i18n("graphs.active_hosts")},
-   {schema="iface:alerts_stats",          label=i18n("show_alerts.iface_engaged_dropped_alerts"), skip=hasAllowedNetworksSet()},
+   {schema="iface:engaged_alerts",        label=i18n("show_alerts.engaged_alerts"), metrics_labels = { i18n("show_alerts.engaged_alerts") }, skip=hasAllowedNetworksSet()},
+   {schema="iface:dropped_alerts",        label=i18n("show_alerts.dropped_alerts"), metrics_labels = { i18n("show_alerts.dropped_alerts") }, skip=hasAllowedNetworksSet()},
    {schema="custom:flows_vs_local_hosts", label=i18n("graphs.flows_vs_local_hosts"), check={"iface:flows", "iface:local_hosts"}, step=60},
    {schema="custom:flows_vs_traffic",     label=i18n("graphs.flows_vs_traffic"), check={"iface:flows", "iface:traffic"}, step=60},
    {schema="custom:memory_vs_flows_hosts", label=i18n("graphs.memory_vs_hosts_flows"), check={"process:resident_memory", "iface:flows", "iface:hosts"}},
    {schema="iface:devices",               label=i18n("graphs.active_devices")},
    {schema="iface:http_hosts",            label=i18n("graphs.active_http_servers"), nedge_exclude=1},
    {schema="iface:traffic",               label=i18n("traffic")},
-   {schema="iface:score",                 label=i18n("score"), enterprise_only=true},
-   {schema="iface:traffic_rxtx",          label=i18n("graphs.traffic_txrx"), layout={
-      ["bytes_sent"] = "area",
-      ["bytes_rcvd"] = "line"
-   } },
-
-   {schema="iface:1d_delta_traffic_volume",  label="1 Day Traffic Delta"}, -- TODO localize
-   {schema="iface:1d_delta_flows",           label="1 Day Active Flows Delta"}, -- TODO localize
-
+   {schema="iface:score",                 label=i18n("score"), metrics_labels = { i18n("graphs.cli_score"), i18n("graphs.srv_score")}},
+   {schema="custom:score_vs_flows_hosts",  label=i18n("graphs.score_vs_hosts_flows"), check={"iface:score", "iface:flows", "iface:hosts"}, metrics_labels = { i18n("graphs.cli_score"), i18n("graphs.srv_score")}},
+   {schema="iface:traffic_rxtx",          label=i18n("graphs.traffic_rxtx"), split_directions = true, layout={ ["bytes_sent"] = "area", ["bytes_rcvd"] = "line" }, value_formatter = {"NtopUtils.fbits_from_bytes", "NtopUtils.bytesToSize"} },
    {schema="iface:packets_vs_drops",      label=i18n("graphs.packets_vs_drops")},
    {schema="iface:nfq_pct",               label=i18n("graphs.num_nfq_pct"), nedge_only=1},
-
+   {schema="iface:hosts_anomalies",       label=i18n("graphs.hosts_anomalies"), layout={ ["num_local_hosts_anomalies"] = "area", ["num_remote_hosts_anomalies"] = "area" }, metrics_labels = { i18n("graphs.loc_host_anomalies"), i18n("graphs.rem_host_anomalies")}  },
+      
    {schema="iface:disc_prob_bytes",       label=i18n("graphs.discarded_probing_bytes"), nedge_exclude=1},
    {schema="iface:disc_prob_pkts",        label=i18n("graphs.discarded_probing_packets"), nedge_exclude=1},
 
@@ -1073,6 +1055,18 @@ local default_timeseries = {
    {schema="iface:tcp_rst",               label=i18n("graphs.tcp_rst_packets"), nedge_exclude=1},
 }
 
+if ntop.isPro() then
+   local pro_timeseries = {
+      {schema="iface:score_anomalies",       label=i18n("graphs.iface_score_anomalies")},
+      {schema="iface:score_behavior",        label=i18n("graphs.iface_score_behavior"), split_directions = true --[[ split RX and TX directions ]], first_timeseries_only = true, metrics_labels = {i18n("graphs.score"), i18n("graphs.lower_bound"), i18n("graphs.upper_bound")}},
+      {schema="iface:traffic_anomalies",     label=i18n("graphs.iface_traffic_anomalies")},
+      {schema="iface:traffic_rx_behavior_v2",   label=i18n("graphs.iface_traffic_rx_behavior"), split_directions = true --[[ split RX and TX directions ]], first_timeseries_only = true, time_elapsed = iface_behavior_update_freq, value_formatter = {"NtopUtils.fbits_from_bytes", "NtopUtils.bytesToSize"}, metrics_labels = {i18n("graphs.traffic_rcvd"), i18n("graphs.lower_bound"), i18n("graphs.upper_bound")}},
+      {schema="iface:traffic_tx_behavior_v2",   label=i18n("graphs.iface_traffic_tx_behavior"), split_directions = true --[[ split RX and TX directions ]], first_timeseries_only = true, time_elapsed = iface_behavior_update_freq, value_formatter = {"NtopUtils.fbits_from_bytes", "NtopUtils.bytesToSize"}, metrics_labels = {i18n("graphs.traffic_sent"), i18n("graphs.lower_bound"), i18n("graphs.upper_bound")}},
+   }
+
+   default_timeseries = table.merge(pro_timeseries, default_timeseries)
+end
+
 -- #################################################
 
 function graph_utils.get_default_timeseries()
