@@ -1,5 +1,5 @@
 --
--- (C) 2018 - ntop.org
+-- (C) 2021 - ntop.org
 --
 
 -- This file contains a small set of utility functions
@@ -24,6 +24,30 @@ end
 
 -- ##############################################
 
+-- @Brief Checks if a dotted-decimal SNMP OID starts with another dotted-decimal SNMP OID
+-- @param oid_string The string-encoded dotted-decimal SNMP OID to check
+-- @param oid_string_start A string-encoded dotted-decimal SNMP OID prefix
+-- @return True if `oid_string` starts with `oid_string_start` or false otherwise
+function string.oid_starts(oid_string, oid_string_start)
+   if type(oid_string) ~= 'string' or type(oid_string_start) ~= 'string' then
+      return false
+   end
+
+   -- Make sure both OIDs end with a dot, to avoid
+   -- considering 1.3.6.1.4.1.99 starting with 1.3.6.1.4.1.9
+   if not string.ends(oid_string, ".") then
+      oid_string = oid_string.."."
+   end
+
+   if not string.ends(oid_string_start, ".") then
+      oid_string_start = oid_string_start.."."
+   end
+
+   return string.sub(oid_string , 1, string.len(oid_string_start)) == oid_string_start
+end
+
+-- ##############################################
+
 -- Print contents of `tbl`, with indentation.
 -- You can call it as tprint(mytable)
 -- The other two parameters should not be set
@@ -81,6 +105,33 @@ end
 
 -- ##############################################
 
+-- NOTE: on index based tables using #table is much more performant
+function table.len(tbl)
+ local count = 0
+
+  if(tbl == nil) then return(0) end
+
+  for k,v in pairs(tbl) do
+    count = count + 1
+  end
+
+  return count
+end
+
+-- ##############################################
+
+function table.slice(tbl, first, last, step)
+   local sliced = {}
+
+   for i = first or 1, last or #tbl, step or 1 do
+      sliced[#sliced+1] = tbl[i]
+   end
+
+   return sliced
+end
+
+-- ##############################################
+
 function table.empty(tbl)
   if(tbl == nil) then return true end
 
@@ -212,12 +263,26 @@ end
 -- ##############################################
 
 function asc(a,b)
-  return (a < b)
+   if a == nil or b == nil then
+      return false
+   elseif type(a) ~= type(b) then
+      traceError(TRACE_WARNING, TRACE_CONSOLE, "Bad types in asc(): " .. a .. " (".. type(a) ..") vs " .. b .. " (".. type(b) .. ")")
+      return false
+   end
+
+   return (a < b)
 end
 
 -- ##############################################
 
 function rev(a,b)
+   if a == nil or b == nil then
+      return false
+   elseif type(a) ~= type(b) then
+      traceError(TRACE_WARNING, TRACE_CONSOLE, "Bad types in rev(): " .. a .. " (".. type(a) ..") vs " .. b .. " (".. type(b) .. ")")
+      return false
+   end
+
    return (a > b)
 end
 
