@@ -1,9 +1,10 @@
 --
--- (C) 2019-20 - ntop.org
+-- (C) 2019-22 - ntop.org
 --
 
 local dirs = ntop.getDirs()
-package.path = dirs.installdir .. "/scripts/lua/modules/recipients/?.lua;" .. package.path
+package.path = dirs.installdir .. "/scripts/lua/modules/notifications/?.lua;" .. package.path
+
 
 local plugins_utils = {}
 local os_utils = require("os_utils")
@@ -11,6 +12,7 @@ local persistence = require("persistence")
 local file_utils = require("file_utils")
 local template_utils = require("template_utils")
 local lua_path_utils = require("lua_path_utils")
+local ntop_utils = require "ntop_utils"
 require "lua_trace"
 
 local dirs = ntop.getDirs()
@@ -18,6 +20,9 @@ local dirs = ntop.getDirs()
 -- enable debug tracing
 local do_trace = false
 
+-- How deep the recursive plugins search should go into subdirectories
+local MAX_RECURSION = 2
+
 plugins_utils.COMMUNITY_SOURCE_DIR = os_utils.fixPath(dirs.scriptdir .. "/plugins")
 plugins_utils.PRO_SOURCE_DIR = os_utils.fixPath(dirs.installdir .. "/pro/scripts/pro_plugins")
 plugins_utils.ENTERPRISE_M_SOURCE_DIR = os_utils.fixPath(dirs.installdir .. "/pro/scripts/enterprise_m_plugins")
@@ -73,8 +78,9 @@ end
 local function recursivePluginsSearch(edition, source_dir, max_recursion, plugins, plugins_with_deps)
    -- Prepend the current `source_dir` to the Lua path - this is necessary for doing the require
    lua_path_utils.package_path_prepend(source_dir)
+   local source_dir_contents = ntop.readdir(source_dir)
 
-   for plugin_name in pairs(ntop.readdir(source_dir)) do
+   for plugin_name in pairs(source_dir_contents) do
       local plugin_dir = os_utils.fixPath(source_dir .. "/" .. plugin_name)
       local plugin_info = os_utils.fixPath(plugin_dir .. "/manifest.lua")
 
@@ -111,9 +117,14 @@ local function recursivePluginsSearch(edition, source_dir, max_recursion, plugin
 	 else
 	    plugins[plugin_name] = metadata
 	 end
-      elseif ntop.isdir(plugin_dir) and max_recursion > 0 then
-	 -- Recursively see if this is a directory containing other plugins
-	 recursivePluginsSearch(edition, plugin_dir, max_recursion - 1, plugins, plugins_with_deps)
+      elseif ntop.isdir(plugin_dir) then
+	 if max_recursion > 0 then
+	    -- Recursively see if this is a directory containing other plugins
+	    recursivePluginsSearch(edition, plugin_dir, max_recursion - 1, plugins, plugins_with_deps)
+	 else
+	    -- Maximum recursion hit. must stop
+	    traceError(TRACE_INFO, TRACE_CONSOLE, string.format("Unable to load '%s'. Too many recursion levels.", plugin_dir))
+	 end
       end
 
       ::continue::
@@ -147,7 +158,7 @@ local function listPlugins(community_plugins_only)
       local edition = source_conf[1]
       local source_dir = source_conf[2]
 
-      recursivePluginsSearch(edition, source_dir, 3, plugins, plugins_with_deps)
+      recursivePluginsSearch(edition, source_dir, MAX_RECURSION, plugins, plugins_with_deps)
    end
 
    -- Add plugins without dependencies to the result
@@ -189,8 +200,7 @@ local function init_runtime_paths()
   RUNTIME_PATHS = {
     -- Definitions
     alert_definitions = os_utils.fixPath(runtime_path .. "/alert_definitions"),
-    status_definitions = os_utils.fixPath(runtime_path .. "/status_definitions"),
-    pro_status_definitions = os_utils.fixPath(runtime_path .. "/status_definitions/pro"),
+    check_definitions = os_utils.fixPath(runtime_path .. "/check_definitions"),
 
     -- Locales
     locales = os_utils.fixPath(runtime_path .. "/locales"),
@@ -216,7 +226,7 @@ local function init_runtime_paths()
     modules = os_utils.fixPath(runtime_path) .. "/modules",
     httpdocs = os_utils.fixPath(runtime_path) .. "/httpdocs",
 
-    -- User scripts
+    -- Checks
     interface_scripts = os_utils.fixPath(runtime_path .. "/callbacks/interface/interface"),
     host_scripts = os_utils.fixPath(runtime_path .. "/callbacks/interface/host"),
     network_scripts = os_utils.fixPath(runtime_path .. "/callbacks/interface/network"),
@@ -253,8 +263,14 @@ local function load_definitions(defs_dir, runtime_path)
 	    return(false)
 	 end
 
-	 -- tprint({"copying", fname, defs_dir, runtime_path})
-	 file_utils.copy_file(fname, defs_dir, runtime_path)
+	 local ntopng_alert_definition = os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/alert_definitions/"..fname)
+	 if ntop.exists(ntopng_alert_definition) then
+	    -- Prevent plugin alert definitions from overwriting alert definitions under modules
+	    traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Cannot copy plugin alert definition from %s (alert already defined in %s)", full_path, ntopng_alert_definition))
+	 else
+	    -- tprint({"copying", fname, defs_dir, runtime_path})
+	    file_utils.copy_file(fname, defs_dir, runtime_path)
+	 end
       end
    end
 
@@ -263,7 +279,7 @@ end
 
 -- ##############################################
 
-local function load_plugin_alert_definitions(plugin)
+local function load_plugin_definitions(plugin)
   -- Reset all the possibly existing (and loaded) definitions
   -- as new alert definitions are being loaded
   local alert_consts = require "alert_consts"
@@ -278,31 +294,6 @@ end
 
 -- ##############################################
 
-local function load_plugin_flow_status_definitions(plugin)
-  -- Reset all the possibly existing (and loaded) flow statuses.
-  -- This is necessary to forcefully re-execute `require`s during
-  -- the load of new flows statuses which is being performed
-  local flow_consts = require "flow_consts"
-  flow_consts.resetDefinitions()
-
-
-  -- Now that existing flow statuses have been cleaned, it is
-  -- safe to load new ones
-  local status_definitions
-
-  if(plugin.edition == "community") then
-    status_definitions = RUNTIME_PATHS.status_definitions
-  else
-    -- It's necessary to split pro plugins to avoid errors on demo mode end
-    -- while loading pro scripts
-    status_definitions = RUNTIME_PATHS.pro_status_definitions
-  end
-
-  return load_definitions(os_utils.fixPath(plugin.path .. "/status_definitions"), status_definitions)
-end
-
--- ##############################################
-
 local function load_plugin_ts_schemas(plugin)
   local src_path = os_utils.fixPath(plugin.path .. "/ts_schemas")
   local ts_path = os_utils.fixPath(RUNTIME_PATHS.ts_schemas .. "/" .. plugin.key)
@@ -374,8 +365,8 @@ end
 
 -- ##############################################
 
-local function load_plugin_user_scripts(paths_to_plugin, plugin)
-  local scripts_path = os_utils.fixPath(plugin.path .. "/user_scripts")
+local function load_plugin_checks(paths_to_plugin, plugin)
+  local scripts_path = os_utils.fixPath(plugin.path .. "/checks")
   local paths_map = {}
   local extn = ".lua"
   local rv = (
@@ -410,6 +401,7 @@ end
 
 local function load_plugin_alert_endpoints(plugin)
    local endpoints_path = os_utils.fixPath(plugin.path .. "/alert_endpoints")
+   local endpoints_template_path = os_utils.fixPath(plugin.path .. "/templates")
 
    if not ntop.exists(endpoints_path) then
       -- No alert endpoints for this plugin
@@ -422,13 +414,43 @@ local function load_plugin_alert_endpoints(plugin)
 	 local fname_path = os_utils.fixPath(endpoints_path .. "/" .. fname)
 	 local endpoint = load_plugin_file(fname_path)
 
-	 if endpoint and endpoint.onLoad then
-	    endpoint.onLoad()
+	 if not endpoint then
+	    traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Unable to load endpoint '%s'", fname))
+	    return false
+	 end
+
+	 -- Check for configuration templates existence
+	 if endpoint.endpoint_template and endpoint.endpoint_template.template_name then
+	    -- Stop if the template doesn't exist
+	    if not ntop.exists(os_utils.fixPath(endpoints_template_path.."/"..endpoint.endpoint_template.template_name)) then
+	       traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Missing conf template '%s' in '%s' for endpoint '%s'",
+								    endpoint.endpoint_template.template_name,
+								    endpoints_template_path,
+								    fname))
+	       return false
+	    end
+	 end
+
+	 -- Check for recipient templates existence
+	 if endpoint.recipient_template and endpoint.recipient_template.template_name then
+	    -- Return if the recipient template doesn't exist
+	    if not ntop.exists(os_utils.fixPath(endpoints_template_path.."/"..endpoint.recipient_template.template_name)) then
+	       traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Missing recipient template '%s' in '%s' for endpoint '%s'",
+								    endpoint.recipient_template.template_name,
+								    endpoints_template_path,
+								    fname))
+	       return false
+	    end
 	 end
 
 	 if not file_utils.copy_file(fname, endpoints_path, RUNTIME_PATHS.alert_endpoints) then
 	    return false
 	 end
+
+
+	 if endpoint and endpoint.onLoad then
+	    endpoint.onLoad()
+	 end
       end
    end
 
@@ -507,7 +529,7 @@ local function load_plugin_other(plugin)
   local rv = true
 
   if ntop.exists(templates_dir) then
-    local path = os_utils.fixPath(RUNTIME_PATHS.templates.. "/" ..plugin.key)
+    local path = plugins_utils.getPluginTemplatesDir(plugin.key)
     ntop.mkdir(path)
     rv = rv and file_utils.recursive_copy(templates_dir, path)
   end
@@ -580,7 +602,7 @@ function plugins_utils.loadPlugins(community_plugins_only)
   -- alert definitions MUST be loaded before flow status definitions as, flow status definitions,
   -- may depend on alert definitions
   for _, plugin in ipairs(plugins) do
-     load_plugin_alert_definitions(plugin)
+     load_plugin_definitions(plugin)
   end
 
   -- Make sure to invalidate the (possibly) already required alert_consts which depends on alert definitions.
@@ -588,11 +610,6 @@ function plugins_utils.loadPlugins(community_plugins_only)
   -- subsequent `require "alert_consts"`
   package.loaded["alert_consts"] = nil
 
-  -- Load plugin flow status definitions, i.e., definitions found under <plugin_name>/status_definitions
-  for _, plugin in ipairs(plugins) do
-     load_plugin_flow_status_definitions(plugin)
-  end
-
   -- Load the plugins following the dependecies order
   for _, plugin in ipairs(plugins) do
     if community_plugins_only and plugin.edition ~= "community" then
@@ -617,7 +634,7 @@ function plugins_utils.loadPlugins(community_plugins_only)
         load_plugin_web_gui(plugin) and
         load_plugin_data_dirs(plugin) and
         load_plugin_other(plugin) and
-        load_plugin_user_scripts(path_map, plugin) and
+        load_plugin_checks(path_map, plugin) and
         load_plugin_alert_endpoints(plugin) then
       loaded_plugins[plugin.key] = plugin
     else
@@ -641,24 +658,19 @@ function plugins_utils.loadPlugins(community_plugins_only)
     plugins = loaded_plugins,
     path_map = path_map,
   }
+
   persistence.store(getMetadataPath(), plugins_metadata)
   ntop.setDefaultFilePermissions(getMetadataPath())
 
   -- Swap the active plugins directory with the shadow
   clearInternalState()
   ntop.swapPluginsDir()
-  deleteCachePattern("ntonpng.cache.user_scripts.available_system_modules.*")
+  deleteCachePattern("ntonpng.cache.checks.available_system_modules.*")
 
-  -- Reload the periodic scripts to load the new plugins
-  ntop.reloadPeriodicScripts()
-
-  -- Mark a change in recipients so they will be automatically reloaded
-  local recipients = require "recipients"
-  recipients.set_recipients_change()
-
-  -- Reload user scripts with their configurations
-  local user_scripts = require "user_scripts"
-  user_scripts.loadUnloadUserScripts(true --[[ load --]])
+  -- Reload checks with their configurations
+  local checks = require "checks"
+  checks.initDefaultConfig()
+  checks.loadUnloadUserScripts(true --[[ load --]])
 
   return(true)
 end
@@ -711,33 +723,6 @@ end
 
 -- ##############################################
 
-function plugins_utils.checkReloadPlugins(when)
-   local demo_ends_at = ntop.getInfo()["pro.demo_ends_at"]
-   local time_delta = demo_ends_at - when
-   local plugins_reloaded = false
-
-   -- tprint({time_delta = time_delta, demo_ends_at = demo_ends_at, when = when, is_pro = ntop.isPro()})
-
-   if ntop.getCache('ntopng.cache.force_reload_plugins') == '1' then
-      -- Check and possibly reload plugins after a user has changed (e.g., applied or removed) a license
-      -- from the web user interface (page about.lua)
-      plugins_utils.loadPlugins(not ntop.isPro() --[[ reload only community if license is not pro --]])
-      ntop.delCache('ntopng.cache.force_reload_plugins')
-      plugins_reloaded = true
-   elseif demo_ends_at and demo_ends_at > 0 and time_delta <= 10 and ntop.isPro() and not ntop.hasPluginsReloaded() then
-      -- Checks and possibly reload plugins for demo licenses. In case of demo licenses,
-      -- if within 10 seconds from the license expirations, a plugin reload is executed only for the community plugins
-      plugins_utils.loadPlugins(true --[[ reload only community plugins --]])
-      plugins_reloaded = true
-   end
-
-   if plugins_reloaded then
-      ntop.reloadPlugins()
-   end
-end
-
--- ##############################################
-
 function plugins_utils.getMenuEntries()
   init_runtime_paths()
   local menu = {}
@@ -769,26 +754,14 @@ end
 
 -- ##############################################
 
-function plugins_utils.getUrl(script)
-  return(ntop.getHttpPrefix() .. "/plugins/" .. script)
+function plugins_utils.getMonitorUrl(script)
+  return(ntop.getHttpPrefix() .. "/lua/monitor/" .. script)
 end
 
 -- ##############################################
 
-function plugins_utils.hasAlerts(ifid, options)
-  -- Requiring alert_utils here to optimize second.lua
-  local alert_utils = require("alert_utils")
-
-  local opts = table.merge(options, {ifid = ifid})
-  local old_ifid = interface.getId()
-  local rv
-  interface.select(ifid)
-
-  rv = (areAlertsEnabled() and
-    (alert_utils.hasAlerts("historical", alert_utils.getTabParameters(opts, "historical")) or
-	alert_utils.hasAlerts("engaged", alert_utils.getTabParameters(opts, "engaged"))))
-  interface.select(''..old_ifid)
-  return(rv)
+function plugins_utils.getUrl(script)
+  return(plugins_utils.getMonitorUrl(script))
 end
 
 -- ##############################################
@@ -811,7 +784,11 @@ local function load_metadata()
 
       if not status then
 	 traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Could not load plugins metadata file '%s'", PLUGIN_RELATIVE_PATHS.metadata))
-	 tprint(debug.traceback())
+	 -- Prints the traceback using multiple traceError to make sure it ends up completely as error in logging systems
+	 local tb = debug.traceback()
+	 for s in tb:gmatch("[^\r\n]+") do
+	    traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("%s", s))
+	 end
       end
   end
 end
@@ -855,6 +832,30 @@ end
 
 -- ##############################################
 
+-- @brief Get the httpdocs directory of the plugin. This can be used to access
+-- javascript, css and similar files
+function plugins_utils.getHttpdocsDir(plugin_name)
+  local dir = ternary(ntop.isPlugins0Dir(), "plugins0_httpdocs", "plugins1_httpdocs")
+
+  -- See url_rewrite_patterns in HTTPserver.cpp
+  return(os_utils.fixPath(ntop.getHttpPrefix() .. "/".. dir .."/" .. plugin_name))
+end
+
+-- ##############################################
+
+-- @brief Retrieve the runtime templates directory of the plugin
+-- @param plugin_name the plugin name
+-- @return the runtime directory path
+function plugins_utils.getPluginTemplatesDir(plugin_name)
+  init_runtime_paths()
+
+  local path = RUNTIME_PATHS.templates .. "/" .. plugin_name
+
+  return os_utils.fixPath(path)
+end
+
+-- ##############################################
+
 -- @brief Retrieve the plugin associated with the user script
 -- @param script_path the runtime path of the user script
 -- @return the associated plugin
@@ -918,7 +919,6 @@ function plugins_utils.getLoadedAlertEndpoints()
 	 local key = string.sub(fname, 1, string.len(fname) - 4)
 
 	 local endpoint = require(key)
-
 	 if(endpoint) then
 	    if((type(endpoint.isAvailable) ~= "function") or endpoint.isAvailable()) then
 	       endpoint.full_path = full_path
@@ -979,13 +979,48 @@ end
 function plugins_utils.renderTemplate(plugin_name, template_file, context)
   init_runtime_paths()
 
-  local full_path = os_utils.fixPath(RUNTIME_PATHS.templates .. "/" .. plugin_name .. "/" .. template_file)
+  -- Locate the template file under the plugin directory
+  local full_path = os_utils.fixPath(plugins_utils.getPluginTemplatesDir(plugin_name) .. "/" .. template_file)
+
+  -- If no template is found...
+  if not ntop.exists(full_path) then
+     -- Attempt at locating the template class under modules (global to ntopng)
+     full_path = os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/check_templates/"..template_file)
+  end
 
   return template_utils.gen(full_path, context, true --[[ using full path ]])
 end
 
 -- ##############################################
 
+-- @brief Load a plugin Lua template, e.g., those used for plugin checks
+function plugins_utils.loadTemplate(plugin_name, template_file)
+   -- Attempt at locating the template class under the plugin templates directory
+   -- Locate the template directory of the plugin containing this user script
+   local plugin_template_path = plugins_utils.getPluginTemplatesDir(plugin_name)
+
+   -- Get the actual template path, using the template name
+   local template_path = os_utils.fixPath(plugin_template_path.."/"..template_file..".lua")
+
+   -- If the plugin file exists..
+   if ntop.exists(template_path) then
+      -- Do the necessary require
+      init_runtime_paths()
+
+      lua_path_utils.package_path_prepend(RUNTIME_PATHS.templates)
+
+      local req_name = string.format("%s.%s", plugin_name, template_file)
+      local req = require(req_name)
+
+      return req
+   end
+
+   -- No template found
+   return nil
+end
+
+-- ##############################################
+
 -- @brief Load a module located inside a plugin. This is equivalent to the
 -- lua "require ..." of the builting ntopng modules
 function plugins_utils.loadModule(plugin_name, module_name)
@@ -1001,17 +1036,6 @@ end
 
 -- ##############################################
 
--- @brief Get the httpdocs directory of the plugin. This can be used to access
--- javascript, css and similar files
-function plugins_utils.getHttpdocsDir(plugin_name)
-  local dir = ternary(ntop.isPlugins0Dir(), "plugins0_httpdocs", "plugins1_httpdocs")
-
-  -- See url_rewrite_patterns in HTTPserver.cpp
-  return(os_utils.fixPath(ntop.getHttpPrefix() .. "/".. dir .."/" .. plugin_name))
-end
-
--- ##############################################
-
 -- @brief Deletes the plugins runtime directories. This is usually called
 -- in boot.lua to start fresh.
 function plugins_utils.cleanup()
