@@ -1,13 +1,14 @@
 --
--- (C) 2017-20 - ntop.org
+-- (C) 2017-22 - ntop.org
 --
 -- Module to keep things in common across pools of various type
 
 local dirs = ntop.getDirs()
-package.path = dirs.installdir .. "/scripts/lua/modules/recipients/?.lua;" .. package.path
+package.path = dirs.installdir .. "/scripts/lua/modules/notifications/?.lua;" .. package.path
+
 
 require "lua_utils"
-local user_scripts = require "user_scripts"
+local checks = require "checks"
 local recipients_mod = require "recipients"
 local json = require "dkjson"
 local ntop_info = ntop.getInfo()
@@ -18,9 +19,9 @@ local pools = {}
 
 -- ##############################################
 
--- A default pool id value associated to any member without pools
-pools.DEFAULT_POOL_ID = 0
-pools.DEFAULT_POOL_NAME = "Default"
+-- A builtin default pool id value associated to any member without pools
+pools.DEFAULT_POOL_ID = 0           -- Keep in sync with ntop_defines.h NO_HOST_POOL_ID
+pools.DEFAULT_POOL_NAME = "Default" -- Keep in sync with ntop_defines.h DEFAULT_POOL_NAME
 
 if ntop.isnEdge() then
     -- Compatibility with nEdge pools
@@ -47,7 +48,9 @@ pools.LIMITED_NUMBER_POOL_MEMBERS = ntop_info["constants.max_num_pool_members"]
 -- ##############################################
 
 -- This is the minimum pool id which will be used to create new pools
-pools.MIN_ASSIGNED_POOL_ID = 1
+-- 0: Default pool
+-- 1: Jailed hosts pool
+pools.MIN_ASSIGNED_POOL_ID = 2
 
 -- ##############################################
 
@@ -78,22 +81,37 @@ end
 
 -- ##############################################
 
+-- @brief Start a pool transaction. Useful to do bulk imports or other operations that may require multiple steps
+--        By default, all operations are non-transational, that is, every operation atomically changes the status of pools.
+--        To perform multiple, non-atomic operations, a transaction can be started.
+--        NOTE: currently, transactions are not supported, unless implemented in pools.lua subclasses
+function pools:start_transaction()
+end
+
+-- ##############################################
+
+-- @brief Ends a pool transaction.
+function pools:end_transaction()
+end
+
+-- ##############################################
+
 function pools:_initialize()
     local locked = self:_lock()
 
     if locked then
         -- Init the default pool, if not already initialized.
-        -- The default pool has always empty members, default configset id, and empty recipients
+        -- The default pool has always empty members and empty recipients
         local default_pool = self:get_pool(pools.DEFAULT_POOL_ID)
 
         if not default_pool then
 	   -- Raw call to persist, no need to go through add_pool as here all the parameters are trusted and
 	   -- there's no need to check.
 	   -- Default pool is always created with builtin recipients
-	   self:_persist(pools.DEFAULT_POOL_ID, pools.DEFAULT_POOL_NAME,
+	   self:_persist(pools.DEFAULT_POOL_ID,
+                         pools.DEFAULT_POOL_NAME,
 			 {} --[[ no members --]] ,
-			 user_scripts.DEFAULT_CONFIGSET_ID,
-			 recipients_mod.get_builtin_recipients() --[[ builtin recipients --]])
+			 recipients_mod.get_builtin_recipients() --[[ builtin recipients --]], nil --[[ policy ]])
         end
 
         self:_unlock()
@@ -223,9 +241,15 @@ function pools:_unlock() ntop.delCache(self:_get_pool_lock_key()) end
 
 -- ##############################################
 
+--@brief Method called after a successful execution of method persist
+function pools:_post_persist(pool_id, name, members, recipients, policy)
+end
+
+-- ##############################################
+
 -- @brief Persist pool details to disk. Possibly assign a pool id
 -- @param pool_id The pool_id of the pool which needs to be persisted. If nil, a new pool id is assigned
-function pools:_persist(pool_id, name, members, configset_id, recipients)
+function pools:_persist(pool_id, name, members, recipients, policy)
     -- self:cleanup()
 
     -- Default pool name and members cannot be modified
@@ -238,13 +262,12 @@ function pools:_persist(pool_id, name, members, configset_id, recipients)
     local pool_details = {
         name = name,
         members = members,
-        configset_id = configset_id,
         recipients = recipients
     }
 
     ntop.setCache(pool_details_key, json.encode(pool_details))
 
-    ntop.reloadPeriodicScripts()
+    self:_post_persist(pool_id, name, members, recipients, policy)
 
     -- Return the assigned pool_id
     return pool_id
@@ -261,18 +284,21 @@ end
 
 -- ##############################################
 
-function pools:add_pool(name, members, configset_id, recipients)
+-- Create a new pool (unless it already exists)
+function pools:add_pool(name, members, recipients, policy)
     local pool_id
 
     local locked = self:_lock()
 
     if locked then
-        if name and members and configset_id and recipients then
+        if name and members and recipients then
             local checks_ok = true
 
             -- Check if duplicate names exist
             local same_name_pool = self:get_pool_by_name(name)
-            if same_name_pool then checks_ok = false end
+            if same_name_pool then
+	      checks_ok = false
+            end
 
             -- Check if members are valid
             if not self:are_valid_members(members) then
@@ -292,16 +318,6 @@ function pools:add_pool(name, members, configset_id, recipients)
                 end
             end
 
-            -- Check if the configset_id is valid
-            if checks_ok then
-                local available_configsets = self:get_available_configset_ids()
-
-                if not available_configsets[configset_id] then
-                    -- Configset id not found
-                    checks_ok = false
-                end
-            end
-
             -- Check if recipients are valid
             if checks_ok then
                 if not self:are_valid_recipients(recipients) then
@@ -313,7 +329,7 @@ function pools:add_pool(name, members, configset_id, recipients)
                 -- All the checks have succeeded
                 -- Now that everything is ok, the id can be assigned and the pool can be persisted with the assigned id
                 pool_id = self:_assign_pool_id()
-                self:_persist(pool_id, name, members, configset_id, recipients)
+                self:_persist(pool_id, name, members, recipients, policy)
                 self:_set_cache_flag()
             end
         end
@@ -326,8 +342,59 @@ end
 
 -- ##############################################
 
-function pools:edit_pool(pool_id, new_name, new_members, new_configset_id,
-                         new_recipients)
+-- Add members and recipients (merge) to an existing pool
+function pools:add_to_pool(name, members, recipients)
+   local ret = true
+   local err = pools.ERRORS.NO_ERROR
+
+   if name then
+
+      local locked = self:_lock()
+      if locked then
+
+         -- Check if pool exists
+         local pool_details = self:get_pool_by_name(name)
+         if pool_details then
+            local pool_id = pool_details.pool_id
+
+            -- Add members
+            if members then
+               for _, member in pairs(members) do
+                  local retm, errm = self:bind_member_if_not_already_bound(member, pool_id, true)
+	          if not retm then
+	             ret = retm
+		     err = errm
+		  end
+	       end
+            end
+
+	    -- Add recipients
+	    if recipients then
+	       for _, recipient_id in pairs(recipients) do
+                  -- Check if recipient is valid
+                  if self:is_valid_recipient(recipient_id) then
+                     local retr, errr = self:_bind_recipient(recipient_id, pool_id)
+	             if not retm then
+	                ret = retr
+		        err = errr
+	             end
+		  end
+               end
+	    end
+         end
+
+         self:_unlock()
+      end
+   end
+
+   return ret, err
+end
+
+-- ##############################################
+
+-- Overwrite the pool name, members and recipients
+-- Policy are used just by Host Pool
+function pools:edit_pool(pool_id, new_name, new_members, new_recipients, new_policy)
     local ret = false
 
     local locked = self:_lock()
@@ -337,65 +404,70 @@ function pools:edit_pool(pool_id, new_name, new_members, new_configset_id,
 
     -- If here, pool_id has been found
     if locked then
-        if not new_members then
-            -- In case members have not been sumbitted, new_members
-            -- are assumed to be the existing members
-            new_members = cur_pool_details["members"]
-        end
-
-        if not new_recipients then
-            -- In case recipients have not been sumbitted, new_recipients
-            -- are assumed to be the existing recipients
-            new_recipients = cur_pool_details["recipients"]
-        end
-
-        if cur_pool_details and new_name and new_members and new_configset_id and
-            new_recipients then
+	
+        if cur_pool_details and cur_pool_details.name then 
             local checks_ok = true
 
-            -- Check if new_name is not the name of any other existing pool
-            local same_name_pool = self:get_pool_by_name(new_name)
-            if same_name_pool and same_name_pool.pool_id ~= pool_id then
-                checks_ok = false
+            if new_name then
+               -- Check if new_name is not the name of any other existing pool
+               local same_name_pool = self:get_pool_by_name(new_name)
+               if same_name_pool and same_name_pool.pool_id ~= pool_id then
+                   checks_ok = false
+               end
+            else
+               new_name = cur_pool_details.name
             end
 
-            -- Check if members are valid
-            if checks_ok and not self:are_valid_members(new_members) then
-                checks_ok = false
+
+            if new_members then
+               -- Check if members are valid
+               if checks_ok and not self:are_valid_members(new_members) then
+                  checks_ok = false
+               end
+
+               -- Check if none of new_members belongs to any other exsiting pool
+               if checks_ok then
+                   for _, new_member in pairs(new_members) do
+                       local new_member_pool = self:get_pool_by_member(new_member)
+
+                       if new_member_pool and new_member_pool["pool_id"] ~= pool_id then
+                           -- Member already existing in another pool
+                           checks_ok = false
+                           break
+                       end
+                   end
+               end
+            else
+               -- In case members have not been sumbitted, new_members
+               -- are assumed to be the existing members
+               new_members = cur_pool_details["members"]
             end
 
-            -- Check if none of new_members belongs to any other exsiting pool
-            if checks_ok then
-                for _, new_member in pairs(new_members) do
-                    local new_member_pool = self:get_pool_by_member(new_member)
+	    if new_recipients then
+	       -- Check if recipients are valid
+	       if checks_ok and not self:are_valid_recipients(new_recipients) then
+		  checks_ok = false
+	       end
+	    else
+	       -- In case recipients have not been sumbitted, new_recipients
+	       -- are assumed to be the existing recipients
+	       new_recipients = {}
 
-                    if new_member_pool and new_member_pool["pool_id"] ~= pool_id then
-                        -- Member already existing in another pool
-                        checks_ok = false
-                        break
-                    end
-                end
-            end
+	       -- Populate with recipient IDs
+	       for _, recipient in pairs(cur_pool_details["recipients"] or {}) do
+		  new_recipients[#new_recipients + 1] = recipient["recipient_id"]
+	       end
+	    end
 
-            -- Check if the configset_id is valid
-            if checks_ok then
-                local available_configsets = self:get_available_configset_ids()
-
-                if not available_configsets[new_configset_id] then
-                    -- Configset id not found
-                    checks_ok = false
-                end
-            end
-
-            -- Check if recipients are valid
-            if checks_ok and not self:are_valid_recipients(new_recipients) then
-                checks_ok = false
+            if not new_policy then
+               -- In case policy have not been sumbitted, new_policy
+               -- is assumed to be the existing policy
+	       new_policy = cur_pool_details["policy"] or ""
             end
 
             if checks_ok then
                 -- If here, all checks are valid and the pool can be edited
-                self:_persist(pool_id, new_name, new_members, new_configset_id,
-                              new_recipients)
+                self:_persist(pool_id, new_name, new_members, new_recipients, new_policy)
                 self:_set_cache_flag()
                 -- Pool edited successfully
                 ret = true
@@ -420,15 +492,13 @@ function pools:delete_pool(pool_id)
         local cur_pool_details = self:get_pool(pool_id)
 
         if cur_pool_details then
-            -- Remove the key with all the pool details (e.g., with members, and configset_id)
+            -- Remove the key with all the pool details (e.g., with members)
             ntop.delCache(self:_get_pool_details_key(pool_id))
 
             -- Remove the pool_id from the set of all currently existing pool ids
             ntop.delMembersCache(self:_get_pool_ids_key(),
                                  string.format("%d", pool_id))
 
-	    -- Reload periodic scripts to make faster refreshes
-	    ntop.reloadPeriodicScripts()
             ret = true
         end
 
@@ -465,6 +535,19 @@ end
 
 -- ##############################################
 
+-- @brief returns the maximum number of pools that can be created
+function pools:get_max_num_pools()
+   return 128
+end
+
+-- ##############################################
+
+-- Currently Implemented only into the Host Pools, used to get the host policy
+function pools:get_pool_policy(pool_id)
+end
+
+-- ##############################################
+
 function pools:get_pool(pool_id, recipient_details)
     local recipient_details = recipient_details or true
     local pool_details
@@ -475,7 +558,7 @@ function pools:get_pool(pool_id, recipient_details)
         local pool_details_str = ntop.getCache(pool_details_key)
         pool_details = json.decode(pool_details_str)
 
-        if pool_details then
+	if pool_details then
             -- Add the integer pool id
             pool_details["pool_id"] = tonumber(pool_id)
 
@@ -489,19 +572,7 @@ function pools:get_pool(pool_id, recipient_details)
                 end
             end
 
-            if pool_details["configset_id"] then
-                local configset_id = pool_details["configset_id"]
-                local config_sets = user_scripts.getConfigsets()
-
-                -- Add a new (small) table with configset details, including the name
-                if config_sets[configset_id] and
-                    config_sets[configset_id]["name"] then
-                    pool_details["configset_details"] =
-                        {name = config_sets[configset_id]["name"]}
-                end
-            end
-
-            if pool_details["recipients"] then
+	    if pool_details["recipients"] then
                 local recipients = {}
                 -- get recipient metadata
                 for _, recipient_id in pairs(pool_details["recipients"]) do
@@ -513,7 +584,7 @@ function pools:get_pool(pool_id, recipient_details)
 			 if recipient and recipient.recipient_name then
 			    -- Keep in in sync with overridden method in host_pool.lua
 			    res["recipient_name"] = recipient.recipient_name
-			    res["recipient_user_script_categories"] = recipient.user_script_categories
+			    res["recipient_check_categories"] = recipient.check_categories
 			    res["recipient_minimum_severity"] = recipient.minimum_severity
 			 end
 		      end
@@ -539,7 +610,9 @@ function pools:get_pool_by_name(name)
         local pool_details = self:get_pool(pool_id)
 
         if pool_details and pool_details["name"] and pool_details["name"] ==
-            name then return pool_details end
+            name then
+	   return pool_details
+        end
     end
 
     return nil
@@ -560,24 +633,6 @@ end
 
 -- ##############################################
 
-function pools:get_pools_by_configset_id(configset_id)
-    local cur_pool_ids = self:_get_assigned_pool_ids()
-    local res = {}
-
-    for _, pool_id in pairs(cur_pool_ids) do
-        local pool_details = self:get_pool(pool_id)
-
-        if pool_details and pool_details["configset_id"] and
-            pool_details["configset_id"] == configset_id then
-            res[#res + 1] = pool_details
-        end
-    end
-
-    return res
-end
-
--- ##############################################
-
 -- @brief Returns a flattened table with pool_member->pool_id pairs
 function pools:get_assigned_members()
     local cur_pool_ids = self:_get_assigned_pool_ids()
@@ -590,8 +645,7 @@ function pools:get_assigned_members()
             for _, member in pairs(pool_details["members"]) do
                 res[member] = {
                     pool_id = tonumber(pool_id),
-                    name = pool_details["name"],
-                    configset_id = pool_details["configset_id"]
+                    name = pool_details["name"]
                 }
             end
         end
@@ -632,6 +686,7 @@ end
 function pools:cleanup()
     -- Delete pool details
     local cur_pool_ids = self:_get_assigned_pool_ids()
+
     for _, pool_id in pairs(cur_pool_ids) do
        self:delete_pool(pool_id)
     end
@@ -762,8 +817,7 @@ function pools:unbind_all_recipient_id(recipient_id)
 
             if found then
                 -- Rewrite the pool using the new recipients set
-                self:_persist(pool["pool_id"], pool["name"], pool["members"],
-                              pool["configset_id"], new_recipients)
+                self:_persist(pool["pool_id"], pool["name"], pool["members"], new_recipients, pool["policy"])
             end
         end
 
@@ -773,6 +827,52 @@ end
 
 -- ##############################################
 
+-- @brief Bind a recipient to all pools
+function pools:bind_all_recipient_id(recipient_id)
+   if not recipient_id then
+      -- Invalid argument
+      return
+   end
+
+   local locked = self:_lock()
+
+   if locked then
+      local all_pools = self:get_all_pools()
+
+      for _, pool in pairs(all_pools) do
+ 	 local found = false
+
+	 -- All the recipients for the current pool
+	 local new_recipients = {}
+
+	 if pool["recipients"] then
+	    for _, cur_recipient in pairs(pool["recipients"]) do
+	       if tonumber(cur_recipient.recipient_id) == tonumber(recipient_id) then
+		  -- Already bound for this pool, nothing to do
+		  found = true
+		  break
+	       else
+		  -- Prepare a lua array with integer recipient ids
+		  new_recipients[#new_recipients + 1] = tonumber(cur_recipient.recipient_id)
+	       end
+	    end
+
+	    if not found then
+	       -- Append the recipient to the array of pool recipients
+	       new_recipients[#new_recipients + 1] = tonumber(recipient_id)
+
+	       -- Rewrite the pool using the extended recipients array
+	       self:_persist(pool["pool_id"], pool["name"], pool["members"], new_recipients, pool["policy"])
+	    end
+	 end
+      end
+
+      self:_unlock()
+   end
+end
+
+-- ##############################################
+
 -- @brief Parses members submitted via HTTP (validated as `pool_members` in `http_lint.lua`) into a table of members
 function pools:parse_members(members_string)
     local members = {}
@@ -804,17 +904,59 @@ end
 
 -- ##############################################
 
+-- @brief Bind a recipient to a pool
+--        PRIVATE FUNCTION, not to be called outside this class
+--        The caller must lock
+function pools:_bind_recipient(recipient_id, pool_id)
+   local ret, err = false, pools.ERRORS.GENERIC
+
+   -- ASSIGN the recipient to the pool with `pool_id`
+   local bind_pool = self:get_pool(pool_id, false)
+
+   if bind_pool then
+      -- Members stay the same
+      local bind_pool_members = bind_pool["members"]
+
+      -- Recipients are all pool recipients plus the recipient which is being bound
+      local bind_pool_recipients = {}
+      local already_present = false
+      for _, recipient in pairs(bind_pool["recipients"] or {}) do
+         bind_pool_recipients[#bind_pool_recipients + 1] = recipient.recipient_id
+	 if recipient.recipient_id == recipient_id then
+            already_present = true
+         end
+      end
+
+      if not already_present then
+         bind_pool_recipients[#bind_pool_recipients + 1] = recipient_id
+
+      -- Persist the pool with the new `recipient`
+         self:_persist(bind_pool["pool_id"], bind_pool["name"],
+                       bind_pool_members, bind_pool_recipients, bind_pool["policy"])
+      end
+
+      -- Bind has executed successfully
+      ret, err = true, pools.ERRORS.NO_ERROR
+   end
+
+   return ret, err
+end
+
+-- ##############################################
+
 -- @brief Bind a member to a pool
 --        PRIVATE FUNCTION, not to be called outside this class
 --        The caller must lock and must check the member doesn't belong to
 --        any other pool apart from pool_id, before calling
 function pools:_bind_member(member, pool_id)
-    local ret, err = false, pools.ERRORS.GENERIC
+    local ret = false
+    local err = pools.ERRORS.GENERIC
 
     -- ASSIGN the member to the pool with `pool_id`
     -- Note: If the pool_id is pools.DEFAULT_POOL_ID, then `member` is not associated to any pool, it's safe to just return
     if tonumber(pool_id) == pools.DEFAULT_POOL_ID then
-        ret, err = true, pools.ERRORS.NO_ERROR
+        ret = true
+	err = pools.ERRORS.NO_ERROR
     else
         local bind_pool = self:get_pool(pool_id, false)
 
@@ -831,11 +973,11 @@ function pools:_bind_member(member, pool_id)
 
             -- Persist the pool with the new `member`
             self:_persist(bind_pool["pool_id"], bind_pool["name"],
-                          bind_pool_members, bind_pool["configset_id"],
-                          bind_pool_recipients)
+                          bind_pool_members, bind_pool_recipients, bind_pool["policy"])
 
             -- Bind has executed successfully
-            ret, err = true, pools.ERRORS.NO_ERROR
+            ret = true
+	    err = pools.ERRORS.NO_ERROR
         end
     end
 
@@ -880,8 +1022,7 @@ function pools:bind_member(member, pool_id)
 
                 -- Persist the existing pool without the removed `member`
                 self:_persist(cur_pool["pool_id"], cur_pool["name"],
-                              new_members, cur_pool["configset_id"],
-                              bind_pool_recipients)
+                              new_members, bind_pool_recipients, cur_pool["policy"])
             end
         end
 
@@ -897,14 +1038,17 @@ end
 
 -- @brief Bind `member` to pool identified with `pool_id`. If the member is already bound to another pool
 --        then nothing is done and an error is returned
-function pools:bind_member_if_not_already_bound(member, pool_id)
+function pools:bind_member_if_not_already_bound(member, pool_id, already_locked)
     local ret, err = false, pools.ERRORS.GENERIC
 
     if not self:is_valid_member(member) then
         return false, pools.ERRORS.INVALID_MEMBER
     end
 
-    local locked = self:_lock()
+    local locked = already_locked
+    if not locked then
+       locked = self:_lock()
+    end
 
     if locked then
         local assigned_members = self:get_assigned_members()
@@ -912,17 +1056,19 @@ function pools:bind_member_if_not_already_bound(member, pool_id)
             -- Member already existing
             if assigned_members[member]["pool_id"] == pool_id then
                 -- Member is bound to the same pool as the parameter `pool_id`
-                ret, err = true, pools.ERRORS.NO_ERROR
+	       ret, err = true, pools.ERRORS.NO_ERROR
             else
                 -- Member is bound to another pool
-                ret, err = false, pools.ERRORS.ALREADY_BOUND
+	       ret, err = false, pools.ERRORS.ALREADY_BOUND
             end
         else
             -- Member isn't bound to any pool, safe to add it
             ret, err = self:_bind_member(member, pool_id)
         end
 
-        self:_unlock()
+	if not already_locked then
+           self:_unlock()
+	end
     end
 
     return ret, err
@@ -930,94 +1076,6 @@ end
 
 -- ##############################################
 
--- @brief Unbind a `configset_id` from all pools which are currently using it, and sets them the defauls configset.
-function pools:unbind_all_configset_id(configset_id)
-    configset_id = tonumber(configset_id)
-
-    if not configset_id then
-        -- Invalid argument
-        return
-    end
-
-    local locked = self:_lock()
-
-    if locked then
-        local all_pools = self:get_all_pools()
-
-        for _, pool in pairs(all_pools) do
-            if pool["configset_id"] == configset_id then
-                -- Rewrite the pool using the default configset id
-                self:_persist(pool["pool_id"], pool["name"], pool["members"],
-                              user_scripts.DEFAULT_CONFIGSET_ID,
-                              pool["recipients"])
-            end
-        end
-
-        self:_unlock()
-    end
-end
-
--- ##############################################
-
--- @brief Returns available confset ids which can be added to a pool
-function pools:get_available_configset_ids()
-    -- Currently, confset_ids are shared across pools of all types
-    -- so all the confset_ids can be returned here without distinction
-    local config_sets = user_scripts.getConfigsets()
-    local res = {}
-
-    for _, configset in pairs(config_sets) do
-        res[configset.id] = {
-            configset_id = configset.id,
-            configset_name = configset.name
-        }
-    end
-
-    return res
-end
-
--- ##############################################
-
--- @param member a valid pool member
--- @return The configset_id found for `member` or the default configset_id
-function pools:get_configset_id(member)
-    if not self.assigned_pool_members then
-        -- Cache it as class member
-        self.assigned_pool_members = self:get_assigned_members()
-    end
-
-    if self.assigned_pool_members[member] and
-        self.assigned_pool_members[member]["configset_id"] then
-        return self.assigned_pool_members[member]["configset_id"]
-    end
-
-    return user_scripts.DEFAULT_CONFIGSET_ID
-end
-
--- ##############################################
-
--- @param pool_id a valid pool id
--- @return The configset_id found for the given `pool_id`, or the default configset_id if `pool_id` is not found
-function pools:get_configset_id_by_pool_id(pool_id)
-    if not self.pool_id_to_configset_id then
-        -- Prepare the cache
-        self.pool_id_to_configset_id = {}
-    end
-
-    if not self.pool_id_to_configset_id[pool_id] then
-        -- Populate the cache with current pool information
-        self.pool_id_to_configset_id[pool_id] = self:get_pool(pool_id) or {}
-    end
-
-    if self.pool_id_to_configset_id[pool_id]["configset_id"] then
-        return self.pool_id_to_configset_id[pool_id]["configset_id"]
-    end
-
-    return user_scripts.DEFAULT_CONFIGSET_ID
-end
-
--- ##############################################
-
 -- @param member a valid pool member
 -- @return The pool_id found for `member` or the default pool_id
 function pools:get_pool_id(member)
