@@ -1,9 +1,9 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
-local NTOP_BASE_ID = 57472
-local NTOP_BASE_NETFLOW_ID = NTOP_BASE_ID+1024
+NTOP_BASE_ID = 57472
+NTOP_BASE_NETFLOW_ID = NTOP_BASE_ID+1024
 
 -- template name to id
 template = {
@@ -89,7 +89,11 @@ template = {
    ['FLOW_END_SEC'] = 151,
    ['FLOW_START_MILLISECONDS'] = 152,
    ['FLOW_END_MILLISECONDS'] = 153,
-   ['BIFLOW_DIRECTION'] = 239,
+   ['FIREWALL_EVENT'] = 233,
+   ['POST_NAT_SRC_IPV4_ADDR'] = 225,
+   ['POST_NAT_DST_IPV4_ADDR'] = 226,
+   ['POST_NAPT_SRC_TRANSPORT_PORT'] = 227,
+   ['POST_NAPT_DST_TRANSPORT_PORT'] = 228,
    ['OBSERVATION_POINT_TYPE'] = 277,
    ['OBSERVATION_POINT_ID'] = 300,
    ['SELECTOR_ID'] = 302,
@@ -100,7 +104,8 @@ template = {
    ['PACKETS_OBSERVED'] = 318,
    ['PACKETS_SELECTED'] = 319,
    ['SELECTOR_NAME'] = 335,
-   ['FRAGMENTS'] = NTOP_BASE_ID+80,
+   ['SRC_FRAGMENTS'] = NTOP_BASE_ID+80,
+   ['DST_FRAGMENTS'] = NTOP_BASE_ID+81,
    ['SRC_TO_DST_MAX_THROUGHPUT'] = NTOP_BASE_ID+82,
    ['SRC_TO_DST_MIN_THROUGHPUT'] = NTOP_BASE_ID+83,
    ['SRC_TO_DST_AVG_THROUGHPUT'] = NTOP_BASE_ID+84,
@@ -157,7 +162,8 @@ template = {
    ['NUM_PKTS_TTL_224_255'] = NTOP_BASE_ID+341,
    ['IN_SRC_OSI_SAP'] = NTOP_BASE_ID+349,
    ['OUT_DST_OSI_SAP'] = NTOP_BASE_ID+350,
-
+   ['FLOW_VERDICT'] =  NTOP_BASE_ID+522,
+   ['L7_RISK_SCORE'] = NTOP_BASE_ID+527,
    -- SIP
    ['SIP_CALL_ID'] = NTOP_BASE_ID+130,
    ['SIP_CALLING_PARTY'] = NTOP_BASE_ID+131,
@@ -201,6 +207,14 @@ template = {
    ['RTP_IN_TRANSIT'] = NTOP_BASE_ID+381,
    ['RTP_OUT_TRANSIT'] = NTOP_BASE_ID+382,
    ['RTP_DTMF_TONES'] = NTOP_BASE_ID+395,
+   ['TCP_WIN_MIN_IN'] = NTOP_BASE_ID+415,
+   ['TCP_WIN_MAX_IN'] = NTOP_BASE_ID+416,
+   ['TCP_WIN_MSS_IN'] = NTOP_BASE_ID+417,
+   ['TCP_WIN_SCALE_IN'] = NTOP_BASE_ID+418,
+   ['TCP_WIN_MIN_OUT'] = NTOP_BASE_ID+419,
+   ['TCP_WIN_MAX_OUT'] = NTOP_BASE_ID+420,
+   ['TCP_WIN_MSS_OUT'] = NTOP_BASE_ID+421,
+   ['TCP_WIN_SCALE_OUT'] = NTOP_BASE_ID+422,
    ['RTP_IN_PKT_DROP'] = NTOP_BASE_ID+430,
    ['RTP_OUT_PKT_DROP'] = NTOP_BASE_ID+431,
    ['RTP_OUT_MOS'] = NTOP_BASE_ID+432,
@@ -212,6 +226,7 @@ template = {
    -- Process
    ['SRC_PROC_PID'] = NTOP_BASE_ID+168,
    ['SRC_PROC_NAME'] = NTOP_BASE_ID+169,
+   ['SRC_PROC_PACKAGE_NAME'] = NTOP_BASE_ID+540,
    ['SRC_PROC_USER_NAME'] = NTOP_BASE_ID+372,
    ['SRC_FATHER_PROC_PID'] = NTOP_BASE_ID+373,
    ['SRC_FATHER_PROC_NAME'] = NTOP_BASE_ID+374,
@@ -221,6 +236,7 @@ template = {
    ['SRC_PROC_NUM_PAGE_FAULTS'] = NTOP_BASE_ID+386,
    ['DST_PROC_PID'] = NTOP_BASE_ID+375,
    ['DST_PROC_NAME'] = NTOP_BASE_ID+376,
+   ['DST_PROC_PACKAGE_NAME'] = NTOP_BASE_ID+541,
    ['DST_PROC_USER_NAME'] = NTOP_BASE_ID+377,
    ['DST_FATHER_PROC_PID'] = NTOP_BASE_ID+378,
    ['DST_FATHER_PROC_NAME'] = NTOP_BASE_ID+379,
@@ -263,6 +279,20 @@ template = {
    ['DNS_QUERY_TYPE'] = NTOP_BASE_ID+207,
    ['DNS_RET_CODE'] = NTOP_BASE_ID+208,
    ['DNS_NUM_ANSWERS'] = NTOP_BASE_ID+209,
+   ['DNS_TTL_ANSWER'] = NTOP_BASE_ID+352,
+   ['DNS_RESPONSE'] = NTOP_BASE_ID+398,
+
+      -- TLS Protocol
+   ['TLS_VERSION'] = NTOP_BASE_ID+495,
+   ['TLS_CERT_NOT_BEFORE'] = NTOP_BASE_ID+496,
+   ['TLS_CERT_AFTER'] = NTOP_BASE_ID+497,
+   ['TLS_CERT_SHA1'] = NTOP_BASE_ID+498,
+   ['TLS_CERT_ISSUER_DN'] = NTOP_BASE_ID+514,
+   ['TLS_CERT_SUBJECT_SN'] = NTOP_BASE_ID+515,
+   ['TLS_REQUESTED_SNI'] = NTOP_BASE_ID+511,
+   ['TLS_SERVER_NAMES'] = NTOP_BASE_ID+512,
+   ['TLS_SERVER_NAMES'] = NTOP_BASE_ID+512,
+   ['TLS_ALPN'] = NTOP_BASE_ID+513,
 
    -- POP
    ['POP_USER'] = NTOP_BASE_ID+210,
@@ -368,12 +398,25 @@ template = {
    ['SSDP_SERVER'] = NTOP_BASE_ID+468,
    ['SSDP_TYPE'] = NTOP_BASE_ID+469,
    ['SSDP_METHOD'] = NTOP_BASE_ID+470,
-   
+
    -- NetBIOS
    ['NETBIOS_QUERY_NAME'] = NTOP_BASE_ID+464,
    ['NETBIOS_QUERY_TYPE'] = NTOP_BASE_ID+465,
-   ['NETBIOS_RESPONSE'] = NTOP_BASE_ID+466,
-   ['NETBIOS_QUERY_OS'] = NTOP_BASE_ID+467
+   ['NETBIOS_RESPONSE']   = NTOP_BASE_ID+466,
+   ['NETBIOS_QUERY_OS']   = NTOP_BASE_ID+467,
+
+   -- Syslog
+   ['DST_OS_NAME']    = NTOP_BASE_ID+542,
+   ['DST_SW_VERSION'] = NTOP_BASE_ID+543,
+   ['DST_USER']       = NTOP_BASE_ID+544,
+   ['DST_INTF_NAME']  = NTOP_BASE_ID+545,
+   ['SRC_USER']       = NTOP_BASE_ID+546,
+   ['SRC_OS_NAME']    = NTOP_BASE_ID+547,
+   ['SRC_SW_VERSION'] = NTOP_BASE_ID+548,
+   ['SRC_INTF_NAME']  = NTOP_BASE_ID+549,
+   ['POLICY_ID']      = NTOP_BASE_ID+550,
+   ['POLICY_ACTION']  = NTOP_BASE_ID+551,
+   ['DEVICE_NAME']    = NTOP_BASE_ID+552,
 }
 
 -- template id to name
