@@ -1,5 +1,5 @@
 --
--- (C) 2018-20 - ntop.org
+-- (C) 2018-22 - ntop.org
 --
 
 local ts_utils = {}
@@ -186,13 +186,15 @@ end
 -- ##############################################
 
 local function isUserAccessAllowed(tags)
-   if tags.ifid and not ntop.isAllowedInterface(tonumber(tags.ifid)) then
+   if tags.ifid and not ntop.isnEdge() and not ntop.isAllowedInterface(tonumber(tags.ifid)) then
       traceError(TRACE_ERROR, TRACE_CONSOLE, "User: " .. _SESSION["user"] .. " is not allowed to access interface " .. tags.ifid)
       return false
    end
 
-   if tags.host and not ntop.isAllowedNetwork(tags.host) then
-      traceError(TRACE_ERROR, TRACE_CONSOLE, "User: " .. _SESSION["user"] .. " is not allowed to access host " .. tags.host)
+   -- Note: tags.host can contain a MAC address for local broadcast domain hosts
+   local host = tags.host_ip or tags.host
+   if host and not ntop.isAllowedNetwork(host) then
+      traceError(TRACE_ERROR, TRACE_CONSOLE, "User: " .. _SESSION["user"] .. " is not allowed to access host " .. host)
       return false
    end
 
@@ -338,12 +340,10 @@ local function getLocalTopTalkers(schema_id, tags, tstart, tend, options)
       direction = "receivers"
       select_col = "rcvd"
    end
-
    local tophosts = {}
 
    for idx1, vlan in pairs(top_talkers.vlan or {}) do
       for idx2, host in pairs(vlan.hosts[1][direction] or {}) do
-	 if host["local"] == "true" then
 	    -- need to recalculate total value
 	    local host_tags = {ifid=tags.ifid, host=host.address}
 	    local host_partials = ts_utils.queryTotal("host:traffic", tstart, tend, host_tags)
@@ -367,8 +367,7 @@ local function getLocalTopTalkers(schema_id, tags, tstart, tend, options)
 		     visual_addr = host.visual_addr, -- optional
 		  }
 	       }
-	    end
-	 end
+	     end
       end
    end
 
@@ -823,22 +822,51 @@ end
 --! @note This function should be updated whenever an existng schema is changed
 function ts_utils.getPossiblyChangedSchemas()
    return {
+      -- Interface timeseries
       "iface:alerted_flows",
+      "iface:score",
+      "iface:score_behavior",
+      "iface:score_anomalies",
+      "iface:traffic_anomalies",
+      "iface:traffic_rx_behavior_v2",
+      "iface:traffic_tx_behavior_v2",
+      "iface:engaged_alerts",
 
+      "subnet:score_anomalies",
+      "subnet:traffic_tx_behavior_v2",
+      "subnet:traffic_rx_behavior_v2",
+      "subnet:traffic_anomalies",
+      "subnet:score_behavior",
+
+      "asn:score_anomalies",
+      "asn:score_behavior",
+      "asn:traffic_anomalies",
+      "asn:traffic_rx_behavior_v2",
+      "asn:traffic_tx_behavior_v2",
+
+      -- Host timeseries
       "host:contacts", -- split in "as_client" and "as_server"
+      "host:score", -- split in "cli_score" and "srv_score"
+      "host:contacts_behaviour",
+      "host:cli_active_flows_behaviour",
+      "host:srv_active_flows_behaviour",
+      "host:cli_score_behaviour",
+      "host:srv_score_behaviour",
+      "host:cli_active_flows_anomalies",
+      "host:srv_active_flows_anomalies",
+      "host:cli_score_anomalies",
+      "host:srv_score_anomalies",
       "host:ndpi_categories", --split in "bytes_sent" and "bytes_rcvd"
 
       -- Added missing ifid tag
       "influxdb:storage_size",
       "influxdb:exported_points",
-      "influxdb:dropped_points",
       "influxdb:exports",
       "influxdb:rtt",
       "system:cpu_load",
       "process:resident_memory",
       "redis:keys",
       "redis:memory",
-      "host:score",
       "periodic_script:timeseries_writes",
       "mac:arp_rqst_sent_rcvd_rpls",
 
@@ -857,4 +885,33 @@ end
 
 -- ##############################################
 
+function ts_utils.get_memory_size_query(influxdb, schema, tstart, tend, time_step)
+   --[[
+      See comments in function driver:getMemoryUsage() to understand
+      why it is necessary to subtract the HeapReleased from Sys.
+   --]]
+   local q = 'SELECT MEAN(Sys) - MEAN(HeapReleased) as mem_bytes' ..
+      ' FROM "_internal".."runtime"' ..
+      " WHERE time >= " .. tstart .. "000000000 AND time <= " .. tend .. "000000000" ..
+      " GROUP BY TIME(".. time_step .."s)"
+
+   return(q)
+end
+
+-- ##############################################
+
+function ts_utils.get_write_success_query(influxdb, schema, tstart, tend, time_step)
+   local q = 'SELECT SUM(writePointsOk) as points' ..
+      ' FROM (SELECT '..
+      ' (DERIVATIVE(MEAN(writePointsOk)) / '.. time_step ..') as writePointsOk' ..
+      ' FROM "monitor"."shard" WHERE "database"=\''.. influxdb.db ..'\'' ..
+      " AND time >= " .. tstart .. "000000000 AND time <= " .. tend .. "000000000" ..
+      " GROUP BY id)" ..
+      " GROUP BY TIME(".. time_step .."s)"
+
+   return(q)
+end
+
+-- ##############################################
+
 return ts_utils
