@@ -1,9 +1,8 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 -- ########################################################
--- require "flow_utils"
 
 
 local payload_type = 0
@@ -119,13 +118,13 @@ function MosPercentageBar(value)
    value = tonumber(value)
 
    if (value >= 4.0)  then
-      ret_bar = '<span class="badge badge-success">'..value..' '..i18n("flow_details.desirable_label")..'</span>'
+      ret_bar = '<span class="badge bg-success">'..value..' '..i18n("flow_details.desirable_label")..'</span>'
    elseif ((value >= 3.6) and (value < 4.0)) then
-      ret_bar = '<span class="badge badge-info">'..value..' '..i18n("flow_details.acceptable_label")..'</span>'
+      ret_bar = '<span class="badge bg-info">'..value..' '..i18n("flow_details.acceptable_label")..'</span>'
    elseif ((value >= 2.6) and (value < 3.6)) then
-      ret_bar = '<span class="badge badge-warning">'..value..' '..i18n("flow_details.reach_connection_label")..'</span>'
+      ret_bar = '<span class="badge bg-warning">'..value..' '..i18n("flow_details.reach_connection_label")..'</span>'
    elseif ((value > 0) and (value < 2.6)) then
-      ret_bar = '<span class="badge badge-danger">'..value..' '..i18n("flow_details.not_recommended_label")..'</span>'
+      ret_bar = '<span class="badge bg-danger">'..value..' '..i18n("flow_details.not_recommended_label")..'</span>'
    end
 
    return ret_bar
@@ -138,13 +137,13 @@ function RFactorPercentageBar(value)
    value = tonumber(value)
 
    if (value >= 80.0)  then
-      ret_bar = '<span class="badge badge-success">'..value..' '..i18n("flow_details.desirable_label")..'</span>'
+      ret_bar = '<span class="badge bg-success">'..value..' '..i18n("flow_details.desirable_label")..'</span>'
    elseif ((value >= 70.0) and (value < 80.0)) then
-      ret_bar = '<span class="badge badge-info">'..value..' '..i18n("flow_details.acceptable_label")..'</span>'
+      ret_bar = '<span class="badge bg-info">'..value..' '..i18n("flow_details.acceptable_label")..'</span>'
    elseif ((value >= 50.0) and (value < 70.0)) then
-      ret_bar = '<span class="badge badge-warning">'..value..' '..i18n("flow_details.reach_connection_label")..'</span>'
+      ret_bar = '<span class="badge bg-warning">'..value..' '..i18n("flow_details.reach_connection_label")..'</span>'
    elseif ((value >= 0) and (value < 50.0)) then
-      ret_bar = '<span class="badge badge-danger">'..value..' '..i18n("flow_details.not_recommended_label")..'</span>'
+      ret_bar = '<span class="badge bg-danger">'..value..' '..i18n("flow_details.not_recommended_label")..'</span>'
    end
 
    return ret_bar
@@ -154,34 +153,34 @@ end
 
 function SipCallStatePercentageBar(state)
   -- Wireshark use different state http://wiki.wireshark.org/VoIP_calls
-  label_class =  "badge-secondary"
+  label_class =  "bg-secondary"
 
   if (state == "REGISTER") then
-    label_class = "badge-info"
+    label_class = "bg-info"
   end
 
   if (state == "CALL_STARTED") then
-    label_class = "badge-info"
+    label_class = "bg-info"
   end
 
   if (state == "CALL_IN_PROGRESS") then
-    label_class = "badge-progress"
+    label_class = "bg-progress"
   end
 
   if (state == "CALL_COMPLETED") then
-    label_class = "badge-success"
+    label_class = "bg-success"
   end
 
   if (state == "CALL_ERROR") then
-    label_class = "badge-danger"
+    label_class = "bg-danger"
   end
 
   if (state == "CALL_CANCELED") then
-    label_class = "badge-warning"
+    label_class = "bg-warning"
   end
 
   if (state == "UNKNOWN") then
-    label_class = "badge-warning"
+    label_class = "bg-warning"
   end
 
   print('<span class="badge '..label_class..'">'..state..'</span>')
