@@ -1,5 +1,5 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -16,7 +16,7 @@ page_utils.print_header()
 
 ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/menu.inc")
 
-print('<div class="alert alert-danger"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png> Page not found</div>')
+print('<div class="alert alert-danger"><i class="fas fa-exclamation-triangle fa-lg fa-ntopng-warning"></i> Page not found</div>')
 
 print ("<center><H4>Unable to find URL <i>")
 
