@@ -1,5 +1,5 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -10,20 +10,20 @@ local json = require ("dkjson")
 local page_utils = require("page_utils")
 local tracker = require("tracker")
 local storage_utils = require("storage_utils")
-local system_utils = require("system_utils")
+local cpu_utils = require("cpu_utils")
 
 if not isAllowedSystemInterface() then
    sendHTTPContentTypeHeader('text/html')
 
    page_utils.print_header()
    dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
-   print("<div class=\"alert alert-danger\"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png>"..i18n("error_not_granted").."</div>")
+   print("<div class=\"alert alert-danger\"><i class='fas fa-exclamation-triangle fa-lg fa-ntopng-warning'></i> "..i18n("error_not_granted").."</div>")
    return
 end
 
 sendHTTPContentTypeHeader('application/json')
 
-local stats = system_utils.systemHostStats()
+local stats = cpu_utils.systemHostStats()
 stats.epoch = os.time()
 stats.storage = storage_utils.storageInfo()
 
