@@ -1,5 +1,5 @@
 --
--- (C) 2019-20 - ntop.org
+-- (C) 2019-22 - ntop.org
 --
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
@@ -7,10 +7,11 @@ package.path = dirs.installdir .. "/scripts/lua/modules/import_export/?.lua;" ..
 
 require "lua_utils"
 
-local all_import_export = require "all_import_export"
 local rest_utils = require "rest_utils"
 local import_export_rest_utils = require "import_export_rest_utils"
 
+local all_import_export = require "all_import_export"
+
 --
 -- Export all configurations
 -- Example: curl -u admin:admin http://localhost:3000/lua/rest/v1/export/all/config.lua
@@ -20,7 +21,7 @@ local import_export_rest_utils = require "import_export_rest_utils"
 
 local download = _GET["download"] 
 
-if not haveAdminPrivileges() then
+if not isAdministratorOrPrintErr() then
    rest_utils.answer(rest_utils.consts.err.not_granted)
    return
 end
