@@ -1,5 +1,5 @@
 --
--- (C) 2019-20 - ntop.org
+-- (C) 2019-22 - ntop.org
 --
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
@@ -9,9 +9,9 @@ require "lua_utils"
 
 local snmp_import_export = require "snmp_import_export"
 local plugins_utils = require("plugins_utils")
-local am_import_export = plugins_utils.loadModule("active_monitoring", "am_import_export")
+local am_import_export = require "am_import_export"
 local notifications_import_export = require "notifications_import_export"
-local scripts_import_export = require "scripts_import_export"
+local checks_import_export = require "checks_import_export"
 local pool_import_export = require "pool_import_export"
 local json = require "dkjson"
 local rest_utils = require "rest_utils"
