@@ -1,5 +1,5 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -7,6 +7,7 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 local page_utils = require("page_utils")
+local ui_utils = require("ui_utils")
 
 sendHTTPContentTypeHeader('text/html')
 
@@ -16,7 +17,7 @@ page_utils.set_active_menu_entry(page_utils.menu_entries.top_hosts)
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
 interface.select(ifname)
-local interface_refresh_rate = getInterfaceRefreshRate(getInterfaceId(ifname)) or 3
+local interface_refresh_rate = interface.getStatsUpdateFreq(getInterfaceId(ifname))
 
 local hosts_stats = interface.getLocalHostsInfo()
 local hosts_stats = hosts_stats["hosts"]
@@ -47,11 +48,14 @@ print [[
 </script>
 
 <script src="]] print(ntop.getHttpPrefix()) print [[/js/cubism_ntop.v1.js"></script>
+<div class='card'>
+<div class='card-body'>
 <div id="tophosts"></div>
+</div>
+</div>
 ]]
 
-print(i18n("top_hosts.note"))
-
+print(ui_utils.render_notes({}, i18n("top_hosts.note")))
 
 print [[
 <script>
@@ -153,7 +157,7 @@ context.on("focus", function(i) {
 
 ]]
 else
-   print("<div class=\"alert alert-danger\"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png> " .. i18n("no_results_found") .. "</div>")
+   print("<div class=\"alert alert-danger\"><i class='fas fa-exclamation-triangle fa-lg fa-ntopng-warning'></i> " .. i18n("no_results_found") .. "</div>")
 end
 
 dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
