@@ -1,5 +1,5 @@
 --
--- (C) 2013-18 - ntop.org
+-- (C) 2013-22 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -11,17 +11,16 @@ local page_utils = require("page_utils")
 
 sendHTTPContentTypeHeader('text/html')
 
+
 if (group_col == nil) then
    group_col = "asn"
 end
 
-page_utils.print_header()
+page_utils.set_active_menu_entry(page_utils.menu_entries.vlans)
 
-active_page = "hosts"
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
 print [[
-      <hr>
       <div id="table-vlan"></div>
 	 <script>
 	 var url_update = "]]
@@ -104,7 +103,14 @@ print [[
                              css: {
 			        textAlign: 'center'
 			     }
-
+				 },
+			     {
+			     title: "]] print(i18n("score")) print[[",
+				 field: "column_score",
+				 sortable: true,
+	 	             css: {
+			        textAlign: 'center'
+			     }
 				 },
 ]]
 
